@@ -1,5 +1,7 @@
-use rustdds::{ros2::NodeOptions, ros2::RosParticipant, serialization::CDRDeserializerAdapter};
-
+use rustdds::{
+  ros2::{NodeOptions, RosParticipant},
+  serialization::CDRDeserializerAdapter,
+};
 use log::{info, warn};
 use mio::{Events, Poll, PollOpt, Ready, Token};
 use mio_extras::channel as mio_channel;
@@ -33,7 +35,7 @@ impl TurtleListener {
       .create_ros_topic(
         &TurtleCmdVelTopic::topic_name(),
         TurtleCmdVelTopic::type_name(),
-        TurtleCmdVelTopic::get_qos(),
+        TurtleCmdVelTopic::qos(),
         TurtleCmdVelTopic::topic_kind(),
       )
       .unwrap();
