@@ -3,30 +3,33 @@
 #![deny(clippy::all)]
 #![warn(clippy::pedantic)]
 
-use log::{debug, trace, error, LevelFilter};
-use log4rs::{Config, config::Appender, config::Root, append::console::ConsoleAppender};
-
-use rustdds::dds::DomainParticipant;
-use rustdds::dds::qos::QosPolicyBuilder;
-use rustdds::dds::qos::policy::{Reliability, Durability, History, Deadline};
-use rustdds::dds::data_types::DDSDuration;
-use rustdds::dds::data_types::TopicKind;
-use rustdds::dds::traits::TopicDescription;
-use rustdds::dds::traits::Keyed;
-use rustdds::dds::statusevents::StatusEvented;
-use serde::{Serialize, Deserialize};
+use std::{
+  io,
+  time::{Duration, Instant},
+};
 
+use log::{debug, error, trace, LevelFilter};
+use log4rs::{
+  append::console::ConsoleAppender,
+  config::{Appender, Root},
+  Config,
+};
+use rustdds::dds::{
+  data_types::{DDSDuration, TopicKind},
+  qos::{
+    policy::{Deadline, Durability, History, Reliability},
+    QosPolicyBuilder,
+  },
+  statusevents::StatusEvented,
+  traits::{Keyed, TopicDescription},
+  DomainParticipant,
+};
+use serde::{Deserialize, Serialize};
 use clap::{App, Arg, ArgMatches}; // command line argument processing
-
 use mio::{Events, Poll, PollOpt, Ready, Token}; // polling
 use mio_extras::channel; // pollable channel
-
-use std::io;
-
 use rand::prelude::*;
 
-use std::time::{Duration, Instant};
-
 #[derive(Serialize, Deserialize, Clone)]
 struct Shape {
   color: String,
@@ -37,7 +40,7 @@ struct Shape {
 
 impl Keyed for Shape {
   type K = String;
-  fn get_key(&self) -> String {
+  fn key(&self) -> String {
     self.color.clone()
   }
 }
@@ -135,7 +138,7 @@ fn main() {
     .unwrap_or_else(|e| panic!("create_topic failed: {:?}", e));
   println!(
     "Topic name is {}. Type is {}.",
-    topic.get_name(),
+    topic.name(),
     topic.get_type().name()
   );
 
@@ -245,7 +248,7 @@ fn main() {
                   Ok(Some(sample)) => match sample.into_value() {
                     Ok(sample) => println!(
                       "{:10.10} {:10.10} {:3.3} {:3.3} [{}]",
-                      topic.get_name(),
+                      topic.name(),
                       sample.color,
                       sample.x,
                       sample.y,
