@@ -1,38 +1,40 @@
-use log::{debug, error, info, warn, trace};
-use mio::{Poll, Event, Events, Token, Ready, PollOpt};
-use mio_extras::channel as mio_channel;
-use std::{collections::HashMap, time::Duration};
 use std::{
+  collections::HashMap,
   rc::Rc,
   sync::{Arc, RwLock},
-  time::Instant,
+  time::{Duration, Instant},
 };
 
+use log::{debug, error, info, trace, warn};
+use mio::{Event, Events, Poll, PollOpt, Ready, Token};
+use mio_extras::channel as mio_channel;
+
 use crate::{
-  dds::{message_receiver::MessageReceiver},
-  dds::reader::{Reader, ReaderIngredients},
-  dds::writer::{Writer, WriterIngredients},
-  network::util::get_local_multicast_locators,
-  structure::builtin_endpoint::{BuiltinEndpointSet},
-  dds::qos::policy,
+  dds::{
+    message_receiver::MessageReceiver,
+    qos::policy,
+    reader::{Reader, ReaderIngredients},
+    writer::{Writer, WriterIngredients},
+  },
+  discovery::{
+    data_types::topic_data::{DiscoveredReaderData, DiscoveredWriterData},
+    discovery_db::DiscoveryDB,
+  },
+  messages::submessages::submessages::AckSubmessage,
+  network::{
+    constant::*, udp_listener::UDPListener, udp_sender::UDPSender,
+    util::get_local_multicast_locators,
+  },
+  structure::{
+    builtin_endpoint::BuiltinEndpointSet,
+    dds_cache::DDSCache,
+    entity::RTPSEntity,
+    guid::{EntityId, GuidPrefix, TokenDecode, GUID},
+    topic_kind::TopicKind,
+  },
 };
-
-use crate::network::udp_listener::UDPListener;
-use crate::network::udp_sender::UDPSender;
-use crate::network::constant::*;
-use crate::structure::guid::{GuidPrefix, GUID, EntityId, TokenDecode};
-use crate::structure::entity::RTPSEntity;
-use crate::discovery::data_types::topic_data::DiscoveredWriterData;
-use crate::discovery::data_types::topic_data::DiscoveredReaderData;
 //use crate::discovery::data_types::spdp_participant_data::SpdpDiscoveredParticipantData;
 use crate::discovery::discovery::Discovery;
-
-use crate::{
-  discovery::discovery_db::DiscoveryDB,
-  structure::{dds_cache::DDSCache, topic_kind::TopicKind},
-  messages::submessages::submessages::AckSubmessage,
-};
-
 use super::{
   rtps_reader_proxy::RtpsReaderProxy, rtps_writer_proxy::RtpsWriterProxy, typedesc::TypeDesc,
 };
@@ -64,10 +66,11 @@ pub struct DPEventLoop {
   // Writers
   add_writer_receiver: TokenReceiverPair<WriterIngredients>,
   remove_writer_receiver: TokenReceiverPair<GUID>,
-  //writer_timed_event_reciever: HashMap<Token, mio_channel::Receiver<TimerMessageType>>,
+  //writer_timed_event_receiver: HashMap<Token, mio_channel::Receiver<TimerMessageType>>,
   stop_poll_receiver: mio_channel::Receiver<()>,
-  // GuidPrefix sent in this channel needs to be RTPSMessage source_guid_prefix. Writer needs this to locate RTPSReaderProxy if negative acknack.
-  ack_nack_reciever: mio_channel::Receiver<(GuidPrefix, AckSubmessage)>,
+  // GuidPrefix sent in this channel needs to be RTPSMessage source_guid_prefix. Writer needs this
+  // to locate RTPSReaderProxy if negative acknack.
+  ack_nack_receiver: mio_channel::Receiver<(GuidPrefix, AckSubmessage)>,
 
   writers: HashMap<EntityId, Writer>,
   udp_sender: Rc<UDPSender>,
@@ -90,9 +93,10 @@ impl DPEventLoop {
     remove_writer_receiver: TokenReceiverPair<GUID>,
     stop_poll_receiver: mio_channel::Receiver<()>,
     discovery_update_notification_receiver: mio_channel::Receiver<DiscoveryNotificationType>,
+    spdp_liveness_sender: mio_channel::SyncSender<GuidPrefix>,
   ) -> DPEventLoop {
     let poll = Poll::new().expect("Unable to create new poll.");
-    let (acknack_sender, acknack_reciever) =
+    let (acknack_sender, acknack_receiver) =
       mio_channel::sync_channel::<(GuidPrefix, AckSubmessage)>(100);
     let mut udp_listeners = udp_listeners;
     for (token, listener) in &mut udp_listeners {
@@ -152,7 +156,7 @@ impl DPEventLoop {
 
     poll
       .register(
-        &acknack_reciever,
+        &acknack_receiver,
         ACKNACK_MESSGAGE_TO_LOCAL_WRITER_TOKEN,
         Ready::readable(),
         PollOpt::edge(),
@@ -168,7 +172,7 @@ impl DPEventLoop {
       )
       .expect("Failed to register reader update notification.");
 
-    // port number 0 menas OS chooses an available port number.
+    // port number 0 means OS chooses an available port number.
     let udp_sender = UDPSender::new(0).expect("UDPSender construction fail"); // TODO
 
     DPEventLoop {
@@ -178,14 +182,18 @@ impl DPEventLoop {
       discovery_db,
       udp_listeners,
       udp_sender: Rc::new(udp_sender),
-      message_receiver: MessageReceiver::new(participant_guid_prefix, acknack_sender),
+      message_receiver: MessageReceiver::new(
+        participant_guid_prefix,
+        acknack_sender,
+        spdp_liveness_sender,
+      ),
       add_reader_receiver,
       remove_reader_receiver,
       add_writer_receiver,
       remove_writer_receiver,
       stop_poll_receiver,
       writers: HashMap::new(),
-      ack_nack_reciever: acknack_reciever,
+      ack_nack_receiver: acknack_receiver,
       discovery_update_notification_receiver,
     }
   }
@@ -241,7 +249,7 @@ impl DPEventLoop {
                       error!("No listener with token {:?}", &event.token());
                       vec![]
                     },
-                    |l| l.get_messages(),
+                    |l| l.messages(),
                   );
                 for packet in udp_messages.into_iter() {
                   ev_wrapper.message_receiver.handle_received_packet(packet)
@@ -319,7 +327,7 @@ impl DPEventLoop {
               if eid.kind().is_reader() {
                 ev_wrapper
                   .message_receiver
-                  .get_reader_mut(eid)
+                  .reader_mut(eid)
                   .map(|reader| reader.process_command())
                   .unwrap_or_else(|| error!("Event for unknown reader {:?}", eid));
               } else if eid.kind().is_writer() {
@@ -331,10 +339,11 @@ impl DPEventLoop {
                   Some(writer) => {
                     // Writer will record data to DDSCache and send it out.
                     writer.process_writer_command();
-                    writer.get_local_readers()
+                    writer.local_readers()
                   }
                 };
-                // Notify local (same participant) readers that new data is available in the cache.
+                // Notify local (same participant) readers that new data is available in the
+                // cache.
                 ev_wrapper
                   .message_receiver
                   .notify_data_to_readers(local_readers);
@@ -386,7 +395,7 @@ impl DPEventLoop {
             .poll
             .register(
               &new_reader.data_reader_command_receiver,
-              new_reader.get_entity_token(),
+              new_reader.entity_token(),
               Ready::readable(),
               PollOpt::edge(),
             )
@@ -444,14 +453,12 @@ impl DPEventLoop {
             .poll
             .register(
               &new_writer.writer_command_receiver,
-              new_writer.get_entity_token(),
+              new_writer.entity_token(),
               Ready::readable(),
               PollOpt::edge(),
             )
             .expect("Writer command channel registration failed!!");
-          self
-            .writers
-            .insert(new_writer.get_guid().entity_id, new_writer);
+          self.writers.insert(new_writer.guid().entity_id, new_writer);
         }
       }
       REMOVE_WRITER_TOKEN => {
@@ -473,7 +480,8 @@ impl DPEventLoop {
   }
 
   /// Writer timed events can be heatrbeats or cache cleaning events.
-  /// events are distinguished by TimerMessageType which is send via mio channel. Channel token in
+  /// events are distinguished by TimerMessageType which is send via mio
+  /// channel. Channel token in
   fn handle_writer_timed_event(&mut self, entity_id: EntityId) {
     match self.writers.get_mut(&entity_id) {
       Some(writer) => writer.handle_timed_event(),
@@ -482,14 +490,14 @@ impl DPEventLoop {
   }
 
   fn handle_reader_timed_event(&mut self, entity_id: EntityId) {
-    match self.message_receiver.get_reader_mut(entity_id) {
+    match self.message_receiver.reader_mut(entity_id) {
       Some(reader) => reader.handle_timed_event(),
       None => error!("Reader was not found with {:?}", entity_id),
     }
   }
 
   fn handle_writer_acknack_action(&mut self, _event: &Event) {
-    while let Ok((acknack_sender_prefix, acknack_submessage)) = self.ack_nack_reciever.try_recv() {
+    while let Ok((acknack_sender_prefix, acknack_submessage)) = self.ack_nack_receiver.try_recv() {
       let writer_guid = GUID::new_with_prefix_and_id(
         self.domain_info.domain_participant_guid.guid_prefix,
         acknack_submessage.writer_id(),
@@ -528,28 +536,28 @@ impl DPEventLoop {
 
       for (writer_eid, reader_eid, endpoint) in &[
         (
-          EntityId::ENTITYID_SPDP_BUILTIN_PARTICIPANT_WRITER, // SPDP
-          EntityId::ENTITYID_SPDP_BUILTIN_PARTICIPANT_READER,
+          EntityId::SPDP_BUILTIN_PARTICIPANT_WRITER, // SPDP
+          EntityId::SPDP_BUILTIN_PARTICIPANT_READER,
           BuiltinEndpointSet::DISC_BUILTIN_ENDPOINT_PARTICIPANT_DETECTOR,
         ),
         (
-          EntityId::ENTITYID_SEDP_BUILTIN_SUBSCRIPTIONS_WRITER, // SEDP ...
-          EntityId::ENTITYID_SEDP_BUILTIN_SUBSCRIPTIONS_READER,
+          EntityId::SEDP_BUILTIN_SUBSCRIPTIONS_WRITER, // SEDP ...
+          EntityId::SEDP_BUILTIN_SUBSCRIPTIONS_READER,
           BuiltinEndpointSet::DISC_BUILTIN_ENDPOINT_SUBSCRIPTIONS_DETECTOR,
         ),
         (
-          EntityId::ENTITYID_SEDP_BUILTIN_PUBLICATIONS_WRITER,
-          EntityId::ENTITYID_SEDP_BUILTIN_PUBLICATIONS_READER,
+          EntityId::SEDP_BUILTIN_PUBLICATIONS_WRITER,
+          EntityId::SEDP_BUILTIN_PUBLICATIONS_READER,
           BuiltinEndpointSet::DISC_BUILTIN_ENDPOINT_PUBLICATIONS_DETECTOR,
         ),
         (
-          EntityId::ENTITYID_SEDP_BUILTIN_TOPIC_WRITER,
-          EntityId::ENTITYID_SEDP_BUILTIN_TOPIC_READER,
+          EntityId::SEDP_BUILTIN_TOPIC_WRITER,
+          EntityId::SEDP_BUILTIN_TOPIC_READER,
           BuiltinEndpointSet::DISC_BUILTIN_ENDPOINT_TOPICS_DETECTOR,
         ),
         (
-          EntityId::ENTITYID_P2P_BUILTIN_PARTICIPANT_MESSAGE_WRITER,
-          EntityId::ENTITYID_P2P_BUILTIN_PARTICIPANT_MESSAGE_READER,
+          EntityId::P2P_BUILTIN_PARTICIPANT_MESSAGE_WRITER,
+          EntityId::P2P_BUILTIN_PARTICIPANT_MESSAGE_READER,
           BuiltinEndpointSet::BUILTIN_ENDPOINT_PARTICIPANT_MESSAGE_DATA_READER,
         ),
       ] {
@@ -559,7 +567,7 @@ impl DPEventLoop {
           // special case by RTPS 2.3 spec Section
           // "8.4.13.3 BuiltinParticipantMessageWriter and
           // BuiltinParticipantMessageReader QoS"
-          if *reader_eid == EntityId::ENTITYID_P2P_BUILTIN_PARTICIPANT_MESSAGE_READER
+          if *reader_eid == EntityId::P2P_BUILTIN_PARTICIPANT_MESSAGE_READER
             && discovered_participant
               .builtin_endpoint_qos
               .map(|beq| beq.is_best_effort())
@@ -574,18 +582,18 @@ impl DPEventLoop {
           {
             let mut reader_proxy = discovered_participant.as_reader_proxy(true, Some(*reader_eid));
 
-            if *writer_eid == EntityId::ENTITYID_SPDP_BUILTIN_PARTICIPANT_WRITER {
+            if *writer_eid == EntityId::SPDP_BUILTIN_PARTICIPANT_WRITER {
               // Simple Particiapnt Discovery Protocol (SPDP) writer is special,
               // different from SEDP writers
               qos = Discovery::create_spdp_patricipant_qos(); // different QoS
                                                               // adding a multicast reader
               reader_proxy.remote_reader_guid = GUID::new_with_prefix_and_id(
-                GuidPrefix::GUIDPREFIX_UNKNOWN,
-                EntityId::ENTITYID_SPDP_BUILTIN_PARTICIPANT_READER,
+                GuidPrefix::UNKNOWN,
+                EntityId::SPDP_BUILTIN_PARTICIPANT_READER,
               );
 
               reader_proxy.multicast_locator_list = get_local_multicast_locators(
-                get_spdp_well_known_multicast_port(self.domain_info.domain_id),
+                spdp_well_known_multicast_port(self.domain_info.domain_id),
               );
             }
             // common processing for SPDP and SEDP
@@ -604,34 +612,34 @@ impl DPEventLoop {
       // EntityIds are for announcers
       for (writer_eid, reader_eid, endpoint) in &[
         (
-          EntityId::ENTITYID_SPDP_BUILTIN_PARTICIPANT_WRITER, // SPDP
-          EntityId::ENTITYID_SPDP_BUILTIN_PARTICIPANT_READER,
+          EntityId::SPDP_BUILTIN_PARTICIPANT_WRITER, // SPDP
+          EntityId::SPDP_BUILTIN_PARTICIPANT_READER,
           BuiltinEndpointSet::DISC_BUILTIN_ENDPOINT_PARTICIPANT_ANNOUNCER,
         ),
         (
-          EntityId::ENTITYID_SEDP_BUILTIN_SUBSCRIPTIONS_WRITER, // SEDP ...
-          EntityId::ENTITYID_SEDP_BUILTIN_SUBSCRIPTIONS_READER,
+          EntityId::SEDP_BUILTIN_SUBSCRIPTIONS_WRITER, // SEDP ...
+          EntityId::SEDP_BUILTIN_SUBSCRIPTIONS_READER,
           BuiltinEndpointSet::DISC_BUILTIN_ENDPOINT_PUBLICATIONS_ANNOUNCER,
         ),
         (
-          EntityId::ENTITYID_SEDP_BUILTIN_PUBLICATIONS_WRITER,
-          EntityId::ENTITYID_SEDP_BUILTIN_PUBLICATIONS_READER,
+          EntityId::SEDP_BUILTIN_PUBLICATIONS_WRITER,
+          EntityId::SEDP_BUILTIN_PUBLICATIONS_READER,
           BuiltinEndpointSet::DISC_BUILTIN_ENDPOINT_PUBLICATIONS_ANNOUNCER,
         ),
         (
-          EntityId::ENTITYID_SEDP_BUILTIN_TOPIC_WRITER,
-          EntityId::ENTITYID_SEDP_BUILTIN_TOPIC_READER,
+          EntityId::SEDP_BUILTIN_TOPIC_WRITER,
+          EntityId::SEDP_BUILTIN_TOPIC_READER,
           BuiltinEndpointSet::DISC_BUILTIN_ENDPOINT_TOPICS_ANNOUNCER,
         ),
         (
-          EntityId::ENTITYID_P2P_BUILTIN_PARTICIPANT_MESSAGE_WRITER,
-          EntityId::ENTITYID_P2P_BUILTIN_PARTICIPANT_MESSAGE_READER,
+          EntityId::P2P_BUILTIN_PARTICIPANT_MESSAGE_WRITER,
+          EntityId::P2P_BUILTIN_PARTICIPANT_MESSAGE_READER,
           BuiltinEndpointSet::BUILTIN_ENDPOINT_PARTICIPANT_MESSAGE_DATA_WRITER,
         ),
       ] {
         if let Some(reader) = self.message_receiver.available_readers.get_mut(reader_eid) {
           debug!("try update_discovery_reader - {:?}", reader.topic_name());
-          let qos = if *reader_eid == EntityId::ENTITYID_SPDP_BUILTIN_PARTICIPANT_READER {
+          let qos = if *reader_eid == EntityId::SPDP_BUILTIN_PARTICIPANT_READER {
             Discovery::create_spdp_patricipant_qos()
           } else {
             Discovery::publisher_qos()
@@ -718,7 +726,7 @@ impl DPEventLoop {
     match self.discovery_db.read() {
       Ok(db) => match self.ddscache.write() {
         Ok(mut ddsc) => {
-          for topic in db.get_all_topics() {
+          for topic in db.all_topics() {
             // TODO: how do you know when topic is keyed and is not
             let topic_kind = match &topic.topic_data.key {
               Some(_) => TopicKind::WithKey,
@@ -744,13 +752,15 @@ impl DPEventLoop {
 
 #[cfg(test)]
 mod tests {
+  use std::{thread, time::Duration};
+
+  use mio::{PollOpt, Ready};
+
   use super::*;
-  use std::thread;
-  use std::time::Duration;
-  use crate::{dds::statusevents::DataReaderStatus};
-  use mio::{Ready, PollOpt};
-  use crate::{dds::with_key::datareader::ReaderCommand, dds::qos::QosPolicies};
-  use crate::structure::dds_cache::DDSCache;
+  use crate::{
+    dds::{qos::QosPolicies, statusevents::DataReaderStatus, with_key::datareader::ReaderCommand},
+    structure::dds_cache::DDSCache,
+  };
 
   #[test]
   fn dpew_add_and_remove_readers() {
@@ -765,9 +775,13 @@ mod tests {
 
     let (_discovery_update_notification_sender, discovery_update_notification_receiver) =
       mio_channel::channel();
+    let (spdp_liveness_sender, _spdp_liveness_receiver) = mio_channel::sync_channel(8);
 
     let ddshc = Arc::new(RwLock::new(DDSCache::new()));
-    let discovery_db = Arc::new(RwLock::new(DiscoveryDB::new(GUID::new_particiapnt_guid())));
+    let discovery_db = Arc::new(RwLock::new(DiscoveryDB::new(
+      GUID::new_particiapnt_guid(),
+      None,
+    )));
 
     let domain_info = DomainInfo {
       domain_participant_guid: GUID::default(),
@@ -802,6 +816,7 @@ mod tests {
         },
         stop_poll_receiver,
         discovery_update_notification_receiver,
+        spdp_liveness_sender,
       );
       dp_event_loop
         .poll
@@ -822,7 +837,7 @@ mod tests {
       let new_guid = GUID::default();
 
       let (send, _rec) = mio_channel::sync_channel::<()>(100);
-      let (status_sender, _status_reciever) =
+      let (status_sender, _status_receiver) =
         mio_extras::channel::sync_channel::<DataReaderStatus>(100);
       let (_reader_commander, reader_command_receiver) =
         mio_extras::channel::sync_channel::<ReaderCommand>(100);
@@ -877,8 +892,8 @@ mod tests {
   //     resource_limits: None,
   //     lifespan: None,
   //   };
-  //   let dp = DomainParticipant::new(0).expect("Failed to create participant");
-  //   let sub = dp.create_subscriber(&somePolicies).unwrap();
+  //   let dp = DomainParticipant::new(0).expect("Failed to create
+  // participant");   let sub = dp.create_subscriber(&somePolicies).unwrap();
 
   //   let topic_1 = dp
   //     .create_topic("TOPIC_1", "jotain", &somePolicies, TopicKind::WithKey)
@@ -892,15 +907,17 @@ mod tests {
 
   //   // Adding readers
   //   let (sender_add_reader, receiver_add) = mio_channel::channel::<Reader>();
-  //   let (_sender_remove_reader, receiver_remove) = mio_channel::channel::<GUID>();
+  //   let (_sender_remove_reader, receiver_remove) =
+  // mio_channel::channel::<GUID>();
 
   //   let (_add_writer_sender, add_writer_receiver) = mio_channel::channel();
-  //   let (_remove_writer_sender, remove_writer_receiver) = mio_channel::channel();
+  //   let (_remove_writer_sender, remove_writer_receiver) =
+  // mio_channel::channel();
 
   //   let (_stop_poll_sender, stop_poll_receiver) = mio_channel::channel();
 
-  //   let (_discovery_update_notification_sender, discovery_update_notification_receiver) =
-  //     mio_channel::channel();
+  //   let (_discovery_update_notification_sender,
+  // discovery_update_notification_receiver) =     mio_channel::channel();
 
   //   let ddshc = Arc::new(RwLock::new(DDSCache::new()));
   //   let discovery_db = Arc::new(RwLock::new(DiscoveryDB::new()));
@@ -948,20 +965,21 @@ mod tests {
   //     )
   //     .expect("Failed to register receivers.");
 
-  //   let child = thread::spawn(move || DPEventLoop::event_loop(dp_event_loop));
+  //   let child = thread::spawn(move ||
+  // DPEventLoop::event_loop(dp_event_loop));
 
   //   //TODO IF THIS IS SET TO 1 TEST SUCCEEDS
   //   let n = 1;
 
   //   let mut reader_guids = Vec::new();
-  //   let mut data_readers: Vec<DataReader<RandomData, CDRDeserializerAdapter<RandomData>>> = vec![];
-  //   let _topics: Vec<Topic> = vec![];
-  //   for i in 0..n {
+  //   let mut data_readers: Vec<DataReader<RandomData,
+  // CDRDeserializerAdapter<RandomData>>> = vec![];   let _topics: Vec<Topic>
+  // = vec![];   for i in 0..n {
   //     //topics.push(topic);
   //     let new_guid = GUID::default();
 
   //     let (send, _rec) = mio_channel::sync_channel::<()>(100);
-  //     let (status_sender, status_reciever_DataReader) =
+  //     let (status_sender, status_receiver_DataReader) =
   //       mio_extras::channel::sync_channel::<DataReaderStatus>(1000);
   //     let (reader_commander, reader_command_receiver) =
   //       mio_extras::channel::sync_channel::<ReaderCommand>(1000);
@@ -998,16 +1016,16 @@ mod tests {
   //       )
   //       .unwrap();
 
-  //     datareader.set_status_change_receiver(status_reciever_DataReader);
+  //     datareader.set_status_change_receiver(status_receiver_DataReader);
   //     datareader.set_reader_commander(reader_commander);
   //     data_readers.push(datareader);
 
   //     //new_reader.set_qos(&somePolicies).unwrap();
-  //     new_reader.matched_writer_add(GUID::default(), EntityId::ENTITYID_UNKNOWN, vec![], vec![]);
-  //     reader_guids.push(new_reader.get_guid().clone());
-  //     info!("\nSent reader number {}: {:?}\n", i, &new_reader);
-  //     sender_add_reader.send(new_reader).unwrap();
-  //     std::thread::sleep(Duration::from_millis(100));
+  //     new_reader.matched_writer_add(GUID::default(),
+  // EntityId::UNKNOWN, vec![], vec![]);     reader_guids.
+  // push(new_reader.guid().clone());     info!("\nSent reader number {}:
+  // {:?}\n", i, &new_reader);     sender_add_reader.send(new_reader).
+  // unwrap();     std::thread::sleep(Duration::from_millis(100));
   //   }
   //   thread::sleep(Duration::from_millis(100));
 
