@@ -1,28 +1,21 @@
-use std::{
-  time::{Duration},
-};
+use std::time::Duration;
 
 use serde::Serialize;
 
-use crate::{serialization::CDRSerializerAdapter, structure::time::Timestamp};
-use crate::structure::entity::{RTPSEntity};
-
-use crate::dds::pubsub::Publisher;
-use crate::dds::topic::Topic;
-use crate::dds::values::result::Result;
-
-use crate::dds::data_types::*;
-use crate::dds::traits::dds_entity::DDSEntity;
-
-use crate::dds::traits::serde_adapters::no_key::SerializerAdapter;
-
-use crate::dds::qos::{HasQoSPolicy, QosPolicies};
-
 use crate::{
+  dds::{
+    data_types::*,
+    pubsub::Publisher,
+    qos::{HasQoSPolicy, QosPolicies},
+    topic::Topic,
+    traits::{dds_entity::DDSEntity, serde_adapters::no_key::SerializerAdapter},
+    values::result::Result,
+    with_key::datawriter as datawriter_with_key,
+  },
   discovery::data_types::topic_data::SubscriptionBuiltinTopicData,
-  dds::with_key::datawriter as datawriter_with_key,
+  serialization::CDRSerializerAdapter,
+  structure::{entity::RTPSEntity, time::Timestamp},
 };
-
 use super::wrappers::{NoKeyWrapper, SAWrapper};
 
 /// DDS DataWriter for no key topics
@@ -279,10 +272,10 @@ where
   /// let topic = domain_participant.create_topic("some_topic".to_string(), "SomeType".to_string(), &qos, TopicKind::NoKey).unwrap();
   /// let data_writer = publisher.create_datawriter_no_key::<SomeType, CDRSerializerAdapter<_>>(topic.clone(), None).unwrap();
   ///
-  /// assert_eq!(&topic, data_writer.get_topic());
+  /// assert_eq!(&topic, data_writer.topic());
   /// ```
-  pub fn get_topic(&self) -> &Topic {
-    self.keyed_datawriter.get_topic()
+  pub fn topic(&self) -> &Topic {
+    self.keyed_datawriter.topic()
   }
 
   /// Publisher this DataWriter is connected to.
@@ -308,10 +301,10 @@ where
   /// let topic = domain_participant.create_topic("some_topic".to_string(), "SomeType".to_string(), &qos, TopicKind::NoKey).unwrap();
   /// let data_writer = publisher.create_datawriter_no_key::<SomeType, CDRSerializerAdapter<_>>(topic, None).unwrap();
   ///
-  /// assert_eq!(&publisher, data_writer.get_publisher());
+  /// assert_eq!(&publisher, data_writer.publisher());
   /// ```
-  pub fn get_publisher(&self) -> &Publisher {
-    self.keyed_datawriter.get_publisher()
+  pub fn publisher(&self) -> &Publisher {
+    self.keyed_datawriter.publisher()
   }
 
   /// Manually asserts liveliness if QoS agrees
@@ -346,9 +339,8 @@ where
   /// Unimplemented. <b>Do not use</b>.
   ///
   /// # Examples
-  ///
   // TODO: enable run when implemented
-  /// ```no_run
+  /// ```no_run ignore
   /// # use serde::{Serialize, Deserialize};
   /// # use rustdds::dds::DomainParticipant;
   /// # use rustdds::dds::qos::QosPolicyBuilder;
@@ -410,8 +402,8 @@ where
 }
 
 impl<D: Serialize, SA: SerializerAdapter<D>> RTPSEntity for DataWriter<D, SA> {
-  fn get_guid(&self) -> GUID {
-    self.keyed_datawriter.get_guid()
+  fn guid(&self) -> GUID {
+    self.keyed_datawriter.guid()
   }
 }
 
@@ -420,8 +412,8 @@ impl<D: Serialize, SA: SerializerAdapter<D>> HasQoSPolicy for DataWriter<D, SA>
   //   self.keyed_datawriter.set_qos(policy)
   // }
 
-  fn get_qos(&self) -> QosPolicies {
-    self.keyed_datawriter.get_qos()
+  fn qos(&self) -> QosPolicies {
+    self.keyed_datawriter.qos()
   }
 }
 
@@ -429,12 +421,15 @@ impl<D: Serialize, SA: SerializerAdapter<D>> DDSEntity for DataWriter<D, SA> {}
 
 #[cfg(test)]
 mod tests {
-  use super::*;
-  use crate::dds::{participant::DomainParticipant, topic::TopicKind};
-  use crate::test::random_data::*;
-  use crate::serialization::cdr_serializer::*;
   use byteorder::LittleEndian;
 
+  use super::*;
+  use crate::{
+    dds::{participant::DomainParticipant, topic::TopicKind},
+    serialization::cdr_serializer::*,
+    test::random_data::*,
+  };
+
   #[test]
   fn dw_write_test() {
     let domain_participant = DomainParticipant::new(0).expect("Failed to create participant");
