@@ -1,38 +1,31 @@
 //use mio::Token;
-use mio_extras::channel as mio_channel;
-#[allow(unused_imports)]
-use log::{error, debug, info, warn, trace};
-
 use std::{
+  collections::HashMap,
+  net::Ipv4Addr,
+  sync::{Arc, Mutex, RwLock, Weak},
   thread,
   thread::JoinHandle,
-  collections::HashMap,
-  time::Duration,
-  sync::{Arc, RwLock, Mutex, Weak},
-  net::Ipv4Addr,
+  time::{Duration, Instant},
 };
 
-use crate::log_and_err_internal;
-use crate::{
-  discovery::data_types::topic_data::DiscoveredTopicData,
-  discovery::discovery::DiscoveryCommand,
-  network::{udp_listener::UDPListener, constant::*},
-};
-
-use crate::dds::{
-  dp_event_loop::DPEventLoop, reader::*, writer::*, pubsub::*, topic::*, typedesc::*, qos::*,
-  values::result::*,
-};
+use mio_extras::channel as mio_channel;
+#[allow(unused_imports)]
+use log::{debug, error, info, trace, warn};
 
 use crate::{
-  discovery::{discovery::Discovery, discovery_db::DiscoveryDB},
-  structure::{
-    entity::{RTPSEntity},
-    guid::GUID,
-    dds_cache::DDSCache,
+  dds::{
+    data_types::*, dp_event_loop::DPEventLoop, pubsub::*, qos::*, reader::*, topic::*, typedesc::*,
+    values::result::*, writer::*,
   },
+  discovery::{
+    data_types::topic_data::DiscoveredTopicData,
+    discovery::{Discovery, DiscoveryCommand},
+    discovery_db::DiscoveryDB,
+  },
+  log_and_err_internal,
+  network::{constant::*, udp_listener::UDPListener},
+  structure::{dds_cache::DDSCache, entity::RTPSEntity, guid::GUID},
 };
-
 use super::dp_event_loop::DomainInfo;
 
 /// DDS DomainParticipant generally only one per domain per machine should be
@@ -53,26 +46,38 @@ impl DomainParticipant {
   pub fn new(domain_id: u16) -> Result<DomainParticipant> {
     trace!("DomainParticipant construct start");
 
-    // Discovery join channel is used to just send a join handle into the inner participant,
-    // so its .drop() can wait until discovery has had a chance to stop.
+    // Discovery join channel is used to just send a join handle into the inner
+    // participant, so its .drop() can wait until discovery has had a chance to
+    // stop.
     let (djh_sender, djh_receiver) = mio_channel::channel();
 
-    let mut dpd = DomainParticipantDisc::new(domain_id, djh_receiver)?;
+    // Channel is used to notify Discovery of (duplicate) SPDP messages from the
+    // wire.
+    let (spdp_liveness_sender, spdp_liveness_receiver) = mio_channel::sync_channel(8);
 
-    let discovery_updated_sender = match dpd.discovery_updated_sender.take() {
-      Some(dus) => dus,
-      // this error should never happen
-      None => return log_and_err_internal!("Unable to receive Discovery Updated Sender."),
-    };
+    // Discovery thread receives and decodes updates from the wire.
+    // It updates data to DiscoveryDB, and sends notifications to dp_event_loop,
+    // which owns the Readers and Writers and notifies them also.
+    let (discovery_updated_sender, discovery_update_notification_receiver) =
+      mio_channel::sync_channel::<DiscoveryNotificationType>(32);
 
-    let discovery_command_receiver = match dpd.discovery_command_receiver.take() {
-      Some(dsr) => dsr,
-      // this error should never happen
-      None => return log_and_err_internal!("Unable to get Discovery Command Receiver."),
-    };
+    // This channel is used to:
+    // * local DataReader and DataWriter notify Discovery on drop() so that
+    // Discovery knows we no longer have them.
+    // * Participant commands Discovery to assert liveness, i.e. send liveness
+    // message to remote participants.
+    // * Discovery commands Discovery (thread) to terminate on exit.
+    let (discovery_command_sender, discovery_command_receiver) =
+      mio_channel::sync_channel::<DiscoveryCommand>(64);
 
     let dp = DomainParticipant {
-      dpi: Arc::new(Mutex::new(dpd)),
+      dpi: Arc::new(Mutex::new(DomainParticipantDisc::new(
+        domain_id,
+        djh_receiver,
+        discovery_update_notification_receiver,
+        discovery_command_sender,
+        spdp_liveness_sender,
+      )?)),
     };
 
     let (discovery_started_sender, discovery_started_receiver) =
@@ -84,19 +89,15 @@ impl DomainParticipant {
     let discovery_handle = thread::Builder::new()
       .name("RustDDS discovery thread".to_string())
       .spawn(move || {
-        match Discovery::new(
+        if let Ok(mut discovery) = Discovery::new(
           dp_clone,
           disc_db_clone,
           discovery_started_sender,
           discovery_updated_sender,
           discovery_command_receiver,
+          spdp_liveness_receiver,
         ) {
-          Ok(mut discovery) =>
-          // run the event loop
-          {
-            discovery.discovery_event_loop()
-          }
-          Err(_) => (),
+          discovery.discovery_event_loop() // run the event loop
         }
       })?;
 
@@ -230,13 +231,13 @@ impl DomainParticipant {
   /// ```
   /// # use rustdds::dds::DomainParticipant;
   /// let domain_participant = DomainParticipant::new(0).unwrap();
-  /// let discovered_topics = domain_participant.get_discovered_topics();
+  /// let discovered_topics = domain_participant.discovered_topics();
   /// for dtopic in discovered_topics.iter() {
   ///   // do something
   /// }
   /// ```
-  pub fn get_discovered_topics(&self) -> Vec<DiscoveredTopicData> {
-    self.dpi.lock().unwrap().get_discovered_topics()
+  pub fn discovered_topics(&self) -> Vec<DiscoveredTopicData> {
+    self.dpi.lock().unwrap().discovered_topics()
   }
 
   /// Manually asserts liveliness, affecting all writers with
@@ -255,11 +256,11 @@ impl DomainParticipant {
   }
 
   pub(crate) fn weak_clone(&self) -> DomainParticipantWeak {
-    DomainParticipantWeak::new(self.clone(), self.get_guid())
+    DomainParticipantWeak::new(self.clone(), self.guid())
   }
 
-  pub(crate) fn get_dds_cache(&self) -> Arc<RwLock<DDSCache>> {
-    self.dpi.lock().unwrap().get_dds_cache()
+  pub(crate) fn dds_cache(&self) -> Arc<RwLock<DDSCache>> {
+    self.dpi.lock().unwrap().dds_cache()
   }
 
   pub(crate) fn discovery_db(&self) -> Arc<RwLock<DiscoveryDB>> {
@@ -277,7 +278,7 @@ impl DomainParticipant {
 
 impl PartialEq for DomainParticipant {
   fn eq(&self, other: &Self) -> bool {
-    self.get_guid() == other.get_guid()
+    self.guid() == other.guid()
       && self.domain_id() == other.domain_id()
       && self.participant_id() == other.participant_id()
   }
@@ -300,14 +301,14 @@ impl DomainParticipantWeak {
 
   pub fn create_publisher(&self, qos: &QosPolicies) -> Result<Publisher> {
     match self.dpi.upgrade() {
-      Some(dpi) => dpi.lock().unwrap().create_publisher(&self, qos),
+      Some(dpi) => dpi.lock().unwrap().create_publisher(self, qos),
       None => Err(Error::OutOfResources),
     }
   }
 
-  pub fn create_subscriber<'a>(&self, qos: &QosPolicies) -> Result<Subscriber> {
+  pub fn create_subscriber(&self, qos: &QosPolicies) -> Result<Subscriber> {
     match self.dpi.upgrade() {
-      Some(dpi) => dpi.lock().unwrap().create_subscriber(&self, qos),
+      Some(dpi) => dpi.lock().unwrap().create_subscriber(self, qos),
       None => Err(Error::OutOfResources),
     }
   }
@@ -323,14 +324,14 @@ impl DomainParticipantWeak {
       Some(dpi) => dpi
         .lock()
         .unwrap()
-        .create_topic(&self, name, type_desc, qos, topic_kind),
+        .create_topic(self, name, type_desc, qos, topic_kind),
       None => Err(Error::LockPoisoned),
     }
   }
 
   pub fn find_topic(&self, name: &str, timeout: Duration) -> Result<Option<Topic>> {
     match self.dpi.upgrade() {
-      Some(dpi) => dpi.lock().unwrap().find_topic(&self, name, timeout),
+      Some(dpi) => dpi.lock().unwrap().find_topic(self, name, timeout),
       None => Err(Error::LockPoisoned),
     }
   }
@@ -349,23 +350,20 @@ impl DomainParticipantWeak {
     }
   }
 
-  pub fn get_discovered_topics(&self) -> Vec<DiscoveredTopicData> {
+  pub fn discovered_topics(&self) -> Vec<DiscoveredTopicData> {
     match self.dpi.upgrade() {
-      Some(dpi) => dpi.lock().unwrap().get_discovered_topics(),
+      Some(dpi) => dpi.lock().unwrap().discovered_topics(),
       None => Vec::new(),
     }
   }
 
   pub fn upgrade(self) -> Option<DomainParticipant> {
-    match self.dpi.upgrade() {
-      Some(d) => Some(DomainParticipant { dpi: d }),
-      None => None,
-    }
+    self.dpi.upgrade().map(|d| DomainParticipant { dpi: d })
   }
 } // end impl
 
 impl RTPSEntity for DomainParticipantWeak {
-  fn get_guid(&self) -> GUID {
+  fn guid(&self) -> GUID {
     self.guid
   }
 }
@@ -375,9 +373,9 @@ impl RTPSEntity for DomainParticipantWeak {
 pub(crate) struct DomainParticipantDisc {
   dpi: Arc<Mutex<DomainParticipantInner>>,
   // Discovery control
-  discovery_updated_sender: Option<mio_channel::SyncSender<DiscoveryNotificationType>>,
-  discovery_command_receiver: Option<mio_channel::Receiver<DiscoveryCommand>>,
-  discovery_command_channel: mio_channel::SyncSender<DiscoveryCommand>,
+  //discovery_updated_sender: mio_channel::SyncSender<DiscoveryNotificationType>,
+  //discovery_command_receiver: mio_channel::Receiver<DiscoveryCommand>,
+  discovery_command_sender: mio_channel::SyncSender<DiscoveryCommand>,
   discovery_join_handle: mio_channel::Receiver<JoinHandle<()>>,
 }
 
@@ -385,20 +383,21 @@ impl DomainParticipantDisc {
   pub fn new(
     domain_id: u16,
     discovery_join_handle: mio_channel::Receiver<JoinHandle<()>>,
+    discovery_update_notification_receiver: mio_channel::Receiver<DiscoveryNotificationType>,
+    discovery_command_sender: mio_channel::SyncSender<DiscoveryCommand>,
+    spdp_liveness_sender: mio_channel::SyncSender<GuidPrefix>,
   ) -> Result<DomainParticipantDisc> {
-    let (discovery_update_notification_sender, discovery_update_notification_receiver) =
-      mio_channel::sync_channel::<DiscoveryNotificationType>(100);
-
-    let dpi = DomainParticipantInner::new(domain_id, discovery_update_notification_receiver)?;
-
-    let (discovery_command_sender, discovery_command_receiver) =
-      mio_channel::sync_channel::<DiscoveryCommand>(10);
+    let dpi = DomainParticipantInner::new(
+      domain_id,
+      discovery_update_notification_receiver,
+      spdp_liveness_sender,
+    )?;
 
     Ok(DomainParticipantDisc {
       dpi: Arc::new(Mutex::new(dpi)),
-      discovery_updated_sender: Some(discovery_update_notification_sender),
-      discovery_command_receiver: Some(discovery_command_receiver),
-      discovery_command_channel: discovery_command_sender,
+      //discovery_updated_sender,
+      //discovery_command_receiver,
+      discovery_command_sender,
       discovery_join_handle,
     })
   }
@@ -412,10 +411,10 @@ impl DomainParticipantDisc {
       .dpi
       .lock()
       .unwrap()
-      .create_publisher(&dp, qos, self.discovery_command_channel.clone())
+      .create_publisher(dp, qos, self.discovery_command_sender.clone())
   }
 
-  pub fn create_subscriber<'a>(
+  pub fn create_subscriber(
     &self,
     dp: &DomainParticipantWeak,
     qos: &QosPolicies,
@@ -424,7 +423,7 @@ impl DomainParticipantDisc {
       .dpi
       .lock()
       .unwrap()
-      .create_subscriber(&dp, qos, self.discovery_command_channel.clone())
+      .create_subscriber(dp, qos, self.discovery_command_sender.clone())
   }
 
   pub fn create_topic(
@@ -440,7 +439,7 @@ impl DomainParticipantDisc {
       .dpi
       .lock()
       .unwrap()
-      .create_topic(&dp, name, type_desc, qos, topic_kind)
+      .create_topic(dp, name, type_desc, qos, topic_kind)
   }
 
   pub fn find_topic(
@@ -449,7 +448,7 @@ impl DomainParticipantDisc {
     name: &str,
     timeout: Duration,
   ) -> Result<Option<Topic>> {
-    self.dpi.lock().unwrap().find_topic(&dp, name, timeout)
+    self.dpi.lock().unwrap().find_topic(dp, name, timeout)
   }
 
   pub fn domain_id(&self) -> u16 {
@@ -460,12 +459,12 @@ impl DomainParticipantDisc {
     self.dpi.lock().unwrap().participant_id()
   }
 
-  pub fn get_discovered_topics(&self) -> Vec<DiscoveredTopicData> {
-    self.dpi.lock().unwrap().get_discovered_topics()
+  pub fn discovered_topics(&self) -> Vec<DiscoveredTopicData> {
+    self.dpi.lock().unwrap().discovered_topics()
   }
 
-  pub(crate) fn get_dds_cache(&self) -> Arc<RwLock<DDSCache>> {
-    return self.dpi.lock().unwrap().get_dds_cache();
+  pub(crate) fn dds_cache(&self) -> Arc<RwLock<DDSCache>> {
+    return self.dpi.lock().unwrap().dds_cache();
   }
 
   pub(crate) fn discovery_db(&self) -> Arc<RwLock<DiscoveryDB>> {
@@ -477,7 +476,7 @@ impl DomainParticipantDisc {
     // the discovery command mutates a field which is only read
     // by writers with that particular QoS.
     self
-      .discovery_command_channel
+      .discovery_command_sender
       .send(DiscoveryCommand::ManualAssertLiveliness)
       .or_else(|e| {
         log_and_err_internal!("assert_liveness - Failed to send DiscoveryCommand. {:?}", e)
@@ -489,7 +488,7 @@ impl Drop for DomainParticipantDisc {
   fn drop(&mut self) {
     debug!("Sending Discovery Stop signal.");
     match self
-      .discovery_command_channel
+      .discovery_command_sender
       .send(DiscoveryCommand::StopDiscovery)
     {
       Ok(_) => (),
@@ -533,16 +532,16 @@ pub(crate) struct DomainParticipantInner {
 
   dds_cache: Arc<RwLock<DDSCache>>,
   discovery_db: Arc<RwLock<DiscoveryDB>>,
+  discovery_db_event_receiver: mio_channel::Receiver<()>,
 }
 
 impl Drop for DomainParticipantInner {
   fn drop(&mut self) {
     // if send has an error simply leave as we have lost control of the
     // ev_loop_thread anyways
-    match self.stop_poll_sender.send(()) {
-      Ok(_) => (),
-      _ => return (),
-    };
+    if self.stop_poll_sender.send(()).is_err() {
+      return;
+    }
 
     debug!("Waiting for dp_event_loop join");
     match self.ev_loop_handle.take() {
@@ -564,13 +563,14 @@ impl DomainParticipantInner {
   fn new(
     domain_id: u16,
     discovery_update_notification_receiver: mio_channel::Receiver<DiscoveryNotificationType>,
+    spdp_liveness_sender: mio_channel::SyncSender<GuidPrefix>,
   ) -> Result<DomainParticipantInner> {
     let mut listeners = HashMap::new();
 
     match UDPListener::new_multicast(
       DISCOVERY_SENDER_TOKEN,
       "0.0.0.0",
-      get_spdp_well_known_multicast_port(domain_id),
+      spdp_well_known_multicast_port(domain_id),
       Ipv4Addr::new(239, 255, 0, 1),
     ) {
       Ok(l) => {
@@ -583,12 +583,13 @@ impl DomainParticipantInner {
 
     let mut discovery_listener = None;
 
-    // Magic value 120 below is from RTPS spec Section "9.6.1.3 Default Port Numbers"
+    // Magic value 120 below is from RTPS spec Section "9.6.1.3 Default Port
+    // Numbers"
     while discovery_listener.is_none() && participant_id < 120 {
       discovery_listener = UDPListener::new_unicast(
         DISCOVERY_SENDER_TOKEN,
         "0.0.0.0",
-        get_spdp_well_known_unicast_port(domain_id, participant_id),
+        spdp_well_known_unicast_port(domain_id, participant_id),
       )
       .ok();
       if discovery_listener.is_none() {
@@ -610,7 +611,7 @@ impl DomainParticipantInner {
     match UDPListener::new_multicast(
       USER_TRAFFIC_SENDER_TOKEN,
       "0.0.0.0",
-      get_user_traffic_multicast_port(domain_id),
+      user_traffic_multicast_port(domain_id),
       Ipv4Addr::new(239, 255, 0, 1),
     ) {
       Ok(l) => {
@@ -622,7 +623,7 @@ impl DomainParticipantInner {
     let user_traffic_listener = UDPListener::new_unicast(
       USER_TRAFFIC_SENDER_TOKEN,
       "0.0.0.0",
-      get_user_traffic_unicast_port(domain_id, participant_id),
+      user_traffic_unicast_port(domain_id, participant_id),
     );
     let user_traffic_listener = match user_traffic_listener {
       Ok(l) => l,
@@ -649,7 +650,12 @@ impl DomainParticipantInner {
 
     let dds_cache = Arc::new(RwLock::new(DDSCache::new()));
 
-    let discovery_db = Arc::new(RwLock::new(DiscoveryDB::new(new_guid)));
+    let (discovery_db_event_sender, discovery_db_event_receiver) =
+      mio_channel::sync_channel::<()>(1);
+    let discovery_db = Arc::new(RwLock::new(DiscoveryDB::new(
+      new_guid,
+      Some(discovery_db_event_sender),
+    )));
 
     let (stop_poll_sender, stop_poll_receiver) = mio_channel::channel::<()>();
 
@@ -683,6 +689,7 @@ impl DomainParticipantInner {
           },
           stop_poll_receiver,
           discovery_update_notification_receiver,
+          spdp_liveness_sender,
         );
         dp_event_loop.event_loop()
       })?;
@@ -707,10 +714,11 @@ impl DomainParticipantInner {
       remove_writer_sender,
       dds_cache,
       discovery_db,
+      discovery_db_event_receiver,
     })
   }
 
-  pub fn get_dds_cache(&self) -> Arc<RwLock<DDSCache>> {
+  pub fn dds_cache(&self) -> Arc<RwLock<DDSCache>> {
     self.dds_cache.clone()
   }
 
@@ -776,9 +784,9 @@ impl DomainParticipantInner {
   ) -> Result<Topic> {
     let topic = Topic::new(
       domain_participant_weak,
-      name.to_string(),
+      name,
       TypeDesc::new(type_desc),
-      &qos,
+      qos,
       topic_kind,
     );
     Ok(topic)
@@ -794,14 +802,37 @@ impl DomainParticipantInner {
     name: &str,
     timeout: Duration,
   ) -> Result<Option<Topic>> {
-    match self.find_topic_in_discovery_db(domain_participant_weak, name)? {
-      Some(topic) => return Ok(Some(topic)),
-      None => (),
+    let poll = mio::Poll::new()?;
+    let mut events = mio::Events::with_capacity(1);
+    // Should be register before the check and use level trigger to avoid missing
+    // event
+    poll.register(
+      &self.discovery_db_event_receiver,
+      mio::Token(0),
+      mio::Ready::readable(),
+      mio::PollOpt::level(),
+    )?;
+
+    let find_end = Instant::now() + timeout;
+    loop {
+      if let Some(topic) = self.find_topic_in_discovery_db(domain_participant_weak, name)? {
+        return Ok(Some(topic));
+      }
+      let timeout = find_end - Instant::now();
+      poll.poll(&mut events, Some(timeout))?;
+
+      if let Some(_event) = events.iter().next() {
+        if self.discovery_db_event_receiver.try_recv().is_ok() {
+          continue;
+        }
+      }
+
+      if Instant::now() > find_end {
+        break;
+      }
     }
 
-    std::thread::sleep(timeout);
-
-    self.find_topic_in_discovery_db(domain_participant_weak, name)
+    Ok(None)
   }
 
   fn find_topic_in_discovery_db(
@@ -814,22 +845,22 @@ impl DomainParticipantInner {
       Err(_) => return Err(Error::LockPoisoned),
     };
 
-    let maybe_discovered_topic = db.get_all_topics().find(|&d| d.get_topic_name() == name);
-    match maybe_discovered_topic {
-      Some(d) => {
-        // build a Topic from DiscoveredTopicData
-        let qos = d.topic_data.get_qos();
-        let topic_kind = match d.topic_data.key {
-          Some(_) => TopicKind::WithKey,
-          None => TopicKind::NoKey,
-        };
-        let name = d.get_topic_name().clone();
-        let type_desc = d.topic_data.type_name.clone();
-        let topic =
-          self.create_topic(domain_participant_weak, name, type_desc, &qos, topic_kind)?;
-        Ok(Some(topic))
-      }
-      None => Ok(None),
+    let build_topic_fn = |d: &DiscoveredTopicData| {
+      let qos = d.topic_data.qos();
+      let topic_kind = match d.topic_data.key {
+        Some(_) => TopicKind::WithKey,
+        None => TopicKind::NoKey,
+      };
+      let name = d.topic_name().clone();
+      let type_desc = d.topic_data.type_name.clone();
+      self.create_topic(domain_participant_weak, name, type_desc, &qos, topic_kind)
+    };
+
+    if let Some(d) = db.get_topic(name) {
+      // build a Topic from DiscoveredTopicData
+      build_topic_fn(d).map(Some)
+    } else {
+      Ok(None)
     }
   }
   // get_builtin_subscriber (why would we need this?)
@@ -866,30 +897,30 @@ impl DomainParticipantInner {
     self.participant_id
   }
 
-  pub fn get_discovered_topics(&self) -> Vec<DiscoveredTopicData> {
+  pub fn discovered_topics(&self) -> Vec<DiscoveredTopicData> {
     let db = match self.discovery_db.read() {
       Ok(db) => db,
       Err(e) => panic!("DiscoveryDB is poisoned. {:?}", e),
     };
 
-    db.get_all_topics().map(|p| p.clone()).collect()
+    db.all_topics().cloned().collect()
   }
 } // impl
 
 impl RTPSEntity for DomainParticipant {
-  fn get_guid(&self) -> GUID {
-    self.dpi.lock().unwrap().get_guid()
+  fn guid(&self) -> GUID {
+    self.dpi.lock().unwrap().guid()
   }
 }
 
 impl RTPSEntity for DomainParticipantDisc {
-  fn get_guid(&self) -> GUID {
-    self.dpi.lock().unwrap().get_guid()
+  fn guid(&self) -> GUID {
+    self.dpi.lock().unwrap().guid()
   }
 }
 
 impl RTPSEntity for DomainParticipantInner {
-  fn get_guid(&self) -> GUID {
+  fn guid(&self) -> GUID {
     self.my_guid
   }
 }
@@ -897,42 +928,43 @@ impl RTPSEntity for DomainParticipantInner {
 impl std::fmt::Debug for DomainParticipant {
   fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
     f.debug_struct("DomainParticipant")
-      .field("Guid", &self.get_guid())
+      .field("Guid", &self.guid())
       .finish()
   }
 }
 
 #[cfg(test)]
 mod tests {
-  use std::{collections::BTreeSet, net::SocketAddr};
+  use std::{
+    collections::BTreeSet,
+    net::{Ipv4Addr, SocketAddr, SocketAddrV4},
+  };
+
   use enumflags2::BitFlags;
   use log::info;
-  use crate::dds::topic::TopicKind;
+  use speedy::{Endianness, Writable};
+  use byteorder::LittleEndian;
+
   use crate::{
-    dds::qos::QosPolicies,
-    network::{udp_sender::UDPSender, constant::get_user_traffic_unicast_port},
-    test::random_data::RandomData,
+    dds::{qos::QosPolicies, topic::TopicKind},
+    messages::{
+      header::Header,
+      protocol_id::ProtocolId,
+      protocol_version::ProtocolVersion,
+      submessages::submessages::{AckNack, EntitySubmessage, SubmessageHeader, SubmessageKind, *},
+      vendor_id::VendorId,
+    },
+    network::{constant::user_traffic_unicast_port, udp_sender::UDPSender},
+    serialization::{cdr_serializer::CDRSerializerAdapter, submessage::*, Message, SubMessage},
     structure::{
-      locator::{LocatorKind, Locator},
       guid::{EntityId, GUID},
+      locator::Locator,
       sequence_number::{SequenceNumber, SequenceNumberSet},
     },
-    messages::submessages::submessages::{
-      EntitySubmessage, AckNack, SubmessageHeader, SubmessageKind,
-    },
-    serialization::{SubMessage, Message, submessage::*},
-    messages::{
-      protocol_version::ProtocolVersion, header::Header, vendor_id::VendorId,
-      protocol_id::ProtocolId, submessages::submessages::*,
-    },
+    test::random_data::RandomData,
   };
   use super::DomainParticipant;
 
-  use speedy::{Endianness, Writable};
-
-  use crate::serialization::cdr_serializer::CDRSerializerAdapter;
-  use byteorder::LittleEndian;
-
   // TODO: improve basic test when more or the structure is known
   #[test]
   fn dp_basic_domain_participant() {
@@ -952,14 +984,14 @@ mod tests {
     let qos = QosPolicies::qos_none();
     let _default_dw_qos = QosPolicies::qos_none();
     let publisher = domain_participant
-      .create_publisher(&qos.clone())
+      .create_publisher(&qos)
       .expect("Failed to create publisher");
 
     let topic = domain_participant
       .create_topic(
         "Aasii".to_string(),
         "RandomData".to_string(),
-        &qos.clone(),
+        &qos,
         TopicKind::WithKey,
       )
       .expect("Failed to create topic");
@@ -970,7 +1002,7 @@ mod tests {
   }
 
   #[test]
-  fn dp_recieve_acknack_message_test() {
+  fn dp_receive_acknack_message_test() {
     // TODO SEND ACKNACK
     let domain_participant = DomainParticipant::new(0).expect("Failed to create participant");
 
@@ -978,14 +1010,14 @@ mod tests {
     let _default_dw_qos = QosPolicies::qos_none();
 
     let publisher = domain_participant
-      .create_publisher(&qos.clone())
+      .create_publisher(&qos)
       .expect("Failed to create publisher");
 
     let topic = domain_participant
       .create_topic(
         "Aasii".to_string(),
         "Huh?".to_string(),
-        &qos.clone(),
+        &qos,
         TopicKind::WithKey,
       )
       .expect("Failed to create topic");
@@ -994,13 +1026,13 @@ mod tests {
       .create_datawriter::<RandomData, CDRSerializerAdapter<RandomData, LittleEndian>>(topic, None)
       .expect("Failed to create datawriter");
 
-    let port_number: u16 = get_user_traffic_unicast_port(5, 0);
+    let port_number: u16 = user_traffic_unicast_port(5, 0);
     let sender = UDPSender::new(1234).unwrap();
     let mut m: Message = Message::default();
 
     let a: AckNack = AckNack {
-      reader_id: EntityId::ENTITYID_SPDP_BUILTIN_PARTICIPANT_READER,
-      writer_id: EntityId::ENTITYID_SPDP_BUILTIN_PARTICIPANT_WRITER,
+      reader_id: EntityId::SPDP_BUILTIN_PARTICIPANT_READER,
+      writer_id: EntityId::SPDP_BUILTIN_PARTICIPANT_WRITER,
       reader_sn_state: SequenceNumberSet::from_base_and_set(
         SequenceNumber::default(),
         &BTreeSet::new(),
@@ -1008,14 +1040,14 @@ mod tests {
       count: 1,
     };
     let flags = BitFlags::<ACKNACK_Flags>::from_endianness(Endianness::BigEndian);
-    let subHeader: SubmessageHeader = SubmessageHeader {
+    let sub_header: SubmessageHeader = SubmessageHeader {
       kind: SubmessageKind::ACKNACK,
       flags: flags.bits(),
       content_length: 24,
     };
 
     let s: SubMessage = SubMessage {
-      header: subHeader,
+      header: sub_header,
       body: SubmessageBody::Entity(EntitySubmessage::AckNack(a, flags)),
     };
     let h = Header {
@@ -1025,20 +1057,12 @@ mod tests {
       guid_prefix: GUID::default().guid_prefix,
     };
     m.set_header(h);
-    m.add_submessage(SubMessage::from(s));
+    m.add_submessage(s);
     let _data: Vec<u8> = m.write_to_vec_with_ctx(Endianness::LittleEndian).unwrap();
     info!("data to send via udp: {:?}", _data);
-    let loca = Locator {
-      kind: LocatorKind::LOCATOR_KIND_UDP_V4,
-      port: port_number as u32,
-      address: [
-        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
-        0x00,
-      ],
-      /* address: [0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x7F,
-       * 0x00, 0x00, 0x01], */
-    };
-    let locas = vec![loca];
-    sender.send_to_locator_list(&_data, &locas);
+    let ip = Ipv4Addr::from([0x00, 0x00, 0x00, 0x00]);
+    let socket_address = SocketAddrV4::new(ip, port_number);
+    let locators = vec![Locator::UdpV4(socket_address)];
+    sender.send_to_locator_list(&_data, &locators);
   }
 }
