@@ -1,52 +1,50 @@
-use mio_extras::channel as mio_channel;
-use log::error;
-
 use std::{
   fmt::Debug,
-  sync::{RwLock, Arc},
+  sync::{Arc, RwLock},
   time::Duration,
 };
 
-use serde::{Serialize, de::DeserializeOwned};
-
-use byteorder::{LittleEndian};
-
-use crate::{
-  discovery::discovery::DiscoveryCommand,
-  log_and_err_precondition_not_met,
-  structure::{guid::GUID, entity::RTPSEntity, guid::EntityId},
-};
-
-use crate::dds::{
-  values::result::*,
-  data_types::EntityKind,
-  participant::*,
-  topic::*,
-  qos::*,
-  reader::ReaderIngredients,
-  writer::WriterIngredients,
-  with_key::datawriter::DataWriter as WithKeyDataWriter,
-  no_key::datawriter::DataWriter as NoKeyDataWriter,
-  with_key::datareader::DataReader as WithKeyDataReader,
-  no_key::datareader::DataReader as NoKeyDataReader,
-  traits::key::{Keyed, Key},
-  traits::serde_adapters::*,
-};
-use crate::dds::statusevents::*;
-
-use crate::{
-  discovery::{discovery_db::DiscoveryDB, data_types::topic_data::DiscoveredWriterData},
-  structure::topic_kind::TopicKind,
-  serialization::cdr_serializer::{CDRSerializerAdapter},
-  serialization::cdr_deserializer::{CDRDeserializerAdapter},
-};
-
+use mio_extras::channel as mio_channel;
+use serde::{de::DeserializeOwned, Serialize};
+use byteorder::LittleEndian;
 use rand::Rng;
-use crate::log_and_err_internal;
 
+use crate::{
+  dds::{
+    data_types::EntityKind,
+    no_key::{
+      datareader::DataReader as NoKeyDataReader, datawriter::DataWriter as NoKeyDataWriter,
+    },
+    participant::*,
+    qos::*,
+    reader::ReaderIngredients,
+    statusevents::*,
+    topic::*,
+    traits::{
+      key::{Key, Keyed},
+      serde_adapters::*,
+    },
+    values::result::*,
+    with_key::{
+      datareader::DataReader as WithKeyDataReader, datawriter::DataWriter as WithKeyDataWriter,
+    },
+    writer::WriterIngredients,
+  },
+  discovery::{
+    data_types::topic_data::DiscoveredWriterData, discovery::DiscoveryCommand,
+    discovery_db::DiscoveryDB,
+  },
+  log_and_err_internal, log_and_err_precondition_not_met,
+  serialization::{cdr_deserializer::CDRDeserializerAdapter, cdr_serializer::CDRSerializerAdapter},
+  structure::{
+    entity::RTPSEntity,
+    guid::{EntityId, GUID},
+    topic_kind::TopicKind,
+  },
+};
 use super::{
+  no_key::wrappers::{DAWrapper, NoKeyWrapper, SAWrapper},
   with_key::datareader::ReaderCommand,
-  no_key::wrappers::{DAWrapper, SAWrapper, NoKeyWrapper},
   writer::WriterCommand,
 };
 
@@ -121,7 +119,7 @@ impl Publisher {
   /// impl Keyed for SomeType {
   ///   type K = i32;
   ///
-  ///   fn get_key(&self) -> Self::K {
+  ///   fn key(&self) -> Self::K {
   ///     self.a
   ///   }
   /// }
@@ -142,7 +140,8 @@ impl Publisher {
     self.inner.create_datawriter(self, None, topic, qos)
   }
 
-  /// Shorthand for crate_datawriter with Commaon Data Representation Little Endian
+  /// Shorthand for crate_datawriter with Commaon Data Representation Little
+  /// Endian
   pub fn create_datawriter_cdr<D>(
     &self,
     topic: Topic,
@@ -271,12 +270,15 @@ impl Publisher {
     )
   }
 
-  // delete_datawriter should not be needed. The DataWriter object itself should be deleted to accomplish this.
+  // delete_datawriter should not be needed. The DataWriter object itself should
+  // be deleted to accomplish this.
 
-  // lookup datawriter: maybe not necessary? App should remember datawriters it has created.
+  // lookup datawriter: maybe not necessary? App should remember datawriters it
+  // has created.
 
   // Suspend and resume publications are preformance optimization methods.
-  // The minimal correct implementation is to do nothing. See DDS spec 2.2.2.4.1.8 and .9
+  // The minimal correct implementation is to do nothing. See DDS spec 2.2.2.4.1.8
+  // and .9
   /// Currently does nothing
   pub fn suspend_publications(&self) -> Result<()> {
     Ok(())
@@ -300,14 +302,16 @@ impl Publisher {
     Ok(())
   }
 
-  // Wait for all matched reliable DataReaders acknowledge data written so far, or timeout.
-  // TODO: implement
+  // Wait for all matched reliable DataReaders acknowledge data written so far, or
+  // timeout. TODO: implement
   pub(crate) fn wait_for_acknowledgments(&self, _max_wait: Duration) -> Result<()> {
     unimplemented!();
   }
 
-  // What is the use case for this? (is it useful in Rust style of programming? Should it be public?)
-  /// Gets [DomainParticipant](struct.DomainParticipant.html) if it has not disappeared from all scopes.
+  // What is the use case for this? (is it useful in Rust style of programming?
+  // Should it be public?)
+  /// Gets [DomainParticipant](struct.DomainParticipant.html) if it has not
+  /// disappeared from all scopes.
   ///
   /// # Example
   ///
@@ -320,13 +324,14 @@ impl Publisher {
   /// let qos = QosPolicyBuilder::new().build();
   ///
   /// let publisher = domain_participant.create_publisher(&qos).unwrap();
-  /// assert_eq!(domain_participant, publisher.get_participant().unwrap());
+  /// assert_eq!(domain_participant, publisher.participant().unwrap());
   /// ```
-  pub fn get_participant(&self) -> Option<DomainParticipant> {
+  pub fn participant(&self) -> Option<DomainParticipant> {
     self.inner.domain_participant.clone().upgrade()
   }
 
-  // delete_contained_entities: We should not need this. Contained DataWriters should dispose themselves and notify publisher.
+  // delete_contained_entities: We should not need this. Contained DataWriters
+  // should dispose themselves and notify publisher.
 
   /// Returns default DataWriter qos. Currently default qos is not used.
   ///
@@ -360,7 +365,8 @@ impl Publisher {
   // / let qos = QosPolicyBuilder::new().build();
   // /
   // / let mut publisher = domain_participant.create_publisher(&qos).unwrap();
-  // / let qos2 = QosPolicyBuilder::new().durability(Durability::Transient).build();
+  // / let qos2 =
+  // QosPolicyBuilder::new().durability(Durability::Transient).build();
   // / publisher.set_default_datawriter_qos(&qos2);
   // /
   // / assert_ne!(qos, *publisher.get_default_datawriter_qos());
@@ -438,25 +444,26 @@ impl InnerPublisher {
     // QoS, modify it to match any QoS settings (that are set) in the
     // Topic QoS and use that.
 
-    // Use Publisher QoS as basis, modify by Topic settings, and modify by specified QoS.
+    // Use Publisher QoS as basis, modify by Topic settings, and modify by specified
+    // QoS.
     let writer_qos = self
       .default_datawriter_qos
-      .modify_by(&topic.get_qos())
+      .modify_by(&topic.qos())
       .modify_by(&optional_qos.unwrap_or_else(QosPolicies::qos_none));
 
     let entity_id =
       unwrap_or_random_entity_id(entity_id_opt, EntityKind::WRITER_WITH_KEY_USER_DEFINED);
     let dp = self
-      .get_participant()
+      .participant()
       .ok_or("upgrade fail")
       .or_else(|e| log_and_err_internal!("Where is my DomainParticipant? {}", e))?;
 
-    let guid = GUID::new_with_prefix_and_id(dp.get_guid().guid_prefix, entity_id);
+    let guid = GUID::new_with_prefix_and_id(dp.guid().guid_prefix, entity_id);
 
     let new_writer = WriterIngredients {
       guid,
       writer_command_receiver: hccc_download,
-      topic_name: topic.get_name(),
+      topic_name: topic.name(),
       qos_policies: writer_qos,
       status_sender,
     };
@@ -472,7 +479,7 @@ impl InnerPublisher {
       Some(guid),
       dwcc_upload,
       self.discovery_command.clone(),
-      dp.get_dds_cache(),
+      dp.dds_cache(),
       status_receiver,
     )?;
 
@@ -534,7 +541,7 @@ impl InnerPublisher {
     unimplemented!();
   }
 
-  pub fn get_participant(&self) -> Option<DomainParticipant> {
+  pub fn participant(&self) -> Option<DomainParticipant> {
     self.domain_participant.clone().upgrade()
   }
 
@@ -549,7 +556,7 @@ impl InnerPublisher {
 
 impl PartialEq for InnerPublisher {
   fn eq(&self, other: &Self) -> bool {
-    self.get_participant() == other.get_participant()
+    self.participant() == other.participant()
       && self.my_qos_policies == other.my_qos_policies
       && self.default_datawriter_qos == other.default_datawriter_qos
     // TODO: publisher is DDSEntity?
@@ -558,7 +565,7 @@ impl PartialEq for InnerPublisher {
 
 impl Debug for InnerPublisher {
   fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
-    f.write_fmt(format_args!("{:?}", self.get_participant()))?;
+    f.write_fmt(format_args!("{:?}", self.participant()))?;
     f.write_fmt(format_args!("Publisher QoS: {:?}", self.my_qos_policies))?;
     f.write_fmt(format_args!(
       "Publishers default Writer QoS: {:?}",
@@ -622,8 +629,10 @@ impl Subscriber {
   ///
   /// # Arguments
   ///
-  /// * `topic` - Reference to the DDS [Topic](struct.Topic.html) this reader reads from
-  /// * `entity_id` - Optional [EntityId](data_types/struct.EntityId.html) if necessary for DDS communication (random if None)
+  /// * `topic` - Reference to the DDS [Topic](struct.Topic.html) this reader
+  ///   reads from
+  /// * `entity_id` - Optional [EntityId](data_types/struct.EntityId.html) if
+  ///   necessary for DDS communication (random if None)
   /// * `qos` - Not in use
   ///
   /// # Examples
@@ -648,7 +657,7 @@ impl Subscriber {
   /// impl Keyed for SomeType {
   ///   type K = i32;
   ///
-  ///   fn get_key(&self) -> Self::K {
+  ///   fn key(&self) -> Self::K {
   ///     self.a
   ///   }
   /// }
@@ -716,9 +725,11 @@ impl Subscriber {
   ///
   /// # Arguments
   ///
-  /// * `topic` - Reference to the DDS [Topic](struct.Topic.html) this reader reads from
-  /// * `entity_id` - Optional [EntityId](data_types/struct.EntityId.html) if necessary for DDS communication (random if None)
-  /// * `qos` - Not in use  
+  /// * `topic` - Reference to the DDS [Topic](struct.Topic.html) this reader
+  ///   reads from
+  /// * `entity_id` - Optional [EntityId](data_types/struct.EntityId.html) if
+  ///   necessary for DDS communication (random if None)
+  /// * `qos` - Not in use
   ///
   /// # Examples
   ///
@@ -794,7 +805,8 @@ impl Subscriber {
   }
 
   // Retrieves a previously created DataReader belonging to the Subscriber.
-  // TODO: Is this even possible. Whould probably need to return reference and store references on creation
+  // TODO: Is this even possible. Whould probably need to return reference and
+  // store references on creation
   /*
   pub(crate) fn lookup_datareader<D, SA>(
     &self,
@@ -810,7 +822,8 @@ impl Subscriber {
   }
   */
 
-  /// Returns [DomainParticipant](struct.DomainParticipant.html) if it is sill alive.
+  /// Returns [DomainParticipant](struct.DomainParticipant.html) if it is sill
+  /// alive.
   ///
   /// # Example
   ///
@@ -823,10 +836,10 @@ impl Subscriber {
   /// let qos = QosPolicyBuilder::new().build();
   ///
   /// let subscriber = domain_participant.create_subscriber(&qos).unwrap();
-  /// assert_eq!(domain_participant, subscriber.get_participant().unwrap());
+  /// assert_eq!(domain_participant, subscriber.participant().unwrap());
   /// ```
-  pub fn get_participant(&self) -> Option<DomainParticipant> {
-    self.inner.get_participant()
+  pub fn participant(&self) -> Option<DomainParticipant> {
+    self.inner.participant()
   }
 }
 
@@ -859,7 +872,7 @@ impl InnerSubscriber {
     }
   }
 
-  /*pub(super)*/
+  /* pub(super) */
   fn create_datareader_internal<D: 'static, SA>(
     &self,
     outer: &Subscriber,
@@ -880,10 +893,11 @@ impl InnerSubscriber {
     let (reader_command_sender, reader_command_receiver) =
       mio_channel::sync_channel::<ReaderCommand>(4);
 
-    // Use subscriber QoS as basis, modify by Topic settings, and modify by specified QoS.
+    // Use subscriber QoS as basis, modify by Topic settings, and modify by
+    // specified QoS.
     let qos = self
       .qos
-      .modify_by(&topic.get_qos())
+      .modify_by(&topic.qos())
       .modify_by(&optional_qos.unwrap_or_else(QosPolicies::qos_none));
 
     let entity_id =
@@ -892,18 +906,18 @@ impl InnerSubscriber {
     let reader_id = entity_id;
     let datareader_id = entity_id;
 
-    let dp = match self.get_participant() {
+    let dp = match self.participant() {
       Some(dp) => dp,
       None => return log_and_err_precondition_not_met!("DomainParticipant doesn't exist anymore."),
     };
 
-    let reader_guid = GUID::new_with_prefix_and_id(dp.get_guid_prefix(), reader_id);
+    let reader_guid = GUID::new_with_prefix_and_id(dp.guid_prefix(), reader_id);
 
     let new_reader = ReaderIngredients {
       guid: reader_guid,
       notification_sender: send,
       status_sender,
-      topic_name: topic.get_name(),
+      topic_name: topic.name(),
       qos_policy: qos.clone(),
       data_reader_command_receiver: reader_command_receiver,
     };
@@ -923,16 +937,16 @@ impl InnerSubscriber {
       topic.clone(),
       qos,
       rec,
-      dp.get_dds_cache(),
+      dp.dds_cache(),
       self.discovery_command.clone(),
       status_receiver,
       reader_command_sender,
     )?;
 
     // Create new topic to DDScache if one isn't present
-    match dp.get_dds_cache().write() {
+    match dp.dds_cache().write() {
       Ok(mut dds_cache) => {
-        dds_cache.add_new_topic(topic.get_name(), topic.kind(), topic.get_type());
+        dds_cache.add_new_topic(topic.name(), topic.kind(), topic.get_type());
       }
       Err(e) => return log_and_err_internal!("Cannot lock DDScache. Error: {}", e),
     }
@@ -996,7 +1010,7 @@ impl InnerSubscriber {
     Ok(NoKeyDataReader::<D, SA>::from_keyed(d))
   }
 
-  pub fn get_participant(&self) -> Option<DomainParticipant> {
+  pub fn participant(&self) -> Option<DomainParticipant> {
     self.domain_participant.clone().upgrade()
   }
 }
