@@ -1,55 +1,47 @@
-use crate::{
-  //common::timed_event_handler::TimedEventHandler,
-  //network::constant::TimerMessageType,
-  structure::{cache_change::ChangeKind, entity::RTPSEntity},
-};
-use crate::structure::endpoint::{Endpoint, EndpointAttributes};
-use crate::messages::submessages::submessages::*;
-
-use crate::dds::ddsdata::DDSData;
-use crate::dds::statusevents::*;
-use crate::dds::rtps_writer_proxy::RtpsWriterProxy;
-use crate::structure::guid::{GUID, EntityId, GuidPrefix};
-use crate::structure::sequence_number::{SequenceNumber, SequenceNumberSet};
-#[cfg(test)]
-use crate::structure::locator::LocatorList;
-use crate::structure::{duration::Duration, time::Timestamp};
-
 use std::{
-  collections::BTreeSet,
+  collections::{BTreeMap, BTreeSet},
+  fmt,
   iter::FromIterator,
-  sync::{Arc, RwLock},
   rc::Rc,
+  sync::{Arc, RwLock},
+  time::Duration as StdDuration,
 };
-use crate::structure::dds_cache::{DDSCache};
 
 use mio::Token;
-use mio_extras::timer::Timer;
-use mio_extras::channel as mio_channel;
-use log::{debug, info, warn, trace, error};
-use std::fmt;
-
-use std::collections::{BTreeMap};
-use std::time::Duration as StdDuration;
+use mio_extras::{channel as mio_channel, timer::Timer};
+use log::{debug, error, info, trace, warn};
 use enumflags2::BitFlags;
+use speedy::{Endianness, Writable};
 
-use crate::structure::cache_change::CacheChange;
-use crate::dds::message_receiver::MessageReceiverState;
-use crate::dds::qos::{QosPolicies, HasQoSPolicy, policy};
-use crate::network::udp_sender::UDPSender;
-
-use crate::serialization::message::Message;
-use crate::messages::header::Header;
-use crate::messages::protocol_id::ProtocolId;
-use crate::messages::protocol_version::ProtocolVersion;
-use crate::messages::vendor_id::VendorId;
-use crate::messages::submessages::submessage_elements::parameter_list::ParameterList;
-
-use speedy::{Writable, Endianness};
-
-use super::{with_key::datareader::ReaderCommand};
-
-use super::qos::InlineQos;
+use crate::{
+  dds::{
+    ddsdata::DDSData,
+    message_receiver::MessageReceiverState,
+    qos::{policy, HasQoSPolicy, QosPolicies},
+    rtps_writer_proxy::RtpsWriterProxy,
+    statusevents::*,
+  },
+  messages::{
+    header::Header,
+    protocol_id::ProtocolId,
+    protocol_version::ProtocolVersion,
+    submessages::{submessage_elements::parameter_list::ParameterList, submessages::*},
+    vendor_id::VendorId,
+  },
+  network::udp_sender::UDPSender,
+  serialization::message::Message,
+  structure::{
+    cache_change::{CacheChange, ChangeKind},
+    dds_cache::DDSCache,
+    duration::Duration,
+    entity::RTPSEntity,
+    guid::{EntityId, GuidPrefix, GUID},
+    locator::Locator,
+    sequence_number::{SequenceNumber, SequenceNumberSet},
+    time::Timestamp,
+  },
+};
+use super::{qos::InlineQos, with_key::datareader::ReaderCommand};
 
 #[derive(Clone, Copy, Debug, PartialEq, Eq)]
 pub(crate) enum TimedEvent {
@@ -95,7 +87,6 @@ pub(crate) struct Reader {
   qos_policy: QosPolicies,
 
   my_guid: GUID,
-  pub enpoint_attributes: EndpointAttributes,
 
   heartbeat_response_delay: StdDuration,
   heartbeat_supression_duration: StdDuration,
@@ -132,7 +123,6 @@ impl Reader {
       #[cfg(test)]
       seqnum_instant_map: BTreeMap::new(),
       my_guid: i.guid,
-      enpoint_attributes: EndpointAttributes::default(),
 
       heartbeat_response_delay: StdDuration::new(0, 500_000_000), // 0,5sec
       heartbeat_supression_duration: StdDuration::new(0, 0),
@@ -149,14 +139,14 @@ impl Reader {
   // TODO: check if it's necessary to implement different handlers for discovery
   // and user messages
 
-
-  /// To know when token represents a reader we should look entity attribute kind
-  pub fn get_entity_token(&self) -> Token {
-    self.get_guid().entity_id.as_token()
+  /// To know when token represents a reader we should look entity attribute
+  /// kind
+  pub fn entity_token(&self) -> Token {
+    self.guid().entity_id.as_token()
   }
 
-  pub fn get_reader_alt_entity_token(&self) -> Token {
-    self.get_guid().entity_id.as_alt_token()
+  pub fn reader_alt_entity_token(&self) -> Token {
+    self.guid().entity_id.as_alt_token()
   }
 
   pub fn set_requested_deadline_check_timer(&mut self) {
@@ -186,9 +176,9 @@ impl Reader {
         // no-one is required to be listening to these.
       }
       Err(mio_channel::TrySendError::Disconnected(_)) => {
-        // If we get here, our DataReader has died. The Reader should now dispose itself.
-        // Or possibly it has lost the receiver object, which is sort of sloppy,
-        // but does not necessarily mean the end of the world.
+        // If we get here, our DataReader has died. The Reader should now dispose
+        // itself. Or possibly it has lost the receiver object, which is sort of
+        // sloppy, but does not necessarily mean the end of the world.
         // TODO: Implement Reader disposal.
         info!("send_status_change - cannot send status, DataReader Disconnected.")
       }
@@ -215,7 +205,8 @@ impl Reader {
           match writer_proxy.last_change_timestamp() {
             Some(last_change) => {
               let since_last = now.duration_since(last_change);
-              // if time singe last received message is greater than deadline increase status and return notification.
+              // if time singe last received message is greater than deadline increase status
+              // and return notification.
               trace!(
                 "Comparing deadlines: {:?} - {:?}",
                 since_last,
@@ -233,7 +224,7 @@ impl Reader {
               }
             }
             None => {
-              // no messages recieved ever so deadline must be missed.
+              // no messages received ever so deadline must be missed.
               // TODO: But what if the Reader or WriterProxy was just created?
               self.requested_deadline_missed_count += 1;
               changes.push(DataReaderStatus::RequestedDeadlineMissed {
@@ -290,10 +281,12 @@ impl Reader {
 
   // TODO Used for test/debugging purposes
   #[cfg(test)]
-  pub fn get_history_cache_change_data(&self, sequence_number: SequenceNumber) -> Option<DDSData> {
+  pub fn history_cache_change_data(&self, sequence_number: SequenceNumber) -> Option<DDSData> {
     let dds_cache = self.dds_cache.read().unwrap();
-    let cc = self.seqnum_instant_map.get(&sequence_number)
-      .map( |i| dds_cache.from_topic_get_change(&self.topic_name, i,))
+    let cc = self
+      .seqnum_instant_map
+      .get(&sequence_number)
+      .map(|i| dds_cache.from_topic_get_change(&self.topic_name, i))
       .flatten();
 
     debug!("history cache !!!! {:?}", cc);
@@ -303,11 +296,13 @@ impl Reader {
 
   // Used for test/debugging purposes
   #[cfg(test)]
-  pub fn get_history_cache_change(&self, sequence_number: SequenceNumber) -> Option<CacheChange> {
+  pub fn history_cache_change(&self, sequence_number: SequenceNumber) -> Option<CacheChange> {
     debug!("{:?}", sequence_number);
     let dds_cache = self.dds_cache.read().unwrap();
-    let cc = self.seqnum_instant_map.get(&sequence_number)
-      .map( |i| dds_cache.from_topic_get_change(&self.topic_name, i,))
+    let cc = self
+      .seqnum_instant_map
+      .get(&sequence_number)
+      .map(|i| dds_cache.from_topic_get_change(&self.topic_name, i))
       .flatten();
     debug!("history cache !!!! {:?}", cc);
     cc.cloned()
@@ -315,7 +310,7 @@ impl Reader {
 
   // TODO Used for test/debugging purposes
   #[cfg(test)]
-  pub fn get_history_cache_sequence_start_and_end_numbers(&self) -> Vec<SequenceNumber> {
+  pub fn history_cache_sequence_start_and_end_numbers(&self) -> Vec<SequenceNumber> {
     let start = self.seqnum_instant_map.iter().min().unwrap().0;
     let end = self.seqnum_instant_map.iter().max().unwrap().0;
     return vec![*start, *end];
@@ -403,8 +398,8 @@ impl Reader {
     &mut self,
     remote_writer_guid: GUID,
     remote_group_entity_id: EntityId,
-    unicast_locator_list: LocatorList,
-    multicast_locator_list: LocatorList,
+    unicast_locator_list: Vec<Locator>,
+    multicast_locator_list: Vec<Locator>,
   ) {
     let proxy = RtpsWriterProxy::new(
       remote_writer_guid,
@@ -435,7 +430,7 @@ impl Reader {
     };
 
     // checking lifespan for silent dropping of message
-    if let Some(ls) = self.get_qos().lifespan {
+    if let Some(ls) = self.qos().lifespan {
       if ls.duration < duration {
         return;
       }
@@ -467,8 +462,7 @@ impl Reader {
     let receive_timestamp = Timestamp::now();
 
     // check if this submessage is expired already
-    if let (Some(source_timestamp), Some(lifespan)) = (mr_state.timestamp, self.get_qos().lifespan)
-    {
+    if let (Some(source_timestamp), Some(lifespan)) = (mr_state.timestamp, self.qos().lifespan) {
       let elapsed = receive_timestamp.duration_since(source_timestamp);
       if lifespan.duration < elapsed {
         info!(
@@ -481,7 +475,8 @@ impl Reader {
     let writer_seq_num = datafrag.writer_sn; // for borrow checker
     if let Some(writer_proxy) = self.matched_writer_lookup(writer_guid) {
       if let Some(complete_ddsdata) = writer_proxy.handle_datafrag(datafrag, datafrag_flags) {
-        // Source timestamp (if any) will be the timestamp of the last fragment (that completes the sample).
+        // Source timestamp (if any) will be the timestamp of the last fragment (that
+        // completes the sample).
         self.process_received_data(
           complete_ddsdata,
           receive_timestamp,
@@ -497,7 +492,8 @@ impl Reader {
     }
   }
 
-  // common parts of processing DATA or a completed DATAFRAG (when all frags are received)
+  // common parts of processing DATA or a completed DATAFRAG (when all frags are
+  // received)
   fn process_received_data(
     &mut self,
     ddsdata: DDSData,
@@ -519,10 +515,11 @@ impl Reader {
         if writer_proxy.contains_change(writer_sn) {
           // change already present
           debug!("handle_data_msg already have this seq={:?}", writer_sn);
-          if my_entityid == EntityId::ENTITYID_SPDP_BUILTIN_PARTICIPANT_READER {
+          if my_entityid == EntityId::SPDP_BUILTIN_PARTICIPANT_READER {
             debug!("Accepting duplicate message to participant reader.");
             // This is an attmpted workaround to eProsima FastRTPS not
-            // incrementing sequence numbers. (eProsime shapes demo 2.1.0 from 2021)
+            // incrementing sequence numbers. (eProsime shapes demo 2.1.0 from
+            // 2021)
           } else {
             return;
           }
@@ -583,7 +580,8 @@ impl Reader {
 
       (None, false, false) => {
         // no data, no key. Maybe there is inline QoS?
-        // At least we should find key hash, or we do not know WTF the writer is talking about
+        // At least we should find key hash, or we do not know WTF the writer is talking
+        // about
         let key_hash = match data
           .inline_qos
           .as_ref()
@@ -595,7 +593,8 @@ impl Reader {
           None => {
             info!("Received DATA that has no payload and no key_hash inline QoS - discarding");
             // Note: This case is normal when handling coherent sets.
-            // The coherent set end marker is sent as DATA with no payload and not key, only Inline QoS.
+            // The coherent set end marker is sent as DATA with no payload and not key, only
+            // Inline QoS.
             Err("DATA with no contents".to_string())
           }
         }?;
@@ -690,13 +689,13 @@ impl Reader {
       for instant in removed_instances.values() {
         match cache.from_topic_remove_change(&self.topic_name, instant) {
           Some(_) => (),
-          None => debug!("WriterProxy told to remove an instant which was not present"), // This may be normal?
+          None => debug!("WriterProxy told to remove an instant which was not present"), /* This may be normal? */
         }
       }
     }
 
-    // this is duplicate code from above, but needed, because we need another mutable borrow.
-    // TODO: Maybe could be written in some sensible way.
+    // this is duplicate code from above, but needed, because we need another
+    // mutable borrow. TODO: Maybe could be written in some sensible way.
     let writer_proxy = match self.matched_writer_lookup(writer_guid) {
       Some(wp) => wp,
       None => {
@@ -707,15 +706,16 @@ impl Reader {
 
     // See if ACKNACK is needed, and generate one.
     let missing_seqnums =
-      writer_proxy.get_missing_sequence_numbers(heartbeat.first_sn, heartbeat.last_sn);
+      writer_proxy.missing_sequence_numbers(heartbeat.first_sn, heartbeat.last_sn);
 
     // Interpretation of final flag in RTPS spec
-    // 8.4.2.3.1 Readers must respond eventually after receiving a HEARTBEAT with final flag not set
+    // 8.4.2.3.1 Readers must respond eventually after receiving a HEARTBEAT with
+    // final flag not set
     //
-    // Upon receiving a HEARTBEAT Message with final flag not set, the Reader must respond
-    // with an ACKNACK Message. The ACKNACK Message may acknowledge having received all
-    // the data samples or may indicate that some data samples are missing.
-    // The response may be delayed to avoid message storms.
+    // Upon receiving a HEARTBEAT Message with final flag not set, the Reader must
+    // respond with an ACKNACK Message. The ACKNACK Message may acknowledge
+    // having received all the data samples or may indicate that some data
+    // samples are missing. The response may be delayed to avoid message storms.
 
     if !missing_seqnums.is_empty() || !final_flag_set {
       // report of what we have.
@@ -741,14 +741,12 @@ impl Reader {
       };
 
       let response_ack_nack = AckNack {
-        reader_id: self.get_entity_id(),
+        reader_id: self.entity_id(),
         writer_id: heartbeat.writer_id,
         reader_sn_state,
         count: self.sent_ack_nack_count,
       };
 
-      self.sent_ack_nack_count += 1;
-
       // Sanity check
       if response_ack_nack.reader_sn_state.base() > heartbeat.last_sn + SequenceNumber::new(1) {
         error!(
@@ -759,7 +757,18 @@ impl Reader {
 
       // The acknack can be sent now or later. The rest of the RTPS message
       // needs to be constructed. p. 48
-      self.send_acknack(response_ack_nack, mr_state);
+      let flags = BitFlags::<ACKNACK_Flags>::from_flag(ACKNACK_Flags::Endianness)
+        | BitFlags::<ACKNACK_Flags>::from_flag(ACKNACK_Flags::Final);
+      self.send_acknack_to(
+        flags,
+        response_ack_nack,
+        InfoDestination {
+          guid_prefix: mr_state.source_guid_prefix,
+        },
+        &mr_state.unicast_reply_locator_list,
+      );
+      self.sent_ack_nack_count += 1;
+
       return true;
     }
 
@@ -802,8 +811,8 @@ impl Reader {
 
     // if gap.gap_list.set.len() != 0 {
     //   if i64::from(gap.gap_start) < 1i64
-    //     || (gap.gap_list.set.iter().max().unwrap() - gap.gap_list.set.iter().min().unwrap()) >= 256
-    //   {
+    //     || (gap.gap_list.set.iter().max().unwrap() -
+    // gap.gap_list.set.iter().min().unwrap()) >= 256   {
     //     return;
     //   }
     // } else {
@@ -812,7 +821,8 @@ impl Reader {
 
     // Irrelevant sequence numbers communicated in the Gap message are
     // composed of two groups:
-    //   1. All sequence numbers in the range gapStart <= sequence_number < gapList.base
+    //   1. All sequence numbers in the range gapStart <= sequence_number <
+    // gapList.base
     let mut removed_changes: BTreeSet<Timestamp> = writer_proxy
       .irrelevant_changes_range(gap.gap_start, gap.gap_list.base())
       .values()
@@ -848,7 +858,8 @@ impl Reader {
     todo!()
   }
 
-  // This is used to determine exact change kind in case we do not get a data payload in DATA submessage
+  // This is used to determine exact change kind in case we do not get a data
+  // payload in DATA submessage
   fn deduce_change_kind(
     inline_qos: Option<ParameterList>,
     no_writers: bool,
@@ -889,15 +900,16 @@ impl Reader {
     cache.add_change(&self.topic_name, &receive_timestamp, cache_change);
   }
 
-  // notifies DataReaders (or any listeners that history cache has changed for this reader)
-  // likely use of mio channel
+  // notifies DataReaders (or any listeners that history cache has changed for
+  // this reader) likely use of mio channel
   pub fn notify_cache_change(&self) {
     match self.notification_sender.try_send(()) {
       Ok(()) => (),
-      Err(mio_channel::TrySendError::Full(_)) => (), // This is harmless. There is a notification in already.
+      Err(mio_channel::TrySendError::Full(_)) => (), /* This is harmless. There is a */
+      // notification in already.
       Err(mio_channel::TrySendError::Disconnected(_)) => {
-        // If we get here, our DataReader has died. The Reader should now dispose itself.
-        // TODO: Implement Reader disposal.
+        // If we get here, our DataReader has died. The Reader should now
+        // dispose itself. TODO: Implement Reader disposal.
       }
       Err(mio_channel::TrySendError::Io(_)) => {
         // TODO: What does this mean? Can we ever get here?
@@ -905,12 +917,13 @@ impl Reader {
     }
   }
 
-  fn send_acknack(&self, acknack: AckNack, mr_state: MessageReceiverState) {
-    // Indicate our endianness.
-    // Set final flag to indicate that we are NOT requesting immediate heartbeat response.
-    let flags = BitFlags::<ACKNACK_Flags>::from_flag(ACKNACK_Flags::Endianness)
-      | BitFlags::<ACKNACK_Flags>::from_flag(ACKNACK_Flags::Final);
-
+  fn send_acknack_to(
+    &self,
+    flags: BitFlags<ACKNACK_Flags>,
+    acknack: AckNack,
+    info_dst: InfoDestination,
+    dst_localtor_list: &[Locator],
+  ) {
     let infodst_flags =
       BitFlags::<INFODESTINATION_Flags>::from_flag(INFODESTINATION_Flags::Endianness);
 
@@ -921,10 +934,6 @@ impl Reader {
       guid_prefix: self.my_guid.guid_prefix,
     });
 
-    let info_dst = InfoDestination {
-      guid_prefix: mr_state.source_guid_prefix,
-    };
-
     match info_dst.create_submessage(infodst_flags) {
       Some(m) => message.add_submessage(m),
       None => return,
@@ -935,62 +944,35 @@ impl Reader {
       None => return,
     };
 
-    /*let mut bytes = message.serialize_header();
-    bytes.extend_from_slice(&submessage.serialize_msg()); */
     let bytes = message
       .write_to_vec_with_ctx(Endianness::LittleEndian)
       .unwrap();
     self
       .udp_sender
-      .send_to_locator_list(&bytes, &mr_state.unicast_reply_locator_list);
+      .send_to_locator_list(&bytes, dst_localtor_list);
   }
 
-  // TODO: This is much duplicate code from send_acknack.
   pub fn send_preemptive_acknacks(&mut self) {
     let flags = BitFlags::<ACKNACK_Flags>::from_flag(ACKNACK_Flags::Endianness);
     // Do not set final flag --> we are requesting immediate heartbeat from writers.
 
-    let infodst_flags =
-      BitFlags::<INFODESTINATION_Flags>::from_flag(INFODESTINATION_Flags::Endianness);
+    for (_, writer_proxy) in self.matched_writers.iter().filter(|(_, p)| p.no_changes()) {
+      self.send_acknack_to(
+        flags,
+        AckNack {
+          reader_id: self.entity_id(),
+          writer_id: writer_proxy.remote_writer_guid.entity_id,
+          reader_sn_state: SequenceNumberSet::new_empty(SequenceNumber::from(1)),
+          count: self.sent_ack_nack_count,
+        },
+        InfoDestination {
+          guid_prefix: writer_proxy.remote_writer_guid.guid_prefix,
+        },
+        &writer_proxy.unicast_locator_list,
+      );
+    }
 
     self.sent_ack_nack_count += 1;
-
-    for (_, writer_proxy) in self.matched_writers.iter().filter(|(_, p)| p.no_changes()) {
-      let mut message = Message::new(Header {
-        protocol_id: ProtocolId::default(),
-        protocol_version: ProtocolVersion::THIS_IMPLEMENTATION,
-        vendor_id: VendorId::THIS_IMPLEMENTATION,
-        guid_prefix: self.my_guid.guid_prefix,
-      });
-
-      let info_dst = InfoDestination {
-        guid_prefix: writer_proxy.remote_writer_guid.guid_prefix,
-      };
-
-      let acknack = AckNack {
-        reader_id: self.get_entity_id(),
-        writer_id: writer_proxy.remote_writer_guid.entity_id,
-        reader_sn_state: SequenceNumberSet::new_empty(SequenceNumber::from(1)),
-        count: self.sent_ack_nack_count,
-      };
-
-      match info_dst.create_submessage(infodst_flags) {
-        Some(m) => message.add_submessage(m),
-        None => continue, //TODO: is this correct??
-      };
-
-      match acknack.create_submessage(flags) {
-        Some(m) => message.add_submessage(m),
-        None => continue, //TODO: ??
-      };
-
-      let bytes = message
-        .write_to_vec_with_ctx(Endianness::LittleEndian)
-        .unwrap();
-      self
-        .udp_sender
-        .send_to_locator_list(&bytes, &writer_proxy.unicast_locator_list);
-    }
   }
 
   pub fn topic_name(&self) -> &String {
@@ -999,23 +981,17 @@ impl Reader {
 } // impl
 
 impl HasQoSPolicy for Reader {
-  fn get_qos(&self) -> QosPolicies {
+  fn qos(&self) -> QosPolicies {
     self.qos_policy.clone()
   }
 }
 
 impl RTPSEntity for Reader {
-  fn get_guid(&self) -> GUID {
+  fn guid(&self) -> GUID {
     self.my_guid
   }
 }
 
-impl Endpoint for Reader {
-  fn as_endpoint(&self) -> &crate::structure::endpoint::EndpointAttributes {
-    &self.enpoint_attributes
-  }
-}
-
 // Not needed anymore
 /*impl PartialEq for Reader {
   // Ignores registration and history cache?
@@ -1036,7 +1012,6 @@ impl fmt::Debug for Reader {
       .field("notification_sender, dds_cache", &"can't print".to_string())
       .field("topic_name", &self.topic_name)
       .field("my_guid", &self.my_guid)
-      .field("enpoint_attributes", &self.enpoint_attributes)
       .field("heartbeat_response_delay", &self.heartbeat_response_delay)
       .field("sent_ack_nack_count", &self.sent_ack_nack_count)
       .field("received_hearbeat_count", &self.received_hearbeat_count)
@@ -1047,20 +1022,23 @@ impl fmt::Debug for Reader {
 #[cfg(test)]
 mod tests {
   use super::*;
-  use crate::structure::guid::{GUID, EntityId};
-  use crate::messages::submessages::submessage_elements::serialized_payload::{SerializedPayload};
-  use crate::structure::guid::{GuidPrefix, EntityKind};
-  use crate::dds::statusevents::DataReaderStatus;
-  use crate::structure::topic_kind::TopicKind;
-  use crate::dds::typedesc::TypeDesc;
+  use crate::{
+    dds::{statusevents::DataReaderStatus, typedesc::TypeDesc},
+    messages::submessages::submessage_elements::serialized_payload::SerializedPayload,
+    structure::{
+      guid::{EntityId, EntityKind, GuidPrefix, GUID},
+      topic_kind::TopicKind,
+    },
+  };
 
   #[test]
+  #[ignore]
   fn rtpsreader_notification() {
     let mut guid = GUID::dummy_test_guid(EntityKind::READER_NO_KEY_USER_DEFINED);
     guid.entity_id = EntityId::create_custom_entity_id([1, 2, 3], EntityKind::from(111));
 
     let (send, rec) = mio_channel::sync_channel::<()>(100);
-    let (status_sender, _status_reciever) =
+    let (status_sender, _status_receiver) =
       mio_extras::channel::sync_channel::<DataReaderStatus>(100);
     let (_reader_command_sender, reader_command_receiver) =
       mio_channel::sync_channel::<ReaderCommand>(10);
@@ -1094,34 +1072,39 @@ mod tests {
         EntityKind::WRITER_WITH_KEY_USER_DEFINED,
       ),
     };
-
-    let mut mr_state = MessageReceiverState::default();
-    mr_state.source_guid_prefix = writer_guid.guid_prefix;
+    let mr_state = MessageReceiverState {
+      source_guid_prefix: writer_guid.guid_prefix,
+      ..Default::default()
+    };
 
     reader.matched_writer_add(
       writer_guid,
-      EntityId::ENTITYID_UNKNOWN,
+      EntityId::UNKNOWN,
       mr_state.unicast_reply_locator_list.clone(),
       mr_state.multicast_reply_locator_list.clone(),
     );
 
-    let mut data = Data::default();
-    data.reader_id = EntityId::create_custom_entity_id([1, 2, 3], EntityKind::from(111));
-    data.writer_id = writer_guid.entity_id;
+    let reader_id = EntityId::create_custom_entity_id([1, 2, 3], EntityKind::from(111));
+    let data = Data {
+      reader_id,
+      writer_id: writer_guid.entity_id,
+      ..Data::default()
+    };
 
     reader.handle_data_msg(data, BitFlags::<DATA_Flags>::empty(), mr_state);
 
-    //assert!(rec.try_recv().is_ok());
     // TODO:
     // Investaige whyt this fails. Is the test case correct?
+    assert!(rec.try_recv().is_ok());
   }
 
   #[test]
+  #[ignore]
   fn rtpsreader_handle_data() {
     let new_guid = GUID::default();
 
     let (send, rec) = mio_channel::sync_channel::<()>(100);
-    let (status_sender, _status_reciever) =
+    let (status_sender, _status_receiver) =
       mio_extras::channel::sync_channel::<DataReaderStatus>(100);
     let (_reader_command_sender, reader_command_receiver) =
       mio_channel::sync_channel::<ReaderCommand>(10);
@@ -1156,35 +1139,40 @@ mod tests {
       ),
     };
 
-    let mut mr_state = MessageReceiverState::default();
-    mr_state.source_guid_prefix = writer_guid.guid_prefix;
+    let mr_state = MessageReceiverState {
+      source_guid_prefix: writer_guid.guid_prefix,
+      ..Default::default()
+    };
 
     new_reader.matched_writer_add(
       writer_guid,
-      EntityId::ENTITYID_UNKNOWN,
+      EntityId::UNKNOWN,
       mr_state.unicast_reply_locator_list.clone(),
       mr_state.multicast_reply_locator_list.clone(),
     );
 
-    let mut d = Data::default();
-    d.writer_id = writer_guid.entity_id;
+    let d = Data {
+      writer_id: writer_guid.entity_id,
+      ..Default::default()
+    };
     let d_seqnum = d.writer_sn;
     new_reader.handle_data_msg(d.clone(), BitFlags::<DATA_Flags>::empty(), mr_state);
 
-    //assert!(rec.try_recv().is_ok());
     // TODO: Investigate why this fails. Is the test case or implementation faulty?
+    assert!(rec.try_recv().is_ok());
 
     let hc_locked = dds_cache.read().unwrap();
 
     let ddsdata = DDSData::new(d.serialized_payload.unwrap());
     let cc_built_here = CacheChange::new(writer_guid, d_seqnum, None, ddsdata);
 
-    // let cc_from_chache = hc_locked.from_topic_get_change(
-    //   &new_reader.topic_name,
-    //   new_reader.seqnum_instant_map.get(&d_seqnum).unwrap(),
-    // );
-    //assert_eq!(cc_from_chache.unwrap(), &cc_built_here);
-    // TODO: Investigate why this fails. Is the test case or implementation faulty?
+    let cc_from_chache = hc_locked.from_topic_get_change(
+      &new_reader.topic_name,
+      new_reader.seqnum_instant_map.get(&d_seqnum).unwrap(),
+    );
+    // TODO: Investigate why this fails. Is the test case or implementation
+    // faulty?
+    assert_eq!(cc_from_chache.unwrap(), &cc_built_here);
   }
 
   #[test]
@@ -1192,7 +1180,7 @@ mod tests {
     let new_guid = GUID::dummy_test_guid(EntityKind::READER_NO_KEY_USER_DEFINED);
 
     let (send, _rec) = mio_channel::sync_channel::<()>(100);
-    let (status_sender, _status_reciever) =
+    let (status_sender, _status_receiver) =
       mio_extras::channel::sync_channel::<DataReaderStatus>(100);
     let (_reader_command_sender, reader_command_receiver) =
       mio_channel::sync_channel::<ReaderCommand>(10);
@@ -1228,12 +1216,14 @@ mod tests {
 
     let writer_id = writer_guid.entity_id;
 
-    let mut mr_state = MessageReceiverState::default();
-    mr_state.source_guid_prefix = writer_guid.guid_prefix;
+    let mr_state = MessageReceiverState {
+      source_guid_prefix: writer_guid.guid_prefix,
+      ..Default::default()
+    };
 
     new_reader.matched_writer_add(
       writer_guid,
-      EntityId::ENTITYID_UNKNOWN,
+      EntityId::UNKNOWN,
       mr_state.unicast_reply_locator_list.clone(),
       mr_state.multicast_reply_locator_list.clone(),
     );
@@ -1242,7 +1232,7 @@ mod tests {
     let mut changes = Vec::new();
 
     let hb_new = Heartbeat {
-      reader_id: new_reader.get_entity_id(),
+      reader_id: new_reader.entity_id(),
       writer_id,
       first_sn: SequenceNumber::from(1), // First hearbeat from a new writer
       last_sn: SequenceNumber::from(0),
@@ -1251,7 +1241,7 @@ mod tests {
     assert!(!new_reader.handle_heartbeat_msg(hb_new, true, mr_state.clone())); // should be false, no ack
 
     let hb_one = Heartbeat {
-      reader_id: new_reader.get_entity_id(),
+      reader_id: new_reader.entity_id(),
       writer_id,
       first_sn: SequenceNumber::from(1), // Only one in writers cache
       last_sn: SequenceNumber::from(1),
@@ -1260,12 +1250,7 @@ mod tests {
     assert!(new_reader.handle_heartbeat_msg(hb_one, false, mr_state.clone())); // Should send an ack_nack
 
     // After ack_nack, will receive the following change
-    let change = CacheChange::new(
-      new_reader.get_guid(),
-      SequenceNumber::from(1),
-      None,
-      d.clone(),
-    );
+    let change = CacheChange::new(new_reader.guid(), SequenceNumber::from(1), None, d.clone());
     new_reader.dds_cache.write().unwrap().add_change(
       &new_reader.topic_name,
       &Timestamp::now(),
@@ -1275,7 +1260,7 @@ mod tests {
 
     // Duplicate
     let hb_one2 = Heartbeat {
-      reader_id: new_reader.get_entity_id(),
+      reader_id: new_reader.entity_id(),
       writer_id,
       first_sn: SequenceNumber::from(1), // Only one in writers cache
       last_sn: SequenceNumber::from(1),
@@ -1284,7 +1269,7 @@ mod tests {
     assert!(!new_reader.handle_heartbeat_msg(hb_one2, false, mr_state.clone())); // No acknack
 
     let hb_3_1 = Heartbeat {
-      reader_id: new_reader.get_entity_id(),
+      reader_id: new_reader.entity_id(),
       writer_id,
       first_sn: SequenceNumber::from(1), // writer has last 2 in cache
       last_sn: SequenceNumber::from(3),  // writer has written 3 samples
@@ -1293,12 +1278,7 @@ mod tests {
     assert!(new_reader.handle_heartbeat_msg(hb_3_1, false, mr_state.clone())); // Should send an ack_nack
 
     // After ack_nack, will receive the following changes
-    let change = CacheChange::new(
-      new_reader.get_guid(),
-      SequenceNumber::from(2),
-      None,
-      d.clone(),
-    );
+    let change = CacheChange::new(new_reader.guid(), SequenceNumber::from(2), None, d.clone());
     new_reader.dds_cache.write().unwrap().add_change(
       &new_reader.topic_name,
       &Timestamp::now(),
@@ -1306,7 +1286,7 @@ mod tests {
     );
     changes.push(change);
 
-    let change = CacheChange::new(new_reader.get_guid(), SequenceNumber::from(3), None, d);
+    let change = CacheChange::new(new_reader.guid(), SequenceNumber::from(3), None, d);
     new_reader.dds_cache.write().unwrap().add_change(
       &new_reader.topic_name,
       &Timestamp::now(),
@@ -1315,7 +1295,7 @@ mod tests {
     changes.push(change);
 
     let hb_none = Heartbeat {
-      reader_id: new_reader.get_entity_id(),
+      reader_id: new_reader.entity_id(),
       writer_id,
       first_sn: SequenceNumber::from(4), // writer has no samples available
       last_sn: SequenceNumber::from(3),  // writer has written 3 samples
@@ -1327,11 +1307,13 @@ mod tests {
   }
 
   #[test]
+  #[ignore]
   fn rtpsreader_handle_gap() {
-    return; // TODO: investiage why this fails. Does the test case even make sense with current code?
+    // TODO: investiage why this fails. Does the test case even make sense with
+    // current code?
     let new_guid = GUID::dummy_test_guid(EntityKind::READER_NO_KEY_USER_DEFINED);
     let (send, _rec) = mio_channel::sync_channel::<()>(100);
-    let (status_sender, _status_reciever) =
+    let (status_sender, _status_receiver) =
       mio_extras::channel::sync_channel::<DataReaderStatus>(100);
     let (_reader_command_sender, reader_command_receiver) =
       mio_channel::sync_channel::<ReaderCommand>(10);
@@ -1367,12 +1349,14 @@ mod tests {
     };
     let writer_id = writer_guid.entity_id;
 
-    let mut mr_state = MessageReceiverState::default();
-    mr_state.source_guid_prefix = writer_guid.guid_prefix;
+    let mr_state = MessageReceiverState {
+      source_guid_prefix: writer_guid.guid_prefix,
+      ..Default::default()
+    };
 
     reader.matched_writer_add(
       writer_guid,
-      EntityId::ENTITYID_UNKNOWN,
+      EntityId::UNKNOWN,
       mr_state.unicast_reply_locator_list.clone(),
       mr_state.multicast_reply_locator_list.clone(),
     );
@@ -1387,12 +1371,7 @@ mod tests {
     for i in 0..n {
       d.writer_sn = SequenceNumber::from(i);
       reader.handle_data_msg(d.clone(), BitFlags::<DATA_Flags>::empty(), mr_state.clone());
-      changes.push(
-        reader
-          .get_history_cache_change(d.writer_sn)
-          .unwrap()
-          .clone(),
-      );
+      changes.push(reader.history_cache_change(d.writer_sn).unwrap().clone());
     }
 
     // make sequence numbers 1-3 and 5 7 irrelevant
@@ -1401,7 +1380,7 @@ mod tests {
     gap_list.insert(SequenceNumber::from(7));
 
     let gap = Gap {
-      reader_id: reader.get_entity_id(),
+      reader_id: reader.entity_id(),
       writer_id,
       gap_start: SequenceNumber::from(1),
       gap_list,
@@ -1411,43 +1390,28 @@ mod tests {
     reader.handle_gap_msg(gap, mr_state);
 
     assert_eq!(
-      reader.get_history_cache_change(SequenceNumber::from(0)),
+      reader.history_cache_change(SequenceNumber::from(0)),
       Some(changes[0].clone())
     );
+    assert_eq!(reader.history_cache_change(SequenceNumber::from(1)), None);
+    assert_eq!(reader.history_cache_change(SequenceNumber::from(2)), None);
+    assert_eq!(reader.history_cache_change(SequenceNumber::from(3)), None);
     assert_eq!(
-      reader.get_history_cache_change(SequenceNumber::from(1)),
-      None
-    );
-    assert_eq!(
-      reader.get_history_cache_change(SequenceNumber::from(2)),
-      None
-    );
-    assert_eq!(
-      reader.get_history_cache_change(SequenceNumber::from(3)),
-      None
-    );
-    assert_eq!(
-      reader.get_history_cache_change(SequenceNumber::from(4)),
+      reader.history_cache_change(SequenceNumber::from(4)),
       Some(changes[4].clone())
     );
+    assert_eq!(reader.history_cache_change(SequenceNumber::from(5)), None);
     assert_eq!(
-      reader.get_history_cache_change(SequenceNumber::from(5)),
-      None
-    );
-    assert_eq!(
-      reader.get_history_cache_change(SequenceNumber::from(6)),
+      reader.history_cache_change(SequenceNumber::from(6)),
       Some(changes[6].clone())
     );
+    assert_eq!(reader.history_cache_change(SequenceNumber::from(7)), None);
     assert_eq!(
-      reader.get_history_cache_change(SequenceNumber::from(7)),
-      None
-    );
-    assert_eq!(
-      reader.get_history_cache_change(SequenceNumber::from(8)),
+      reader.history_cache_change(SequenceNumber::from(8)),
       Some(changes[8].clone())
     );
     assert_eq!(
-      reader.get_history_cache_change(SequenceNumber::from(9)),
+      reader.history_cache_change(SequenceNumber::from(9)),
       Some(changes[9].clone())
     );
   }
