@@ -1,46 +1,36 @@
-use std::ops::Bound::Included;
+use std::{
+  cmp::max,
+  collections::{BTreeMap, BTreeSet, HashSet},
+  iter::FromIterator,
+  ops::Bound::Included,
+  rc::Rc,
+  sync::{Arc, RwLock},
+};
 
 #[allow(unused_imports)]
-use log::{debug, error, warn, info, trace};
-
-use speedy::{Writable, Endianness};
-use mio_extras::channel::{self as mio_channel, SyncSender, TrySendError};
-use mio_extras::timer::Timer;
+use log::{debug, error, info, trace, warn};
+use speedy::{Endianness, Writable};
+use mio_extras::{
+  channel::{self as mio_channel, SyncSender, TrySendError},
+  timer::Timer,
+};
 use mio::Token;
-use std::{
-  sync::{RwLock, Arc},
-  rc::Rc,
-  collections::{HashSet, BTreeMap, BTreeSet},
-  iter::FromIterator,
-  cmp::max,
-};
+use policy::{History, Reliability};
 
-use crate::{serialization::MessageBuilder};
-
-use crate::structure::time::Timestamp;
-use crate::structure::duration::Duration;
-
-use crate::structure::guid::{GuidPrefix, EntityId, GUID};
-use crate::structure::sequence_number::{SequenceNumber};
 use crate::{
-  // messages::submessages::submessages::{
-  //   AckNack,
-  // },
+  dds::{ddsdata::DDSData, dp_event_loop::NACK_RESPONSE_DELAY, qos::HasQoSPolicy},
   messages::submessages::submessages::AckSubmessage,
-
-  structure::cache_change::{CacheChange},
-  serialization::{Message},
-  dds::dp_event_loop::NACK_RESPONSE_DELAY,
-};
-
-use crate::dds::{ddsdata::DDSData, qos::HasQoSPolicy};
-use crate::{
   network::udp_sender::UDPSender,
+  serialization::{Message, MessageBuilder},
   structure::{
-    entity::RTPSEntity,
-    endpoint::{EndpointAttributes, Endpoint},
-    locator::Locator,
+    cache_change::CacheChange,
     dds_cache::DDSCache,
+    duration::Duration,
+    entity::RTPSEntity,
+    guid::{EntityId, GuidPrefix, GUID},
+    locator::Locator,
+    sequence_number::SequenceNumber,
+    time::Timestamp,
   },
 };
 use super::{
@@ -48,7 +38,6 @@ use super::{
   rtps_reader_proxy::RtpsReaderProxy,
   statusevents::*,
 };
-use policy::{History, Reliability};
 
 #[derive(PartialEq, Eq, Clone, Copy)]
 pub enum DeliveryMode {
@@ -119,28 +108,28 @@ pub(crate) struct Writer {
   ///SerializedPayload that may be
   ///sent by the Writer
   pub data_max_size_serialized: u64,
-  endpoint_attributes: EndpointAttributes,
   my_guid: GUID,
   pub(crate) writer_command_receiver: mio_channel::Receiver<WriterCommand>,
-  ///The RTPS ReaderProxy class represents the information an RTPS StatefulWriter maintains on each matched
-  ///RTPS Reader
+  ///The RTPS ReaderProxy class represents the information an RTPS
+  /// StatefulWriter maintains on each matched RTPS Reader
   readers: BTreeMap<GUID, RtpsReaderProxy>, // TODO: Convert to BTreeMap for faster finds.
   matched_readers_count_total: i32, // all matches, never decremented
   requested_incompatible_qos_count: i32, // how many times a Reader requested incompatible QoS
   //message: Option<Message>,
   udp_sender: Rc<UDPSender>,
 
-  // This writer can read/write to only one of this DDSCache topic caches identified with my_topic_name
+  // This writer can read/write to only one of this DDSCache topic caches identified with
+  // my_topic_name
   dds_cache: Arc<RwLock<DDSCache>>,
   /// Writer can only read/write to this topic DDSHistoryCache.
   my_topic_name: String,
 
   /// Maps this writers local sequence numbers to DDSHistodyCache instants.
-  /// Useful when negative acknack is recieved.
+  /// Useful when negative acknack is received.
   sequence_number_to_instant: BTreeMap<SequenceNumber, Timestamp>,
 
   /// Maps this writers local sequence numbers to DDSHistodyCache instants.
-  /// Useful when datawriter dispose is recieved.
+  /// Useful when datawriter dispose is received.
   //key_to_instant: HashMap<u128, Timestamp>,  // unused?
 
   /// Set of disposed samples.
@@ -150,11 +139,12 @@ pub(crate) struct Writer {
   //When dataWriter sends cacheChange message with cacheKind is NotAliveDisposed
   //this is set true. If Datawriter after disposing sends new cahceChanges this falg is then
   //turned true.
-  //When writer is in disposed state it needs to send StatusInfo_t (PID_STATUS_INFO) with DisposedFlag
-  // pub writer_is_disposed: bool,
-  ///Contains timer that needs to be set to timeout with duration of self.heartbeat_perioid
-  ///timed_event_handler sends notification when timer is up via miochannel to poll in Dp_eventWrapper
-  ///this also handles writers cache cleaning timeouts.
+  //When writer is in disposed state it needs to send StatusInfo_t (PID_STATUS_INFO) with
+  // DisposedFlag pub writer_is_disposed: bool,
+  ///Contains timer that needs to be set to timeout with duration of
+  /// self.heartbeat_perioid timed_event_handler sends notification when timer
+  /// is up via miochannel to poll in Dp_eventWrapper this also handles
+  /// writers cache cleaning timeouts.
   pub(crate) timed_event_timer: Timer<TimedEvent>,
 
   qos_policies: QosPolicies,
@@ -190,7 +180,8 @@ impl Writer {
     mut timed_event_timer: Timer<TimedEvent>,
   ) -> Writer {
     let heartbeat_period = match &i.qos_policies.reliability {
-      Some(Reliability::Reliable { .. }) => Some(Duration::from_secs(1)), // TODO: make configurable
+      Some(Reliability::Reliable { .. }) => Some(Duration::from_secs(1)), /* TODO: make */
+      // configurable
       Some(Reliability::BestEffort) => None,
       None => None,
     };
@@ -240,7 +231,6 @@ impl Writer {
       readers: BTreeMap::new(),
       matched_readers_count_total: 0,
       requested_incompatible_qos_count: 0,
-      endpoint_attributes: EndpointAttributes::default(),
       udp_sender,
       dds_cache,
       my_topic_name: i.topic_name,
@@ -254,22 +244,23 @@ impl Writer {
     }
   }
 
-  /// To know when token represents a writer we should look entity attribute kind
-  /// this entity token can be used in DataWriter -> Writer mio::channel.
-  pub fn get_entity_token(&self) -> Token {
-    self.get_guid().entity_id.as_token()
+  /// To know when token represents a writer we should look entity attribute
+  /// kind this entity token can be used in DataWriter -> Writer mio::channel.
+  pub fn entity_token(&self) -> Token {
+    self.guid().entity_id.as_token()
   }
 
-  /// This token is used in timed event mio::channel HearbeatHandler -> dpEventwrapper
-  pub fn get_timed_event_entity_token(&self) -> Token {
-    self.get_guid().entity_id.as_alt_token()
+  /// This token is used in timed event mio::channel HearbeatHandler ->
+  /// dpEventwrapper
+  pub fn timed_event_entity_token(&self) -> Token {
+    self.guid().entity_id.as_alt_token()
   }
 
   pub fn is_reliable(&self) -> bool {
     self.qos_policies.reliability.is_some()
   }
 
-  pub fn get_local_readers(&self) -> Vec<EntityId> {
+  pub fn local_readers(&self) -> Vec<EntityId> {
     let min = GUID::new_with_prefix_and_id(self.my_guid.guid_prefix, EntityId::MIN);
     let max = GUID::new_with_prefix_and_id(self.my_guid.guid_prefix, EntityId::MAX);
 
@@ -305,7 +296,8 @@ impl Writer {
       match e {
         TimedEvent::Heartbeat => {
           self.handle_heartbeat_tick(false);
-          // ^^ false = This is automatic heartbeat by timer, not manual by application call.
+          // ^^ false = This is automatic heartbeat by timer, not manual by application
+          // call.
           if let Some(period) = self.heartbeat_period {
             self
               .timed_event_timer
@@ -380,7 +372,8 @@ impl Writer {
           // 1. Insert it to history cache and get it sequence numbered
           // 2. Send out data.
           //    If we are pushing data, send the DATA submessage and HEARTBEAT.
-          //    If we are not pushing, send out HEARTBEAT only. Readers will then ask the DATA with ACKNACK.
+          //    If we are not pushing, send out HEARTBEAT only. Readers will then ask the
+          // DATA with ACKNACK.
           let timestamp = self.insert_to_history_cache(data, source_timestamp);
 
           self.increase_heartbeat_counter();
@@ -403,8 +396,8 @@ impl Writer {
               partial_message.data_msg(
                 cache_change.clone(),
                 // Now that payload contains Bytes, it is relatively cheap to clone
-                EntityId::ENTITYID_UNKNOWN, // reader
-                self.my_guid.entity_id,     // writer
+                EntityId::UNKNOWN,      // reader
+                self.my_guid.entity_id, // writer
                 self.endianness,
               )
             } else {
@@ -416,12 +409,7 @@ impl Writer {
           let final_flag = false;
           let liveliness_flag = false;
           let data_hb_message = data_hb_message_builder
-            .heartbeat_msg(
-              self,
-              EntityId::ENTITYID_UNKNOWN,
-              final_flag,
-              liveliness_flag,
-            )
+            .heartbeat_msg(self, EntityId::UNKNOWN, final_flag, liveliness_flag)
             .add_header_and_build(self.my_guid.guid_prefix);
           self.send_message_to_readers(
             DeliveryMode::Multicast,
@@ -475,8 +463,9 @@ impl Writer {
     let new_sequence_number = self.last_change_sequence_number + SequenceNumber::from(1);
     self.last_change_sequence_number = new_sequence_number;
 
-    // setting first change sequence number according to our qos (not offering more than our QOS says)
-    self.first_change_sequence_number = match self.get_qos().history {
+    // setting first change sequence number according to our qos (not offering more
+    // than our QOS says)
+    self.first_change_sequence_number = match self.qos().history {
       None => self.last_change_sequence_number, // default: depth = 1
 
       Some(History::KeepAll) =>
@@ -495,7 +484,7 @@ impl Writer {
 
     // create new CacheChange from DDSData
     let new_cache_change = CacheChange::new(
-      self.get_guid(),
+      self.guid(),
       self.last_change_sequence_number,
       source_timestamp,
       data,
@@ -532,7 +521,8 @@ impl Writer {
   /// This is called periodically.
   pub fn handle_heartbeat_tick(&mut self, is_manual_assertion: bool) {
     // Reliable Stateless Writer will set the final flag.
-    // Reliable Stateful Writer (that tracks Readers by ReaderProxy) will not set the final flag.
+    // Reliable Stateful Writer (that tracks Readers by ReaderProxy) will not set
+    // the final flag.
     let final_flag = false;
     let liveliness_flag = is_manual_assertion; // RTPS spec "8.3.7.5 Heartbeat"
 
@@ -555,16 +545,11 @@ impl Writer {
     } else {
       let hb_message = MessageBuilder::new()
         .ts_msg(self.endianness, Some(Timestamp::now()))
-        .heartbeat_msg(
-          self,
-          EntityId::ENTITYID_UNKNOWN,
-          final_flag,
-          liveliness_flag,
-        )
+        .heartbeat_msg(self, EntityId::UNKNOWN, final_flag, liveliness_flag)
         .add_header_and_build(self.my_guid.guid_prefix);
       debug!(
         "Writer {:?} topic={:} HEARTBEAT {:?}",
-        self.get_guid().entity_id,
+        self.guid().entity_id,
         self.topic_name(),
         hb_message
       );
@@ -576,8 +561,9 @@ impl Writer {
     }
   }
 
-  /// When receiving an ACKNACK Message indicating a Reader is missing some data samples, the Writer must
-  /// respond by either sending the missing data samples, sending a GAP message when the sample is not relevant, or
+  /// When receiving an ACKNACK Message indicating a Reader is missing some data
+  /// samples, the Writer must respond by either sending the missing data
+  /// samples, sending a GAP message when the sample is not relevant, or
   /// sending a HEARTBEAT message when the sample is no longer available
   pub fn handle_ack_nack(&mut self, reader_guid_prefix: GuidPrefix, ack_submessage: AckSubmessage) {
     match ack_submessage {
@@ -586,7 +572,7 @@ impl Writer {
         if !self.is_reliable() {
           warn!(
             "Writer {:x?} is best effort! It should not handle acknack messages!",
-            self.get_entity_id()
+            self.entity_id()
           );
           return;
         }
@@ -609,8 +595,9 @@ impl Writer {
           reader_proxy.handle_ack_nack(&ack_submessage, last_seq);
 
           let reader_guid = reader_proxy.remote_reader_guid; // copy to avoid double mut borrow
-                                                             // Sanity Check: if the reader asked for something we did not even advertise yet.
-                                                             // TODO: This checks the stored unset_changes, not presentely received ACKNACK.
+                                                             // Sanity Check: if the reader asked for something we did not even advertise
+                                                             // yet. TODO: This
+                                                             // checks the stored unset_changes, not presentely received ACKNACK.
           if let Some(&high) = reader_proxy.unsent_changes.iter().next_back() {
             if high > last_seq {
               warn!(
@@ -694,8 +681,9 @@ impl Writer {
     // Then we can mutate both the reader and other fields in self.
     // Doing a .get_mut() on the reader map would make self immutable.
     if let Some(reader_proxy) = self.readers.remove(&to_reader) {
-      // We use a worker function to ensure that afterwards we can insert the reader_proxy back.
-      // This technique ensures that all return paths lead to re-insertion.
+      // We use a worker function to ensure that afterwards we can insert the
+      // reader_proxy back. This technique ensures that all return paths lead to
+      // re-insertion.
       let reader_proxy = self.handle_repair_data_send_worker(reader_proxy);
       // insert reader back
       let reject = self
@@ -744,7 +732,8 @@ impl Writer {
               self.my_guid.entity_id, // writer
               self.endianness,
             );
-            // TODO: Here we are cloning the entire payload. We need to rewrite the transmit path to avoid copying.
+            // TODO: Here we are cloning the entire payload. We need to rewrite
+            // the transmit path to avoid copying.
 
             // CC will be sent. Remove from unsent list.
           } else {
@@ -790,8 +779,8 @@ impl Writer {
   } // fn
 
   /// Removes permanently cacheChanges from DDSCache.
-  /// CacheChanges can be safely removed only if they are acked by all readers. (Reliable)
-  /// Depth is QoS policy History depth.
+  /// CacheChanges can be safely removed only if they are acked by all readers.
+  /// (Reliable) Depth is QoS policy History depth.
   /// Returns SequenceNumbers of removed CacheChanges
   /// This is called repeadedly by handle_cache_cleaning action.
   fn remove_all_acked_changes_but_keep_depth(&mut self, depth: usize) {
@@ -835,8 +824,8 @@ impl Writer {
     readers: &mut dyn Iterator<Item = &RtpsReaderProxy>,
   ) {
     // TODO: This is a stupid transmit algorithm. We should compute a preferred
-    // unicast and multicast locators for each reader only on every reader update, and
-    // not find it dynamically on every message.
+    // unicast and multicast locators for each reader only on every reader update,
+    // and not find it dynamically on every message.
     let buffer = message.write_to_vec_with_ctx(self.endianness).unwrap();
     let mut already_sent_to = BTreeSet::new();
 
@@ -1050,19 +1039,13 @@ impl Writer {
 }
 
 impl RTPSEntity for Writer {
-  fn get_guid(&self) -> GUID {
+  fn guid(&self) -> GUID {
     self.my_guid
   }
 }
 
-impl Endpoint for Writer {
-  fn as_endpoint(&self) -> &crate::structure::endpoint::EndpointAttributes {
-    &self.endpoint_attributes
-  }
-}
-
 impl HasQoSPolicy for Writer {
-  fn get_qos(&self) -> QosPolicies {
+  fn qos(&self) -> QosPolicies {
     self.qos_policies.clone()
   }
 }
@@ -1073,20 +1056,22 @@ impl HasQoSPolicy for Writer {
 
 #[cfg(test)]
 mod tests {
-  use crate::{
-    dds::{
-      participant::DomainParticipant, qos::QosPolicies, with_key::datawriter::DataWriter,
-      topic::TopicKind,
-    },
-  };
   use std::thread;
-  use crate::test::random_data::*;
-  use crate::serialization::cdr_serializer::CDRSerializerAdapter;
+
   use byteorder::LittleEndian;
   use log::info;
 
+  use crate::{
+    dds::{
+      participant::DomainParticipant, qos::QosPolicies, topic::TopicKind,
+      with_key::datawriter::DataWriter,
+    },
+    serialization::cdr_serializer::CDRSerializerAdapter,
+    test::random_data::*,
+  };
+
   #[test]
-  fn test_writer_recieves_datawriter_cache_change_notifications() {
+  fn test_writer_receives_datawriter_cache_change_notifications() {
     let domain_participant = DomainParticipant::new(0).expect("Failed to create participant");
     let qos = QosPolicies::qos_none();
     let _default_dw_qos = QosPolicies::qos_none();
@@ -1122,19 +1107,19 @@ mod tests {
       b: "Fobar".to_string(),
     };
 
-    let writeResult = data_writer.write(data, None).expect("Unable to write data");
+    let write_result = data_writer.write(data, None).expect("Unable to write data");
 
-    info!("writerResult:  {:?}", writeResult);
-    let writeResult = data_writer
+    info!("writerResult:  {:?}", write_result);
+    let write_result = data_writer
       .write(data2, None)
       .expect("Unable to write data");
 
-    info!("writerResult:  {:?}", writeResult);
-    let writeResult = data_writer
+    info!("writerResult:  {:?}", write_result);
+    let write_result = data_writer
       .write(data3, None)
       .expect("Unable to write data");
 
     thread::sleep(std::time::Duration::from_millis(100));
-    info!("writerResult:  {:?}", writeResult);
+    info!("writerResult:  {:?}", write_result);
   }
 }
