@@ -1,38 +1,40 @@
 use std::time::Instant;
 
-use serde::{Serialize, Deserialize, de};
-
+use serde::{de, Deserialize, Serialize};
 use chrono::Utc;
-
 use cdr_encoding_size::*;
 
 use crate::{
   dds::{
-    qos::policy::{
-      Deadline, Durability, LatencyBudget, Reliability, Ownership, DestinationOrder, Liveliness,
-      TimeBasedFilter, Presentation, Lifespan, History, ResourceLimits,
-    },
-    traits::key::Keyed,
-    traits::serde_adapters::with_key::SerializerAdapter, // these are WITH_KEY data
-    rtps_reader_proxy::RtpsReaderProxy,
-    reader::Reader,
     participant::DomainParticipant,
-    topic::Topic,
-    with_key::datawriter::DataWriter,
+    qos::{
+      policy::{
+        Deadline, DestinationOrder, Durability, History, LatencyBudget, Lifespan, Liveliness,
+        Ownership, Presentation, Reliability, ResourceLimits, TimeBasedFilter,
+      },
+      HasQoSPolicy, QosPolicies,
+    },
+    reader::Reader,
+    rtps_reader_proxy::RtpsReaderProxy,
     rtps_writer_proxy::RtpsWriterProxy,
+    topic::Topic,
+    traits::{
+      key::{Key, Keyed},
+      serde_adapters::with_key::SerializerAdapter,
+      TopicDescription,
+    },
+    with_key::datawriter::DataWriter,
   },
-  dds::qos::HasQoSPolicy,
-  dds::qos::QosPolicies,
-  dds::traits::{key::Key, TopicDescription},
   discovery::content_filter_property::ContentFilterProperty,
-  network::constant::get_user_traffic_unicast_port,
-  network::util::get_local_unicast_socket_address,
+  network::{constant::user_traffic_unicast_port, util::get_local_unicast_socket_address},
   serialization::{
-    builtin_data_serializer::BuiltinDataSerializer,
     builtin_data_deserializer::BuiltinDataDeserializer,
+    builtin_data_serializer::BuiltinDataSerializer,
   },
   structure::{
-    entity::RTPSEntity, guid::GUID, guid::GuidPrefix, guid::EntityKind, locator::LocatorList,
+    entity::RTPSEntity,
+    guid::{EntityKind, GuidPrefix, GUID},
+    locator::Locator,
   },
 };
 
@@ -45,8 +47,8 @@ use crate::{
 pub struct ReaderProxy {
   pub remote_reader_guid: GUID,
   pub expects_inline_qos: bool,
-  pub unicast_locator_list: LocatorList,
-  pub multicast_locator_list: LocatorList,
+  pub unicast_locator_list: Vec<Locator>,
+  pub multicast_locator_list: Vec<Locator>,
 }
 
 impl ReaderProxy {
@@ -309,14 +311,14 @@ impl DiscoveredReaderData {
     dp: &DomainParticipant,
     topic: &Topic,
   ) -> DiscoveredReaderData {
-    let reader_proxy = ReaderProxy::new(reader.get_guid());
+    let reader_proxy = ReaderProxy::new(reader.guid());
     let mut subscription_topic_data = SubscriptionBuiltinTopicData::new(
-      reader.get_guid(),
-      topic.get_name(),
+      reader.guid(),
+      topic.name(),
       topic.get_type().name().to_string(),
-      &topic.get_qos(),
+      &topic.qos(),
     );
-    subscription_topic_data.set_participant_key(dp.get_guid());
+    subscription_topic_data.set_participant_key(dp.guid());
 
     DiscoveredReaderData {
       reader_proxy,
@@ -350,14 +352,14 @@ impl DiscoveredReaderData {
 }
 
 // separate type is needed to serialize correctly
-#[derive(Eq, PartialEq, Ord, PartialOrd, Debug, Clone, Copy, Hash, CdrEncodingSize,)]
+#[derive(Eq, PartialEq, Ord, PartialOrd, Debug, Clone, Copy, Hash, CdrEncodingSize)]
 pub struct DiscoveredReaderDataKey(pub GUID);
 
 impl Key for DiscoveredReaderDataKey {}
 
 impl Keyed for DiscoveredReaderData {
   type K = DiscoveredReaderDataKey;
-  fn get_key(&self) -> Self::K {
+  fn key(&self) -> Self::K {
     DiscoveredReaderDataKey(self.subscription_topic_data.key)
   }
 }
@@ -418,16 +420,16 @@ impl Serialize for DiscoveredReaderDataKey {
 #[derive(Debug, Clone, PartialEq, Eq, Hash)]
 pub struct WriterProxy {
   pub remote_writer_guid: GUID,
-  pub unicast_locator_list: LocatorList,
-  pub multicast_locator_list: LocatorList,
+  pub unicast_locator_list: Vec<Locator>,
+  pub multicast_locator_list: Vec<Locator>,
   pub data_max_size_serialized: Option<u32>,
 }
 
 impl WriterProxy {
   pub fn new(
     guid: GUID,
-    multicast_locator_list: LocatorList,
-    unicast_locator_list: LocatorList,
+    multicast_locator_list: Vec<Locator>,
+    unicast_locator_list: Vec<Locator>,
   ) -> WriterProxy {
     WriterProxy {
       remote_writer_guid: guid,
@@ -565,7 +567,7 @@ impl Serialize for PublicationBuiltinTopicData {
 
 // ------------------------------------------
 
-#[derive(Debug, Clone, PartialEq, Eq, Hash, CdrEncodingSize,)]
+#[derive(Debug, Clone, PartialEq, Eq, Hash, CdrEncodingSize)]
 pub struct PublicationBuiltinTopicDataKey(pub GUID);
 
 impl Serialize for PublicationBuiltinTopicDataKey {
@@ -592,7 +594,7 @@ pub struct DiscoveredWriterData {
 }
 
 // separate type is needed to serialize correctly
-#[derive(Eq, PartialEq, Ord, PartialOrd, Debug, Clone, Copy, Hash, CdrEncodingSize,)]
+#[derive(Eq, PartialEq, Ord, PartialOrd, Debug, Clone, Copy, Hash, CdrEncodingSize)]
 pub struct DiscoveredWriterDataKey(pub GUID); // wrapper to enable custom PL CDR (de)serialization
 
 impl Key for DiscoveredWriterDataKey {}
@@ -600,7 +602,7 @@ impl Key for DiscoveredWriterDataKey {}
 impl Keyed for DiscoveredWriterData {
   type K = DiscoveredWriterDataKey;
 
-  fn get_key(&self) -> Self::K {
+  fn key(&self) -> Self::K {
     DiscoveredWriterDataKey(self.publication_topic_data.key)
   }
 }
@@ -611,18 +613,18 @@ impl DiscoveredWriterData {
     topic: &Topic,
     dp: &DomainParticipant,
   ) -> DiscoveredWriterData {
-    let unicast_port = get_user_traffic_unicast_port(dp.domain_id(), dp.participant_id());
+    let unicast_port = user_traffic_unicast_port(dp.domain_id(), dp.participant_id());
     let unicast_addresses = get_local_unicast_socket_address(unicast_port);
 
-    let writer_proxy = WriterProxy::new(writer.get_guid(), vec![], unicast_addresses);
+    let writer_proxy = WriterProxy::new(writer.guid(), vec![], unicast_addresses);
     let mut publication_topic_data = PublicationBuiltinTopicData::new(
-      writer.get_guid(),
-      dp.get_guid(),
-      topic.get_name(),
+      writer.guid(),
+      dp.guid(),
+      topic.name(),
       topic.get_type().name().to_string(),
     );
 
-    publication_topic_data.read_qos(&topic.get_qos());
+    publication_topic_data.read_qos(&topic.qos());
 
     DiscoveredWriterData {
       last_updated: Instant::now(),
@@ -708,7 +710,7 @@ pub struct TopicBuiltinTopicData {
 }
 
 impl HasQoSPolicy for TopicBuiltinTopicData {
-  fn get_qos(&self) -> QosPolicies {
+  fn qos(&self) -> QosPolicies {
     QosPolicies {
       durability: self.durability,
       presentation: self.presentation,
@@ -769,11 +771,11 @@ impl DiscoveredTopicData {
     }
   }
 
-  pub fn get_topic_name(&self) -> &String {
+  pub fn topic_name(&self) -> &String {
     &self.topic_data.name
   }
 
-  pub fn get_type_name(&self) -> &String {
+  pub fn type_name(&self) -> &String {
     &self.topic_data.type_name
   }
 }
@@ -806,7 +808,7 @@ pub type DiscoveredTopicDataKey = GUID;
 impl Keyed for DiscoveredTopicData {
   type K = GUID;
 
-  fn get_key(&self) -> Self::K {
+  fn key(&self) -> Self::K {
     // topic should always have a name, if this crashes the problem is in the
     // overall logic (or message parsing)
     match self.topic_data.key {
@@ -820,7 +822,9 @@ impl Keyed for DiscoveredTopicData {
 // =======================================================================
 // =======================================================================
 
-#[derive(Copy, Clone, Debug, PartialOrd, PartialEq, Ord, Eq, Hash, Serialize, Deserialize,CdrEncodingSize,)]
+#[derive(
+  Copy, Clone, Debug, PartialOrd, PartialEq, Ord, Eq, Hash, Serialize, Deserialize, CdrEncodingSize,
+)]
 pub struct ParticipantMessageDataKind {
   value: [u8; 4],
 }
@@ -856,15 +860,16 @@ pub struct ParticipantMessageData {
 impl Keyed for ParticipantMessageData {
   type K = ParticipantMessageDataKey;
 
-  fn get_key(&self) -> Self::K {
+  fn key(&self) -> Self::K {
     ParticipantMessageDataKey(self.guid, self.kind)
   }
 }
 
-#[derive(Debug, PartialEq, Eq, Clone, Copy, Hash , Ord, PartialOrd, Serialize, Deserialize, CdrEncodingSize,)]
+#[derive(
+  Debug, PartialEq, Eq, Clone, Copy, Hash, Ord, PartialOrd, Serialize, Deserialize, CdrEncodingSize,
+)]
 pub struct ParticipantMessageDataKey(GuidPrefix, ParticipantMessageDataKind);
 
-
 impl Key for ParticipantMessageDataKey {}
 
 // =======================================================================
@@ -873,27 +878,22 @@ impl Key for ParticipantMessageDataKey {}
 
 #[cfg(test)]
 mod tests {
-  use super::*;
-
-  // use crate::serialization::cdr_serializer::to_little_endian_binary;
-  use crate::serialization::{
-    Message,
-    cdr_serializer::{to_bytes},
-  };
   use byteorder::LittleEndian;
   use bytes::Bytes;
   use log::info;
-  use crate::serialization::pl_cdr_deserializer::PlCdrDeserializerAdapter;
 
+  use super::*;
+  // use crate::serialization::cdr_serializer::to_little_endian_binary;
   use crate::{
-    test::test_data::{
-      subscription_builtin_topic_data, reader_proxy_data, content_filter_data, writer_proxy_data,
-      publication_builtin_topic_data, topic_data,
-    },
-  };
-  use crate::{
-    messages::submessages::submessage_elements::serialized_payload::RepresentationIdentifier,
     dds::traits::serde_adapters::no_key::DeserializerAdapter,
+    messages::submessages::submessage_elements::serialized_payload::RepresentationIdentifier,
+    serialization::{
+      cdr_serializer::to_bytes, pl_cdr_deserializer::PlCdrDeserializerAdapter, Message,
+    },
+    test::test_data::{
+      content_filter_data, publication_builtin_topic_data, reader_proxy_data,
+      subscription_builtin_topic_data, topic_data, writer_proxy_data,
+    },
   };
 
   #[test]
