@@ -1,65 +1,57 @@
-use std::time::Instant;
-use crate::network::util::get_local_unicast_socket_address;
-use crate::discovery::data_types::topic_data::WriterProxy;
-use crate::discovery::data_types::topic_data::PublicationBuiltinTopicData;
-
-use crate::discovery::data_types::topic_data::DiscoveredReaderDataKey;
-use crate::discovery::data_types::topic_data::DiscoveredWriterDataKey;
-use crate::discovery::data_types::topic_data::DiscoveredTopicDataKey;
-use crate::discovery::data_types::topic_data::ReaderProxy;
-use crate::network::util::get_local_multicast_locators;
-use crate::dds::data_types::SubscriptionBuiltinTopicData;
-use crate::dds::rtps_reader_proxy::RtpsReaderProxy;
-#[allow(unused_imports)]
-use log::{debug, error, warn, info, trace};
-
-use mio::{Ready, Poll, PollOpt, Events};
-use mio_extras::timer::Timer;
-use mio_extras::channel as mio_channel;
-
 use std::{
-  sync::{Arc, RwLock},
-  sync::RwLockReadGuard,
-  sync::RwLockWriteGuard,
-  time::Duration as StdDuration,
+  sync::{Arc, RwLock, RwLockReadGuard, RwLockWriteGuard},
+  time::{Duration as StdDuration, Instant},
 };
 
+#[allow(unused_imports)]
+use log::{debug, error, info, trace, warn};
+use mio::{Events, Poll, PollOpt, Ready};
+use mio_extras::{channel as mio_channel, timer::Timer};
+
 use crate::{
   dds::{
-    with_key::datareader::DataReader,
-    with_key::datareader::DataReaderCdr,
-    /*with_key::datawriter::DataWriter,*/ with_key::datawriter::DataWriterCdr,
-    topic::*,
-    participant::{DomainParticipantWeak},
-    Publisher, Subscriber,
+    data_types::SubscriptionBuiltinTopicData,
+    participant::DomainParticipantWeak,
     qos::{
-      QosPolicies,
       policy::{
-        Reliability, History, Durability, Presentation, PresentationAccessScope, Deadline,
-        Ownership, Liveliness, TimeBasedFilter, DestinationOrder,
+        Deadline, DestinationOrder, Durability, History, Liveliness, Ownership, Presentation,
+        PresentationAccessScope, Reliability, TimeBasedFilter,
       },
+      QosPolicies, QosPolicyBuilder,
     },
     readcondition::ReadCondition,
+    rtps_reader_proxy::RtpsReaderProxy,
+    topic::*,
+    values::result::{Error, Result},
+    with_key::{
+      datareader::{DataReader, DataReaderCdr},
+      datawriter::DataWriterCdr,
+    },
+    Publisher, Subscriber,
   },
-  dds::values::result::{Error, Result},
-  structure::entity::RTPSEntity,
-  structure::guid::{GUID, GuidPrefix},
-  dds::qos::QosPolicyBuilder,
-};
-
-use crate::discovery::{
-  data_types::spdp_participant_data::{
-    SpdpDiscoveredParticipantData, SpdpDiscoveredParticipantDataKey,
+  discovery::{
+    data_types::{
+      spdp_participant_data::{SpdpDiscoveredParticipantData, SpdpDiscoveredParticipantDataKey},
+      topic_data::{
+        DiscoveredReaderData, DiscoveredReaderDataKey, DiscoveredTopicDataKey,
+        DiscoveredWriterData, DiscoveredWriterDataKey, PublicationBuiltinTopicData, ReaderProxy,
+        WriterProxy,
+      },
+    },
+    discovery_db::DiscoveryDB,
+  },
+  network::{
+    constant::*,
+    util::{get_local_multicast_locators, get_local_unicast_socket_address},
+  },
+  serialization::pl_cdr_deserializer::PlCdrDeserializerAdapter,
+  structure::{
+    duration::Duration,
+    entity::RTPSEntity,
+    guid::{EntityId, GuidPrefix, GUID},
+    time::Timestamp,
   },
-  data_types::topic_data::{DiscoveredWriterData, DiscoveredReaderData},
-  discovery_db::DiscoveryDB,
 };
-
-use crate::structure::{duration::Duration, guid::EntityId, time::Timestamp};
-
-use crate::serialization::{pl_cdr_deserializer::PlCdrDeserializerAdapter};
-
-use crate::network::constant::*;
 use super::data_types::topic_data::{
   DiscoveredTopicData, ParticipantMessageData, ParticipantMessageDataKind,
 };
@@ -105,6 +97,7 @@ pub(crate) struct Discovery {
   discovery_updated_sender: mio_channel::SyncSender<DiscoveryNotificationType>,
   // Discovery gets commands from dp_event_loop from this channel
   discovery_command_receiver: mio_channel::Receiver<DiscoveryCommand>,
+  spdp_liveness_receiver: mio_channel::Receiver<GuidPrefix>,
 
   liveliness_state: LivelinessState,
 
@@ -183,6 +176,7 @@ impl Discovery {
     discovery_started_sender: std::sync::mpsc::Sender<Result<()>>,
     discovery_updated_sender: mio_channel::SyncSender<DiscoveryNotificationType>,
     discovery_command_receiver: mio_channel::Receiver<DiscoveryCommand>,
+    spdp_liveness_receiver: mio_channel::Receiver<GuidPrefix>,
   ) -> Result<Discovery> {
     // helper macro to handle initialization failures.
     macro_rules! try_construct {
@@ -212,6 +206,16 @@ impl Discovery {
       "Failed to register Discovery poll. {:?}"
     );
 
+    try_construct!(
+      poll.register(
+        &spdp_liveness_receiver,
+        SPDP_LIVENESS_TOKEN,
+        Ready::readable(),
+        PollOpt::edge(),
+      ),
+      "Failed to register Discovery poll. {:?}"
+    );
+
     let discovery_subscriber_qos = Discovery::subscriber_qos();
     let discovery_publisher_qos = Discovery::publisher_qos();
 
@@ -240,13 +244,13 @@ impl Discovery {
     let dcps_participant_reader = try_construct!( discovery_subscriber
       .create_datareader_with_entityid::<SpdpDiscoveredParticipantData,PlCdrDeserializerAdapter<SpdpDiscoveredParticipantData>>(
         dcps_participant_topic.clone(),
-        EntityId::ENTITYID_SPDP_BUILTIN_PARTICIPANT_READER,
+        EntityId::SPDP_BUILTIN_PARTICIPANT_READER,
         None,
       ) ,"Unable to create DataReader for DCPSParticipant. {:?}");
 
     let dcps_participant_writer = try_construct!(
       discovery_publisher.create_datawriter_cdr_with_entityid::<SpdpDiscoveredParticipantData>(
-        EntityId::ENTITYID_SPDP_BUILTIN_PARTICIPANT_WRITER,
+        EntityId::SPDP_BUILTIN_PARTICIPANT_WRITER,
         dcps_participant_topic.clone(),
         None,
       ),
@@ -291,7 +295,8 @@ impl Discovery {
       "Unable to register participant info sender. {:?}"
     );
 
-    // Subscriptions: What are the Readers on the network and what are they subscribing to?
+    // Subscriptions: What are the Readers on the network and what are they
+    // subscribing to?
 
     let dcps_subscription_topic = try_construct!(
       domain_participant.create_topic(
@@ -306,7 +311,7 @@ impl Discovery {
     let dcps_subscription_reader = try_construct!( discovery_subscriber
       .create_datareader_with_entityid::<DiscoveredReaderData, PlCdrDeserializerAdapter<DiscoveredReaderData>>(
         dcps_subscription_topic.clone(),
-        EntityId::ENTITYID_SEDP_BUILTIN_SUBSCRIPTIONS_READER,
+        EntityId::SEDP_BUILTIN_SUBSCRIPTIONS_READER,
         None,
       ) ,"Unable to create DataReader for DCPSSubscription. {:?}");
 
@@ -322,7 +327,7 @@ impl Discovery {
 
     let dcps_subscription_writer = try_construct!(
       discovery_publisher.create_datawriter_cdr_with_entityid::<DiscoveredReaderData>(
-        EntityId::ENTITYID_SEDP_BUILTIN_SUBSCRIPTIONS_WRITER,
+        EntityId::SEDP_BUILTIN_SUBSCRIPTIONS_WRITER,
         dcps_subscription_topic.clone(),
         None,
       ),
@@ -356,7 +361,7 @@ impl Discovery {
     let dcps_publication_reader = try_construct!( discovery_subscriber
       .create_datareader_with_entityid::<DiscoveredWriterData, PlCdrDeserializerAdapter<DiscoveredWriterData>>(
         dcps_publication_topic.clone(),
-        EntityId::ENTITYID_SEDP_BUILTIN_PUBLICATIONS_READER,
+        EntityId::SEDP_BUILTIN_PUBLICATIONS_READER,
         None,
       ) ,"Unable to create DataReader for DCPSPublication. {:?}");
 
@@ -372,7 +377,7 @@ impl Discovery {
 
     let dcps_publication_writer = try_construct!(
       discovery_publisher.create_datawriter_cdr_with_entityid::<DiscoveredWriterData>(
-        EntityId::ENTITYID_SEDP_BUILTIN_PUBLICATIONS_WRITER,
+        EntityId::SEDP_BUILTIN_PUBLICATIONS_WRITER,
         dcps_publication_topic.clone(),
         None,
       ),
@@ -406,7 +411,7 @@ impl Discovery {
     let dcps_topic_reader = try_construct!( discovery_subscriber
       .create_datareader_with_entityid::<DiscoveredTopicData, PlCdrDeserializerAdapter<DiscoveredTopicData>>(
         dcps_topic_topic.clone(),
-        EntityId::ENTITYID_SEDP_BUILTIN_TOPIC_READER,
+        EntityId::SEDP_BUILTIN_TOPIC_READER,
         None,
       ) ,"Unable to create DataReader for DCPSTopic. {:?}");
 
@@ -422,7 +427,7 @@ impl Discovery {
 
     let dcps_topic_writer = try_construct!(
       discovery_publisher.create_datawriter_cdr_with_entityid::<DiscoveredTopicData>(
-        EntityId::ENTITYID_SEDP_BUILTIN_TOPIC_WRITER,
+        EntityId::SEDP_BUILTIN_TOPIC_WRITER,
         dcps_topic_topic.clone(),
         None,
       ),
@@ -469,7 +474,7 @@ impl Discovery {
     let dcps_participant_message_reader = try_construct!(
       discovery_subscriber.create_datareader_cdr_with_entityid::<ParticipantMessageData>(
         participant_message_topic.clone(),
-        EntityId::ENTITYID_P2P_BUILTIN_PARTICIPANT_MESSAGE_READER,
+        EntityId::P2P_BUILTIN_PARTICIPANT_MESSAGE_READER,
         None,
       ),
       "Unable to create DCPSParticipantMessage reader. {:?}"
@@ -487,7 +492,7 @@ impl Discovery {
 
     let dcps_participant_message_writer = try_construct!(
       discovery_publisher.create_datawriter_cdr_with_entityid::<ParticipantMessageData>(
-        EntityId::ENTITYID_P2P_BUILTIN_PARTICIPANT_MESSAGE_WRITER,
+        EntityId::P2P_BUILTIN_PARTICIPANT_MESSAGE_WRITER,
         participant_message_topic.clone(),
         None,
       ),
@@ -513,6 +518,7 @@ impl Discovery {
       discovery_started_sender,
       discovery_updated_sender,
       discovery_command_receiver,
+      spdp_liveness_receiver,
 
       liveliness_state: LivelinessState::new(),
 
@@ -602,7 +608,7 @@ impl Discovery {
                   self
                     .dcps_participant_writer
                     .dispose(
-                      SpdpDiscoveredParticipantDataKey(self.domain_participant.get_guid()),
+                      SpdpDiscoveredParticipantDataKey(self.domain_participant.guid()),
                       None,
                     )
                     .unwrap_or(());
@@ -610,7 +616,7 @@ impl Discovery {
                   return; // terminate event loop
                 }
                 DiscoveryCommand::RemoveLocalWriter { guid } => {
-                  if guid == self.dcps_publication_writer.get_guid() {
+                  if guid == self.dcps_publication_writer.guid() {
                     continue;
                   }
                   self
@@ -627,7 +633,7 @@ impl Discovery {
                   }
                 }
                 DiscoveryCommand::RemoveLocalReader { guid } => {
-                  if guid == self.dcps_subscription_writer.get_guid() {
+                  if guid == self.dcps_subscription_writer.guid() {
                     continue;
                   }
 
@@ -684,7 +690,8 @@ impl Discovery {
               }
             };
 
-            // setting 5 times the duration so lease doesn't break if update fails once or twice
+            // setting 5 times the duration so lease doesn't break if update fails once or
+            // twice
             let data = SpdpDiscoveredParticipantData::from_local_participant(
               &strong_dp,
               5.0 * Duration::from(Discovery::SEND_PARTICIPANT_INFO_PERIOD),
@@ -745,6 +752,17 @@ impl Discovery {
               .dcps_participant_message_timer
               .set_timeout(Discovery::CHECK_PARTICIPANT_MESSAGES, ());
           }
+          SPDP_LIVENESS_TOKEN => {
+            while let Ok(guid_prefix) = self.spdp_liveness_receiver.try_recv() {
+              match self.discovery_db.write() {
+                Ok(mut db) => db.participant_is_alive(guid_prefix),
+                Err(e) => {
+                  error!("DiscoveryDB is poisoned. {:?}", e);
+                  return;
+                }
+              }
+            }
+          }
           other_token => {
             error!("discovery event loop got token: {:?}", other_token);
           }
@@ -757,7 +775,8 @@ impl Discovery {
   // That causes ReaderProxies and WriterProxies to be constructed and
   // and we also get our own local readers and writers connected, both
   // built-in and user-defined.
-  // If we did not do this, the Readers and Writers in this participant could not find each other.
+  // If we did not do this, the Readers and Writers in this participant could not
+  // find each other.
   fn initialize_participant(&self) {
     let dp = match self.domain_participant.clone().upgrade() {
       Some(dp) => dp,
@@ -767,13 +786,14 @@ impl Discovery {
       }
     };
 
-    let mc_port = get_spdp_well_known_multicast_port(dp.domain_id());
-    let uc_port = get_spdp_well_known_unicast_port(dp.domain_id(), dp.participant_id());
+    let mc_port = spdp_well_known_multicast_port(dp.domain_id());
+    let uc_port = spdp_well_known_unicast_port(dp.domain_id(), dp.participant_id());
 
     let participant_data =
       SpdpDiscoveredParticipantData::from_local_participant(&dp, Duration::DURATION_INFINITE);
 
-    // Initialize our own particiapnt data into the Discovery DB, so we can talk to ourself.
+    // Initialize our own particiapnt data into the Discovery DB, so we can talk to
+    // ourself.
     self
       .discovery_db_write()
       .update_participant(&participant_data);
@@ -781,13 +801,14 @@ impl Discovery {
     // This will read the participant from Discovery DB and construct
     // ReaderProxy and WriterProxy objects for built-in Readers and Writers
     self.send_discovery_notification(DiscoveryNotificationType::ParticipantUpdated {
-      guid_prefix: dp.get_guid().guid_prefix,
+      guid_prefix: dp.guid().guid_prefix,
     });
 
-    // insert a (fake) reader proxy as multicast address, so discovery notifications are sent somewhere
+    // insert a (fake) reader proxy as multicast address, so discovery notifications
+    // are sent somewhere
     let reader_guid = GUID::new_with_prefix_and_id(
-      GuidPrefix::GUIDPREFIX_UNKNOWN,
-      EntityId::ENTITYID_SPDP_BUILTIN_PARTICIPANT_READER,
+      GuidPrefix::UNKNOWN,
+      EntityId::SPDP_BUILTIN_PARTICIPANT_READER,
     );
 
     let mut reader_proxy = ReaderProxy::new(reader_guid);
@@ -806,8 +827,8 @@ impl Discovery {
     };
 
     let writer_guid = GUID::new_with_prefix_and_id(
-      dp.get_guid().guid_prefix,
-      EntityId::ENTITYID_SPDP_BUILTIN_PARTICIPANT_WRITER,
+      dp.guid().guid_prefix,
+      EntityId::SPDP_BUILTIN_PARTICIPANT_WRITER,
     );
 
     let writer_proxy = WriterProxy::new(
@@ -818,7 +839,7 @@ impl Discovery {
 
     let pub_topic_data = PublicationBuiltinTopicData::new(
       writer_guid,
-      dp.get_guid(),
+      dp.guid(),
       String::from("DCPSParticipant"),
       String::from("SPDPDiscoveredParticipantData"),
     );
@@ -851,7 +872,8 @@ impl Discovery {
         Ok(Some(d)) => match d.value {
           Ok(participant_data) => {
             let participant_data = participant_data.clone(); // .clone() is necessary, because .read
-                                                             // returns references to within Reader, so we cannot operate on self until we clone.
+                                                             // returns references to within Reader, so we cannot operate on self until we
+                                                             // clone.
             debug!(
               "handle_participant_reader discovered {:?}",
               &participant_data
@@ -1120,7 +1142,7 @@ impl Discovery {
       if let Some(&mm) = min_automatic {
         if current_duration > mm {
           let pp = ParticipantMessageData {
-            guid: self.domain_participant.get_guid_prefix(),
+            guid: self.domain_participant.guid_prefix(),
             kind:
               ParticipantMessageDataKind::PARTICIPANT_MESSAGE_DATA_KIND_AUTOMATIC_LIVELINESS_UPDATE,
             data: Vec::new(),
@@ -1152,7 +1174,7 @@ impl Discovery {
       if let Some(&dur) = min_manual_participant {
         if current_duration > dur {
           let pp = ParticipantMessageData {
-            guid: self.domain_participant.get_guid_prefix(),
+            guid: self.domain_participant.guid_prefix(),
             kind:
               ParticipantMessageDataKind::PARTICIPANT_MESSAGE_DATA_KIND_MANUAL_LIVELINESS_UPDATE,
             data: Vec::new(),
@@ -1207,11 +1229,11 @@ impl Discovery {
       // filtering out discoveries own readers
       .filter(|p| {
         let eid = p.reader_proxy.remote_reader_guid.entity_id;
-        eid != EntityId::ENTITYID_SPDP_BUILTIN_PARTICIPANT_READER
-          && eid != EntityId::ENTITYID_SEDP_BUILTIN_SUBSCRIPTIONS_READER
-          && eid != EntityId::ENTITYID_SEDP_BUILTIN_PUBLICATIONS_READER
-          && eid != EntityId::ENTITYID_SEDP_BUILTIN_TOPIC_READER
-          && eid != EntityId::ENTITYID_P2P_BUILTIN_PARTICIPANT_MESSAGE_READER
+        eid != EntityId::SPDP_BUILTIN_PARTICIPANT_READER
+          && eid != EntityId::SEDP_BUILTIN_SUBSCRIPTIONS_READER
+          && eid != EntityId::SEDP_BUILTIN_PUBLICATIONS_READER
+          && eid != EntityId::SEDP_BUILTIN_TOPIC_READER
+          && eid != EntityId::P2P_BUILTIN_PARTICIPANT_MESSAGE_READER
       })
     {
       match self.dcps_subscription_writer.write(data.clone(), None) {
@@ -1227,11 +1249,11 @@ impl Discovery {
     for data in datas.filter(|p| {
       let eid = p.writer_proxy.remote_writer_guid.entity_id;
 
-      eid != EntityId::ENTITYID_SPDP_BUILTIN_PARTICIPANT_WRITER
-        && eid != EntityId::ENTITYID_SEDP_BUILTIN_SUBSCRIPTIONS_WRITER
-        && eid != EntityId::ENTITYID_SEDP_BUILTIN_PUBLICATIONS_WRITER
-        && eid != EntityId::ENTITYID_SEDP_BUILTIN_TOPIC_WRITER
-        && eid != EntityId::ENTITYID_P2P_BUILTIN_PARTICIPANT_MESSAGE_WRITER
+      eid != EntityId::SPDP_BUILTIN_PARTICIPANT_WRITER
+        && eid != EntityId::SEDP_BUILTIN_SUBSCRIPTIONS_WRITER
+        && eid != EntityId::SEDP_BUILTIN_PUBLICATIONS_WRITER
+        && eid != EntityId::SEDP_BUILTIN_TOPIC_WRITER
+        && eid != EntityId::P2P_BUILTIN_PARTICIPANT_MESSAGE_WRITER
     }) {
       match self.dcps_publication_writer.write(data.clone(), None) {
         Ok(_) => (),
@@ -1242,7 +1264,7 @@ impl Discovery {
 
   pub fn write_topic_info(&self) {
     let db = self.discovery_db_read();
-    let datas = db.get_all_topics();
+    let datas = db.all_topics();
     for data in datas {
       match self.dcps_topic_writer.write(data.clone(), None) {
         Ok(_) => (),
@@ -1346,33 +1368,33 @@ impl Discovery {
 
 #[cfg(test)]
 mod tests {
+  use std::net::SocketAddr;
+
+  use bytes::Bytes;
+  use mio::Token;
+  use speedy::{Endianness, Writable};
+
   use super::*;
   use crate::{
+    dds::{participant::DomainParticipant, traits::serde_adapters::no_key::DeserializerAdapter},
+    discovery::data_types::topic_data::TopicBuiltinTopicData,
+    messages::submessages::{
+      submessage_elements::serialized_payload::RepresentationIdentifier,
+      submessages::{EntitySubmessage, InterpreterSubmessage},
+    },
+    network::{udp_listener::UDPListener, udp_sender::UDPSender},
+    serialization::{
+      cdr_deserializer::CDRDeserializerAdapter, cdr_serializer::to_bytes, submessage::*,
+    },
+    structure::{entity::RTPSEntity, locator::Locator},
     test::{
       shape_type::ShapeType,
       test_data::{
-        spdp_subscription_msg, spdp_publication_msg, spdp_participant_msg_mod,
-        create_rtps_data_message,
+        create_rtps_data_message, spdp_participant_msg_mod, spdp_publication_msg,
+        spdp_subscription_msg,
       },
     },
-    network::{udp_listener::UDPListener, udp_sender::UDPSender},
-    structure::{entity::RTPSEntity, locator::Locator},
-    serialization::{cdr_serializer::to_bytes, cdr_deserializer::CDRDeserializerAdapter},
-    messages::submessages::submessages::{InterpreterSubmessage, EntitySubmessage},
-    messages::{
-      submessages::submessage_elements::serialized_payload::{RepresentationIdentifier},
-    },
   };
-  use crate::{
-    discovery::data_types::topic_data::TopicBuiltinTopicData,
-    dds::{participant::DomainParticipant, traits::serde_adapters::no_key::DeserializerAdapter},
-  };
-  use crate::serialization::submessage::*;
-
-  use std::{net::SocketAddr};
-  use bytes::Bytes;
-  use mio::Token;
-  use speedy::{Writable, Endianness};
 
   #[test]
   fn discovery_participant_data_test() {
@@ -1391,7 +1413,7 @@ mod tests {
     let udp_sender = UDPSender::new_with_random_port().expect("failed to create UDPSender");
     let addresses = vec![SocketAddr::new(
       "127.0.0.1".parse().unwrap(),
-      get_spdp_well_known_unicast_port(0, 0),
+      spdp_well_known_unicast_port(0, 0),
     )];
 
     let tdata = spdp_participant_msg_mod(11000);
@@ -1407,7 +1429,8 @@ mod tests {
       .unwrap();
 
     let _data2 = udp_listener.get_message();
-    // TODO: we should have received our own participants info decoding the actual message might be good idea
+    // TODO: we should have received our own participants info decoding the
+    // actual message might be good idea
   }
 
   #[test]
@@ -1450,7 +1473,7 @@ mod tests {
     let udp_sender = UDPSender::new_with_random_port().expect("failed to create UDPSender");
     let addresses = vec![SocketAddr::new(
       "127.0.0.1".parse().unwrap(),
-      get_spdp_well_known_unicast_port(14, 0),
+      spdp_well_known_unicast_port(14, 0),
     )];
 
     let mut tdata = spdp_subscription_msg();
@@ -1538,7 +1561,7 @@ mod tests {
     let udp_sender = UDPSender::new_with_random_port().expect("failed to create UDPSender");
     let addresses = vec![SocketAddr::new(
       "127.0.0.1".parse().unwrap(),
-      get_spdp_well_known_unicast_port(15, 0),
+      spdp_well_known_unicast_port(15, 0),
     )];
 
     let mut tdata = spdp_publication_msg();
@@ -1546,7 +1569,7 @@ mod tests {
       match &mut submsg.body {
         SubmessageBody::Interpreter(v) => match v {
           InterpreterSubmessage::InfoDestination(dst, _flags) => {
-            dst.guid_prefix = participant.get_guid_prefix();
+            dst.guid_prefix = participant.guid_prefix();
           }
           _ => continue,
         },
@@ -1570,7 +1593,7 @@ mod tests {
       .poll(&mut events, Some(StdDuration::from_secs(1)))
       .unwrap();
 
-    for _ in udp_listener.get_messages() {
+    for _ in udp_listener.messages() {
       info!("Message received");
     }
   }
@@ -1598,14 +1621,14 @@ mod tests {
 
     let rtps_message = create_rtps_data_message(
       topic_data,
-      EntityId::ENTITYID_SEDP_BUILTIN_TOPIC_READER,
-      EntityId::ENTITYID_SEDP_BUILTIN_TOPIC_WRITER,
+      EntityId::SEDP_BUILTIN_TOPIC_READER,
+      EntityId::SEDP_BUILTIN_TOPIC_WRITER,
     );
 
     let udp_sender = UDPSender::new_with_random_port().expect("failed to create UDPSender");
     let addresses = vec![SocketAddr::new(
       "127.0.0.1".parse().unwrap(),
-      get_spdp_well_known_unicast_port(16, 0),
+      spdp_well_known_unicast_port(16, 0),
     )];
 
     let rr = rtps_message
