@@ -1,34 +1,27 @@
 use std::{
-  collections::{HashMap, BTreeMap},
+  collections::{BTreeMap, HashMap},
   time::Instant,
 };
 
 #[allow(unused_imports)]
-use log::{error, warn, debug, trace, info};
-
-use crate::{dds::qos::HasQoSPolicy, structure::guid::GuidPrefix};
-
-use crate::structure::{
-  guid::GUID, guid::EntityId, duration::Duration, entity::RTPSEntity, locator::LocatorList,
-};
+use log::{debug, error, info, trace, warn};
 
 use crate::{
   dds::{
-    rtps_reader_proxy::RtpsReaderProxy,
-    reader::{ReaderIngredients},
-    participant::DomainParticipant,
-    topic::Topic,
-    traits::TopicDescription,
+    participant::DomainParticipant, qos::HasQoSPolicy, reader::ReaderIngredients,
+    rtps_reader_proxy::RtpsReaderProxy, topic::Topic, traits::TopicDescription,
+  },
+  structure::{
+    duration::Duration,
+    entity::RTPSEntity,
+    guid::{EntityId, GuidPrefix, GUID},
   },
 };
-
-use super::{
-  data_types::{
-    spdp_participant_data::SpdpDiscoveredParticipantData,
-    topic_data::{
-      DiscoveredReaderData, DiscoveredTopicData, DiscoveredWriterData, ParticipantMessageData,
-      ReaderProxy, SubscriptionBuiltinTopicData, TopicBuiltinTopicData,
-    },
+use super::data_types::{
+  spdp_participant_data::SpdpDiscoveredParticipantData,
+  topic_data::{
+    DiscoveredReaderData, DiscoveredTopicData, DiscoveredWriterData, ParticipantMessageData,
+    ReaderProxy, SubscriptionBuiltinTopicData, TopicBuiltinTopicData,
   },
 };
 
@@ -39,6 +32,8 @@ const DEFAULT_PARTICIPANT_LEASE_DURATION: Duration = Duration::from_secs(60);
 // How much longer to wait than lease duration before pronouncing lost.
 const PARTICIPANT_LEASE_DURATION_TOLREANCE: Duration = Duration::from_secs(0);
 
+// TODO: Let DiscoveryDB itself become thread-safe and support smaller-scope
+// lock
 pub(crate) struct DiscoveryDB {
   my_guid: GUID,
   participant_proxies: BTreeMap<GuidPrefix, SpdpDiscoveredParticipantData>,
@@ -54,12 +49,16 @@ pub(crate) struct DiscoveryDB {
 
   topics: HashMap<String, DiscoveredTopicData>,
 
+  event_sender: Option<mio_extras::channel::SyncSender<()>>,
   readers_updated: bool,
   writers_updated: bool,
 }
 
 impl DiscoveryDB {
-  pub fn new(my_guid: GUID) -> DiscoveryDB {
+  pub fn new(
+    my_guid: GUID,
+    event_sender: Option<mio_extras::channel::SyncSender<()>>,
+  ) -> DiscoveryDB {
     DiscoveryDB {
       my_guid,
       participant_proxies: BTreeMap::new(),
@@ -69,6 +68,7 @@ impl DiscoveryDB {
       external_topic_readers: BTreeMap::new(),
       external_topic_writers: BTreeMap::new(),
       topics: HashMap::new(),
+      event_sender,
       readers_updated: false,
       writers_updated: false,
     }
@@ -80,7 +80,7 @@ impl DiscoveryDB {
     let guid = data.participant_guid;
 
     // sanity check
-    if guid.entity_id != EntityId::ENTITYID_PARTICIPANT {
+    if guid.entity_id != EntityId::PARTICIPANT {
       error!(
         "Discovered participant GUID entity_id is not for participant: {:?}",
         guid
@@ -121,6 +121,18 @@ impl DiscoveryDB {
 
     new_participant
   }
+  pub fn participant_is_alive(&mut self, guid_prefix: GuidPrefix) {
+    match self.participant_last_life_signs.get_mut(&guid_prefix) {
+      Some(ts) => {
+        let now = Instant::now();
+        if now.duration_since(*ts) > std::time::Duration::from_secs(1) {
+          debug!("Participant alive update for {:?}, but no full update.", guid_prefix);
+        }
+        *ts = now;
+      }
+      None => info!("Participant alive update for unknown {:?}. This is normal, if the message does not repeat.", guid_prefix),
+    }
+  }
 
   pub fn remove_participant(&mut self, guid_prefix: GuidPrefix) {
     info!("removing participant {:?}", guid_prefix);
@@ -144,7 +156,8 @@ impl DiscoveryDB {
   }
 
   fn remove_topic_reader_with_prefix(&mut self, guid_prefix: GuidPrefix) {
-    // TODO: Implement this using .drain_filter() in BTreeMap once it lands in stable.
+    // TODO: Implement this using .drain_filter() in BTreeMap once it lands in
+    // stable.
     let to_remove: Vec<GUID> = self
       .external_topic_readers
       .range(guid_prefix.range())
@@ -161,7 +174,8 @@ impl DiscoveryDB {
   }
 
   fn remove_topic_writer_with_prefix(&mut self, guid_prefix: GuidPrefix) {
-    // TODO: Implement this using .drain_filter() in BTreeMap once it lands in stable.
+    // TODO: Implement this using .drain_filter() in BTreeMap once it lands in
+    // stable.
     let to_remove: Vec<GUID> = self
       .external_topic_writers
       .range(guid_prefix.range())
@@ -176,13 +190,14 @@ impl DiscoveryDB {
     self.external_topic_writers.remove(&guid);
   }
 
-  // Delete participant proxies, if we have not heard of them within lease_duration
+  // Delete participant proxies, if we have not heard of them within
+  // lease_duration
   pub fn participant_cleanup(&mut self) -> Vec<GuidPrefix> {
     let inow = Instant::now();
 
     let mut to_remove = Vec::new();
-    // TODO: We are not cleaning up liast_life_signs table, but that should not be a problem,
-    // except for a slight memory leak.
+    // TODO: We are not cleaning up liast_life_signs table, but that should not be a
+    // problem, except for a slight memory leak.
     for (&guid, sp) in self.participant_proxies.iter() {
       let lease_duration = sp
         .lease_duration
@@ -263,7 +278,7 @@ impl DiscoveryDB {
     }
   }
 
-  pub fn get_participants(&self) -> impl Iterator<Item = &SpdpDiscoveredParticipantData> {
+  pub fn participants(&self) -> impl Iterator<Item = &SpdpDiscoveredParticipantData> {
     self.participant_proxies.values()
   }
 
@@ -279,27 +294,25 @@ impl DiscoveryDB {
     self.writers_updated = true;
   }
 
-  pub fn get_external_reader_proxies<'a>(
-    &'a self,
-  ) -> impl Iterator<Item = &DiscoveredReaderData> + 'a {
+  pub fn external_reader_proxies<'a>(&'a self) -> impl Iterator<Item = &DiscoveredReaderData> + 'a {
     self.external_topic_readers.values()
   }
 
-  pub fn get_external_writer_proxies<'a>(
-    &'a self,
-  ) -> impl Iterator<Item = &DiscoveredWriterData> + 'a {
+  pub fn external_writer_proxies<'a>(&'a self) -> impl Iterator<Item = &DiscoveredWriterData> + 'a {
     self.external_topic_writers.values()
   }
 
   // TODO: This is silly. Returns one of the paramters cloned, or None
-  // TODO: Why are we here checking if discovery db already has this? What about reader proxies in writers?
+  // TODO: Why are we here checking if discovery db already has this? What about
+  // reader proxies in writers?
   pub fn update_subscription(
     &mut self,
     data: &DiscoveredReaderData,
   ) -> Option<(DiscoveredReaderData, RtpsReaderProxy)> {
     let guid = data.reader_proxy.remote_reader_guid;
     // we could return None to indicate that we already knew all about this reader
-    // To do that, we should check that the reader is the same as what we have in the DB already.
+    // To do that, we should check that the reader is the same as what we have in
+    // the DB already.
     match self.external_topic_readers.get(&guid) {
       Some(drd) if drd == data => None, // already have this
       _ => {
@@ -315,7 +328,7 @@ impl DiscoveryDB {
             )
           })
           .unwrap_or_else(|| {
-            if guid.guid_prefix != GuidPrefix::GUIDPREFIX_UNKNOWN {
+            if guid.guid_prefix != GuidPrefix::UNKNOWN {
               // This is normal, since we might not know about the participant yet.
               debug!(
                 "No remote participant known for {:?}\nSearched with {:?} in {:?}",
@@ -324,7 +337,7 @@ impl DiscoveryDB {
                 self.participant_proxies.keys()
               );
             }
-            (LocatorList::new(), LocatorList::new())
+            (Vec::default(), Vec::default())
           });
         debug!("External reader: {:?}", data);
         Some((
@@ -404,19 +417,19 @@ impl DiscoveryDB {
   pub fn update_topic_data_p(&mut self, topic: &Topic) {
     let topic_data = DiscoveredTopicData::new(TopicBuiltinTopicData {
       key: None,
-      name: topic.get_name(),
+      name: topic.name(),
       type_name: String::from(topic.get_type().name()),
-      durability: topic.get_qos().durability,
-      deadline: topic.get_qos().deadline,
-      latency_budget: topic.get_qos().latency_budget,
-      liveliness: topic.get_qos().liveliness,
-      reliability: topic.get_qos().reliability,
-      lifespan: topic.get_qos().lifespan,
-      destination_order: topic.get_qos().destination_order,
-      presentation: topic.get_qos().presentation,
-      history: topic.get_qos().history,
-      resource_limits: topic.get_qos().resource_limits,
-      ownership: topic.get_qos().ownership,
+      durability: topic.qos().durability,
+      deadline: topic.qos().deadline,
+      latency_budget: topic.qos().latency_budget,
+      liveliness: topic.qos().liveliness,
+      reliability: topic.qos().reliability,
+      lifespan: topic.qos().lifespan,
+      destination_order: topic.qos().destination_order,
+      presentation: topic.qos().presentation,
+      history: topic.qos().history,
+      resource_limits: topic.qos().resource_limits,
+      ownership: topic.qos().ownership,
     });
 
     self.update_topic_data(&topic_data);
@@ -430,6 +443,9 @@ impl DiscoveryDB {
       Some(t) => *t = data.clone(),
       None => {
         self.topics.insert(topic_name, data.clone());
+        if let Some(c) = &self.event_sender {
+          let _ = c.try_send(());
+        }
       }
     };
 
@@ -453,11 +469,11 @@ impl DiscoveryDB {
 
     let mut subscription_data = SubscriptionBuiltinTopicData::new(
       reader_guid,
-      topic.get_name(),
+      topic.name(),
       topic.get_type().name().to_string(),
-      &topic.get_qos(),
+      &topic.qos(),
     );
-    subscription_data.set_participant_key(domain_participant.get_guid());
+    subscription_data.set_participant_key(domain_participant.guid());
 
     // TODO: possibly change content filter to dynamic value
     let content_filter = None;
@@ -504,7 +520,7 @@ impl DiscoveryDB {
     self.local_topic_writers.iter().map(|(_, p)| p)
   }
 
-  pub fn get_all_topics(&self) -> impl Iterator<Item = &DiscoveredTopicData> {
+  pub fn all_topics(&self) -> impl Iterator<Item = &DiscoveredTopicData> {
     self
       .topics
       .iter()
@@ -512,13 +528,21 @@ impl DiscoveryDB {
       .map(|(_, v)| v)
   }
 
+  pub fn get_topic(&self, topic_name: &str) -> Option<&DiscoveredTopicData> {
+    self.topics.get(topic_name)
+  }
+
+  pub fn new_topic_token() -> mio::Token {
+    mio::Token(0)
+  }
+
   // // TODO: return iterator somehow?
   #[cfg(test)] // used only for testing
   pub fn get_local_topic_readers<'a, T: TopicDescription>(
     &'a self,
     topic: &'a T,
   ) -> Vec<&DiscoveredReaderData> {
-    let topic_name = topic.get_name();
+    let topic_name = topic.name();
     self
       .local_topic_readers
       .iter()
@@ -540,32 +564,32 @@ impl DiscoveryDB {
 #[cfg(test)]
 
 mod tests {
-  use super::*;
+  use std::{
+    rc::Rc,
+    sync::{Arc, RwLock},
+    time::Duration as StdDuration,
+  };
 
+  use byteorder::LittleEndian;
+
+  use super::*;
   use crate::{
-    dds::qos::QosPolicies,
-    structure::dds_cache::DDSCache,
-    dds::topic::TopicKind,
+    dds::{
+      qos::QosPolicies, reader::Reader, statusevents::DataReaderStatus, topic::TopicKind,
+      with_key::datareader::ReaderCommand,
+    },
+    network::udp_sender::UDPSender,
+    serialization::cdr_serializer::CDRSerializerAdapter,
+    structure::{dds_cache::DDSCache, guid::*},
     test::{
       random_data::RandomData,
-      test_data::{subscription_builtin_topic_data, spdp_participant_data, reader_proxy_data},
+      test_data::{reader_proxy_data, spdp_participant_data, subscription_builtin_topic_data},
     },
   };
-  use std::sync::{RwLock, Arc};
-  use std::rc::Rc;
-
-  use crate::network::udp_sender::UDPSender;
-  use crate::dds::reader::Reader;
-  use crate::structure::guid::*;
-  use crate::serialization::cdr_serializer::CDRSerializerAdapter;
-  use byteorder::LittleEndian;
-  use std::time::Duration as StdDuration;
-  use crate::dds::statusevents::DataReaderStatus;
-  use crate::dds::with_key::datareader::ReaderCommand;
 
   #[test]
   fn discdb_participant_operations() {
-    let mut discoverydb = DiscoveryDB::new(GUID::new_particiapnt_guid());
+    let mut discoverydb = DiscoveryDB::new(GUID::new_particiapnt_guid(), None);
     let mut data = spdp_participant_data().unwrap();
     data.lease_duration = Some(Duration::from(StdDuration::from_secs(1)));
 
@@ -584,7 +608,7 @@ mod tests {
 
   #[test]
   fn discdb_writer_proxies() {
-    let _discoverydb = DiscoveryDB::new(GUID::new_particiapnt_guid());
+    let _discoverydb = DiscoveryDB::new(GUID::new_particiapnt_guid(), None);
     let topic_name = String::from("some_topic");
     let type_name = String::from("RandomData");
     let _dreader = DiscoveredReaderData::default(topic_name, type_name);
@@ -594,7 +618,7 @@ mod tests {
 
   #[test]
   fn discdb_subscription_operations() {
-    let mut discovery_db = DiscoveryDB::new(GUID::new_particiapnt_guid());
+    let mut discovery_db = DiscoveryDB::new(GUID::new_particiapnt_guid(), None);
 
     let domain_participant = DomainParticipant::new(0).expect("Failed to create publisher");
     let topic = domain_participant
@@ -648,7 +672,7 @@ mod tests {
     let reader1 = reader_proxy_data().unwrap();
     let mut reader1sub = subscription_builtin_topic_data().unwrap();
     reader1sub.set_key(reader1.remote_reader_guid);
-    reader1sub.set_topic_name(&topic.get_name());
+    reader1sub.set_topic_name(&topic.name());
     let dreader1 = DiscoveredReaderData {
       reader_proxy: reader1.clone(),
       subscription_topic_data: reader1sub.clone(),
@@ -659,7 +683,7 @@ mod tests {
     let reader2 = reader_proxy_data().unwrap();
     let mut reader2sub = subscription_builtin_topic_data().unwrap();
     reader2sub.set_key(reader2.remote_reader_guid);
-    reader2sub.set_topic_name(&topic2.get_name());
+    reader2sub.set_topic_name(&topic2.name());
     let dreader2 = DiscoveredReaderData {
       reader_proxy: reader2,
       subscription_topic_data: reader2sub,
@@ -690,10 +714,10 @@ mod tests {
         TopicKind::WithKey,
       )
       .unwrap();
-    let mut discoverydb = DiscoveryDB::new(GUID::new_particiapnt_guid());
+    let mut discoverydb = DiscoveryDB::new(GUID::new_particiapnt_guid(), None);
 
     let (notification_sender, _notification_receiver) = mio_extras::channel::sync_channel(100);
-    let (status_sender, _status_reciever) =
+    let (status_sender, _status_receiver) =
       mio_extras::channel::sync_channel::<DataReaderStatus>(100);
     let (_reader_commander1, reader_command_receiver1) =
       mio_extras::channel::sync_channel::<ReaderCommand>(100);
@@ -704,7 +728,7 @@ mod tests {
       guid: GUID::dummy_test_guid(EntityKind::READER_NO_KEY_USER_DEFINED),
       notification_sender: notification_sender.clone(),
       status_sender: status_sender.clone(),
-      topic_name: topic.get_name(),
+      topic_name: topic.name(),
       qos_policy: QosPolicies::qos_none(),
       data_reader_command_receiver: reader_command_receiver1,
     };
@@ -732,9 +756,9 @@ mod tests {
           entity_kind: EntityKind::READER_NO_KEY_USER_DEFINED,
         },
       ), // GUID needs to be different in order to be added
-      notification_sender: notification_sender.clone(),
-      status_sender: status_sender.clone(),
-      topic_name: topic.get_name().to_string(),
+      notification_sender,
+      status_sender,
+      topic_name: topic.name(),
       qos_policy: QosPolicies::qos_none(),
       data_reader_command_receiver: reader_command_receiver2,
     };
