@@ -1,65 +1,60 @@
 use std::time::Instant;
 
 use serde::Deserialize;
-
 use chrono::Utc;
-
-use log::{warn, error};
-
-use crate::{
-  log_and_err_discovery,
-  dds::{qos::QosPolicyBuilder},
-  structure::{
-    guid::GUID,
-    parameter_id::ParameterId,
-    locator::{LocatorList, Locator},
-    builtin_endpoint::{BuiltinEndpointSet, BuiltinEndpointQos},
-    duration::Duration,
-    endpoint::ReliabilityKind,
-  },
-};
-
-use crate::messages::{
-  protocol_version::ProtocolVersion, vendor_id::VendorId,
-  submessages::submessage_elements::serialized_payload::RepresentationIdentifier,
-};
-
-use crate::serialization::{error::Error};
+use log::{error, warn};
 
 use crate::{
   dds::{
-    qos::policy::{
-      Deadline, Durability, LatencyBudget, Liveliness, Reliability, Ownership, DestinationOrder,
-      TimeBasedFilter, Presentation, Lifespan, History, ResourceLimits,
+    qos::{
+      policy::{
+        Deadline, DestinationOrder, Durability, History, LatencyBudget, Lifespan, Liveliness,
+        Ownership, Presentation, Reliability, ResourceLimits, TimeBasedFilter,
+      },
+      QosPolicyBuilder,
     },
     traits::serde_adapters::no_key::*,
   },
   discovery::{
     content_filter_property::ContentFilterProperty,
     data_types::{
-      topic_data::{
-        SubscriptionBuiltinTopicData, ReaderProxy, DiscoveredReaderData, WriterProxy,
-        PublicationBuiltinTopicData, DiscoveredWriterData, TopicBuiltinTopicData,
-        DiscoveredReaderDataKey, DiscoveredWriterDataKey,
-      },
       spdp_participant_data::{SpdpDiscoveredParticipantData, SpdpDiscoveredParticipantDataKey},
+      topic_data::{
+        DiscoveredReaderData, DiscoveredReaderDataKey, DiscoveredWriterData,
+        DiscoveredWriterDataKey, PublicationBuiltinTopicData, ReaderProxy,
+        SubscriptionBuiltinTopicData, TopicBuiltinTopicData, WriterProxy,
+      },
     },
   },
+  log_and_err_discovery,
+  messages::{
+    protocol_version::ProtocolVersion,
+    submessages::submessage_elements::serialized_payload::RepresentationIdentifier,
+    vendor_id::VendorId,
+  },
+  serialization::error::Error,
+  structure::{
+    builtin_endpoint::{BuiltinEndpointQos, BuiltinEndpointSet},
+    duration::Duration,
+    endpoint::ReliabilityKind,
+    guid::GUID,
+    locator::Locator,
+    parameter_id::ParameterId,
+  },
 };
-
 use super::cdr_deserializer::CDRDeserializerAdapter;
 
-#[derive(Debug)]
+#[derive(Debug, Default)]
 pub struct BuiltinDataDeserializer {
   // Participant Data
   pub protocol_version: Option<ProtocolVersion>,
   pub vendor_id: Option<VendorId>,
   pub expects_inline_qos: Option<bool>,
   pub participant_guid: Option<GUID>,
-  pub metatraffic_unicast_locators: LocatorList,
-  pub metatraffic_multicast_locators: LocatorList,
-  pub default_unicast_locators: LocatorList,
-  pub default_multicast_locators: LocatorList,
+  pub metatraffic_unicast_locators: Vec<Locator>,
+  pub metatraffic_multicast_locators: Vec<Locator>,
+  pub default_unicast_locators: Vec<Locator>,
+  pub default_multicast_locators: Vec<Locator>,
   pub available_builtin_endpoints: Option<BuiltinEndpointSet>,
   pub lease_duration: Option<Duration>,
   pub manual_liveliness_count: Option<i32>,
@@ -70,8 +65,8 @@ pub struct BuiltinDataDeserializer {
   pub endpoint_guid: Option<GUID>,
 
   // Reader Proxy
-  pub unicast_locator_list: LocatorList,
-  pub multicast_locator_list: LocatorList,
+  pub unicast_locator_list: Vec<Locator>,
+  pub multicast_locator_list: Vec<Locator>,
 
   // Writer Proxy
   pub data_max_size_serialized: Option<u32>,
@@ -97,45 +92,7 @@ pub struct BuiltinDataDeserializer {
 
 impl BuiltinDataDeserializer {
   pub fn new() -> BuiltinDataDeserializer {
-    BuiltinDataDeserializer {
-      protocol_version: None,
-      vendor_id: None,
-      expects_inline_qos: None,
-      participant_guid: None,
-      metatraffic_unicast_locators: LocatorList::new(),
-      metatraffic_multicast_locators: LocatorList::new(),
-      default_unicast_locators: LocatorList::new(),
-      default_multicast_locators: LocatorList::new(),
-      available_builtin_endpoints: None,
-      lease_duration: None,
-      manual_liveliness_count: None,
-      builtin_endpoint_qos: None,
-      entity_name: None,
-      sentinel: None,
-
-      endpoint_guid: None,
-      unicast_locator_list: LocatorList::new(),
-      multicast_locator_list: LocatorList::new(),
-
-      data_max_size_serialized: None,
-
-      topic_name: None,
-      type_name: None,
-      durability: None,
-      deadline: None,
-      latency_budget: None,
-      liveliness: None,
-      reliability: None,
-      ownership: None,
-      destination_order: None,
-      time_based_filter: None,
-      presentation: None,
-      lifespan: None,
-      history: None,
-      resource_limits: None,
-
-      content_filter_property: None,
-    }
+    Self::default()
   }
 
   pub fn generate_spdp_participant_data(&self) -> Result<SpdpDiscoveredParticipantData, Error> {
