@@ -1,40 +1,41 @@
 // use crate::discovery::data_types::topic_data::PublicationBuiltinTopicDataKey;
-// use crate::discovery::data_types::topic_data::SubscriptionBuiltinTopicDataKey;
-use crate::discovery::data_types::topic_data::DiscoveredReaderDataKey;
-use crate::discovery::data_types::topic_data::DiscoveredWriterDataKey;
+// use crate::discovery::data_types::topic_data::
+// SubscriptionBuiltinTopicDataKey;
+use std::time::Duration as StdDuration;
+
+use serde::{ser::SerializeStruct, Deserialize, Serialize, Serializer};
+
 use crate::{
-  structure::{
-    locator::{LocatorList, LocatorData},
-    parameter_id::ParameterId,
-    guid::{GUID, GUIDData},
-    builtin_endpoint::{
-      BuiltinEndpointQosData, BuiltinEndpointSetData, BuiltinEndpointSet, BuiltinEndpointQos,
-    },
-    duration::{Duration, DurationData},
-    endpoint::ReliabilityKind,
+  dds::qos::policy::{
+    Deadline, DestinationOrder, Durability, History, LatencyBudget, Lifespan, Liveliness,
+    Ownership, Presentation, QosData, Reliability, ResourceLimits, TimeBasedFilter,
   },
   discovery::{
-    content_filter_property::{ContentFilterPropertyData, ContentFilterProperty},
+    content_filter_property::{ContentFilterProperty, ContentFilterPropertyData},
     data_types::{
+      spdp_participant_data::{SpdpDiscoveredParticipantData, SpdpDiscoveredParticipantDataKey},
       topic_data::{
-        SubscriptionBuiltinTopicData, ReaderProxy, DiscoveredReaderData, WriterProxy,
-        PublicationBuiltinTopicData, DiscoveredWriterData, TopicBuiltinTopicData,
+        DiscoveredReaderData, DiscoveredReaderDataKey, DiscoveredWriterData,
+        DiscoveredWriterDataKey, PublicationBuiltinTopicData, ReaderProxy,
+        SubscriptionBuiltinTopicData, TopicBuiltinTopicData, WriterProxy,
       },
-      spdp_participant_data::SpdpDiscoveredParticipantData,
-      spdp_participant_data::SpdpDiscoveredParticipantDataKey,
     },
   },
   messages::{
-    vendor_id::{VendorId, VendorIdData},
     protocol_version::{ProtocolVersion, ProtocolVersionData},
+    vendor_id::{VendorId, VendorIdData},
   },
-  dds::qos::policy::{
-    Deadline, Durability, LatencyBudget, Liveliness, Reliability, Ownership, DestinationOrder,
-    TimeBasedFilter, Presentation, Lifespan, History, ResourceLimits, QosData,
+  structure::{
+    builtin_endpoint::{
+      BuiltinEndpointQos, BuiltinEndpointQosData, BuiltinEndpointSet, BuiltinEndpointSetData,
+    },
+    duration::{Duration, DurationData},
+    endpoint::ReliabilityKind,
+    guid::{GUIDData, GUID},
+    locator::{Data as LocatorData, Locator},
+    parameter_id::ParameterId,
   },
 };
-use serde::{Serialize, Serializer, ser::SerializeStruct, Deserialize};
-use std::time::Duration as StdDuration;
 
 #[derive(Serialize, Deserialize)]
 struct StringData {
@@ -148,16 +149,17 @@ impl BuiltinDataSerializerKey {
   }
 }
 
+#[derive(Default)]
 pub struct BuiltinDataSerializer<'a> {
   // Participant Data
   pub protocol_version: Option<ProtocolVersion>,
   pub vendor_id: Option<VendorId>,
   pub expects_inline_qos: Option<bool>,
   pub participant_guid: Option<GUID>,
-  pub metatraffic_unicast_locators: Option<&'a LocatorList>,
-  pub metatraffic_multicast_locators: Option<&'a LocatorList>,
-  pub default_unicast_locators: Option<&'a LocatorList>,
-  pub default_multicast_locators: Option<&'a LocatorList>,
+  pub metatraffic_unicast_locators: Option<&'a Vec<Locator>>,
+  pub metatraffic_multicast_locators: Option<&'a Vec<Locator>>,
+  pub default_unicast_locators: Option<&'a Vec<Locator>>,
+  pub default_multicast_locators: Option<&'a Vec<Locator>>,
   pub available_builtin_endpoints: Option<BuiltinEndpointSet>,
   pub lease_duration: Option<Duration>,
   pub manual_liveliness_count: Option<i32>,
@@ -167,8 +169,8 @@ pub struct BuiltinDataSerializer<'a> {
   pub endpoint_guid: Option<GUID>,
 
   // Reader Proxy
-  pub unicast_locator_list: Option<&'a LocatorList>,
-  pub multicast_locator_list: Option<&'a LocatorList>,
+  pub unicast_locator_list: Option<&'a Vec<Locator>>,
+  pub multicast_locator_list: Option<&'a Vec<Locator>>,
 
   // Writer Proxy
   pub data_max_size_serialized: Option<u32>,
@@ -343,99 +345,27 @@ impl<'a> BuiltinDataSerializer<'a> {
       manual_liveliness_count: Some(participant_data.manual_liveliness_count),
       builtin_endpoint_qos: participant_data.builtin_endpoint_qos,
       entity_name: participant_data.entity_name.as_ref(),
-      endpoint_guid: None,
-      unicast_locator_list: None,
-      multicast_locator_list: None,
-      data_max_size_serialized: None,
-      topic_name: None,
-      type_name: None,
-      durability: None,
-      deadline: None,
-      latency_budget: None,
-      liveliness: None,
-      reliability: None,
-      ownership: None,
-      destination_order: None,
-      time_based_filter: None,
-      presentation: None,
-      lifespan: None,
-      history: None,
-      resource_limits: None,
-      content_filter_property: None,
+      ..BuiltinDataSerializer::default()
     }
   }
 
   pub fn from_reader_proxy(reader_proxy: &'a ReaderProxy) -> BuiltinDataSerializer<'a> {
     BuiltinDataSerializer {
-      protocol_version: None,
-      vendor_id: None,
       expects_inline_qos: Some(reader_proxy.expects_inline_qos),
-      participant_guid: None,
-      metatraffic_unicast_locators: None,
-      metatraffic_multicast_locators: None,
-      default_unicast_locators: None,
-      default_multicast_locators: None,
-      available_builtin_endpoints: None,
-      lease_duration: None,
-      manual_liveliness_count: None,
-      builtin_endpoint_qos: None,
-      entity_name: None,
       endpoint_guid: Some(reader_proxy.remote_reader_guid),
       unicast_locator_list: Some(&reader_proxy.unicast_locator_list),
       multicast_locator_list: Some(&reader_proxy.multicast_locator_list),
-      data_max_size_serialized: None,
-      topic_name: None,
-      type_name: None,
-      durability: None,
-      deadline: None,
-      latency_budget: None,
-      liveliness: None,
-      reliability: None,
-      ownership: None,
-      destination_order: None,
-      time_based_filter: None,
-      presentation: None,
-      lifespan: None,
-      history: None,
-      resource_limits: None,
-      content_filter_property: None,
+      ..BuiltinDataSerializer::default()
     }
   }
 
   pub fn from_writer_proxy(writer_proxy: &'a WriterProxy) -> BuiltinDataSerializer<'a> {
     BuiltinDataSerializer {
-      protocol_version: None,
-      vendor_id: None,
-      expects_inline_qos: None,
-      participant_guid: None,
-      metatraffic_unicast_locators: None,
-      metatraffic_multicast_locators: None,
-      default_unicast_locators: None,
-      default_multicast_locators: None,
-      available_builtin_endpoints: None,
-      lease_duration: None,
-      manual_liveliness_count: None,
-      builtin_endpoint_qos: None,
-      entity_name: None,
       endpoint_guid: Some(writer_proxy.remote_writer_guid),
       unicast_locator_list: Some(&writer_proxy.unicast_locator_list),
       multicast_locator_list: Some(&writer_proxy.multicast_locator_list),
       data_max_size_serialized: writer_proxy.data_max_size_serialized,
-      topic_name: None,
-      type_name: None,
-      durability: None,
-      deadline: None,
-      latency_budget: None,
-      liveliness: None,
-      reliability: None,
-      ownership: None,
-      destination_order: None,
-      time_based_filter: None,
-      presentation: None,
-      lifespan: None,
-      history: None,
-      resource_limits: None,
-      content_filter_property: None,
+      ..BuiltinDataSerializer::default()
     }
   }
 
@@ -443,23 +373,8 @@ impl<'a> BuiltinDataSerializer<'a> {
     subscription_topic_data: &'a SubscriptionBuiltinTopicData,
   ) -> BuiltinDataSerializer<'a> {
     BuiltinDataSerializer {
-      protocol_version: None,
-      vendor_id: None,
-      expects_inline_qos: None,
       participant_guid: *subscription_topic_data.participant_key(),
-      metatraffic_unicast_locators: None,
-      metatraffic_multicast_locators: None,
-      default_unicast_locators: None,
-      default_multicast_locators: None,
-      available_builtin_endpoints: None,
-      lease_duration: None,
-      manual_liveliness_count: None,
-      builtin_endpoint_qos: None,
-      entity_name: None,
       endpoint_guid: Some(subscription_topic_data.key()),
-      unicast_locator_list: None,
-      multicast_locator_list: None,
-      data_max_size_serialized: None,
       topic_name: Some(subscription_topic_data.topic_name()),
       type_name: Some(subscription_topic_data.type_name()),
       durability: *subscription_topic_data.durability(),
@@ -472,9 +387,7 @@ impl<'a> BuiltinDataSerializer<'a> {
       time_based_filter: *subscription_topic_data.time_based_filter(),
       presentation: *subscription_topic_data.presentation(),
       lifespan: *subscription_topic_data.lifespan(),
-      history: None,
-      resource_limits: None,
-      content_filter_property: None,
+      ..BuiltinDataSerializer::default()
     }
   }
 
@@ -482,23 +395,8 @@ impl<'a> BuiltinDataSerializer<'a> {
     publication_topic_data: &'a PublicationBuiltinTopicData,
   ) -> BuiltinDataSerializer {
     BuiltinDataSerializer {
-      protocol_version: None,
-      vendor_id: None,
-      expects_inline_qos: None,
       participant_guid: publication_topic_data.participant_key,
-      metatraffic_unicast_locators: None,
-      metatraffic_multicast_locators: None,
-      default_unicast_locators: None,
-      default_multicast_locators: None,
-      available_builtin_endpoints: None,
-      lease_duration: None,
-      manual_liveliness_count: None,
-      builtin_endpoint_qos: None,
-      entity_name: None,
       endpoint_guid: Some(publication_topic_data.key),
-      unicast_locator_list: None,
-      multicast_locator_list: None,
-      data_max_size_serialized: None,
       topic_name: Some(&publication_topic_data.topic_name),
       type_name: Some(&publication_topic_data.type_name),
       durability: publication_topic_data.durability,
@@ -511,68 +409,20 @@ impl<'a> BuiltinDataSerializer<'a> {
       time_based_filter: publication_topic_data.time_based_filter,
       presentation: publication_topic_data.presentation,
       lifespan: publication_topic_data.lifespan,
-      history: None,
-      resource_limits: None,
-      content_filter_property: None,
+      ..BuiltinDataSerializer::default()
     }
   }
 
   pub fn from_endpoint_guid(guid: &'a GUID) -> BuiltinDataSerializer<'a> {
     BuiltinDataSerializer {
-      protocol_version: None,
-      vendor_id: None,
-      expects_inline_qos: None,
-      participant_guid: None,
-      metatraffic_unicast_locators: None,
-      metatraffic_multicast_locators: None,
-      default_unicast_locators: None,
-      default_multicast_locators: None,
-      available_builtin_endpoints: None,
-      lease_duration: None,
-      manual_liveliness_count: None,
-      builtin_endpoint_qos: None,
-      entity_name: None,
       endpoint_guid: Some(*guid),
-      unicast_locator_list: None,
-      multicast_locator_list: None,
-      data_max_size_serialized: None,
-      topic_name: None,
-      type_name: None,
-      durability: None,
-      deadline: None,
-      latency_budget: None,
-      liveliness: None,
-      reliability: None,
-      ownership: None,
-      destination_order: None,
-      time_based_filter: None,
-      presentation: None,
-      lifespan: None,
-      history: None,
-      resource_limits: None,
-      content_filter_property: None,
+      ..BuiltinDataSerializer::default()
     }
   }
 
   pub fn from_topic_data(topic_data: &'a TopicBuiltinTopicData) -> BuiltinDataSerializer<'a> {
     BuiltinDataSerializer {
-      protocol_version: None,
-      vendor_id: None,
-      expects_inline_qos: None,
-      participant_guid: None,
-      metatraffic_unicast_locators: None,
-      metatraffic_multicast_locators: None,
-      default_unicast_locators: None,
-      default_multicast_locators: None,
-      available_builtin_endpoints: None,
-      lease_duration: None,
-      manual_liveliness_count: None,
-      builtin_endpoint_qos: None,
-      entity_name: None,
       endpoint_guid: topic_data.key,
-      unicast_locator_list: None,
-      multicast_locator_list: None,
-      data_max_size_serialized: None,
       topic_name: Some(&topic_data.name),
       type_name: Some(&topic_data.type_name),
       durability: topic_data.durability,
@@ -582,12 +432,11 @@ impl<'a> BuiltinDataSerializer<'a> {
       reliability: topic_data.reliability,
       ownership: topic_data.ownership,
       destination_order: topic_data.destination_order,
-      time_based_filter: None,
       presentation: topic_data.presentation,
       lifespan: topic_data.lifespan,
       history: topic_data.history,
       resource_limits: topic_data.resource_limits,
-      content_filter_property: None,
+      ..BuiltinDataSerializer::default()
     }
   }
 
@@ -702,7 +551,7 @@ impl<'a> BuiltinDataSerializer<'a> {
   fn fields_amount(&self) -> usize {
     let mut count: usize = 0;
 
-    let empty_ll = LocatorList::new();
+    let empty_ll = Vec::default();
     count += self.protocol_version.is_some() as usize;
     count += self.vendor_id.is_some() as usize;
     count += self.expects_inline_qos.is_some() as usize;
@@ -804,7 +653,7 @@ impl<'a> BuiltinDataSerializer<'a> {
     for locator in locators {
       s.serialize_field(
         "metatraffic_unicast_locators",
-        &LocatorData::from(locator, ParameterId::PID_METATRAFFIC_UNICAST_LOCATOR),
+        &LocatorData::from(*locator, ParameterId::PID_METATRAFFIC_UNICAST_LOCATOR),
       )
       .unwrap();
     }
@@ -820,7 +669,7 @@ impl<'a> BuiltinDataSerializer<'a> {
     for locator in locators {
       s.serialize_field(
         "metatraffic_multicast_locators",
-        &LocatorData::from(locator, ParameterId::PID_METATRAFFIC_MULTICAST_LOCATOR),
+        &LocatorData::from(*locator, ParameterId::PID_METATRAFFIC_MULTICAST_LOCATOR),
       )
       .unwrap();
     }
@@ -836,7 +685,7 @@ impl<'a> BuiltinDataSerializer<'a> {
     for locator in locators {
       s.serialize_field(
         "default_unicast_locators",
-        &LocatorData::from(locator, ParameterId::PID_DEFAULT_UNICAST_LOCATOR),
+        &LocatorData::from(*locator, ParameterId::PID_DEFAULT_UNICAST_LOCATOR),
       )
       .unwrap();
     }
@@ -852,7 +701,7 @@ impl<'a> BuiltinDataSerializer<'a> {
     for locator in locators {
       s.serialize_field(
         "default_multicast_locators",
-        &LocatorData::from(locator, ParameterId::PID_DEFAULT_MULTICAST_LOCATOR),
+        &LocatorData::from(*locator, ParameterId::PID_DEFAULT_MULTICAST_LOCATOR),
       )
       .unwrap();
     }
@@ -925,7 +774,7 @@ impl<'a> BuiltinDataSerializer<'a> {
     for locator in locators {
       s.serialize_field(
         "default_unicast_locators",
-        &LocatorData::from(locator, ParameterId::PID_UNICAST_LOCATOR),
+        &LocatorData::from(*locator, ParameterId::PID_UNICAST_LOCATOR),
       )
       .unwrap();
     }
@@ -941,7 +790,7 @@ impl<'a> BuiltinDataSerializer<'a> {
     for locator in locators {
       s.serialize_field(
         "default_unicast_locators",
-        &LocatorData::from(locator, ParameterId::PID_MULTICAST_LOCATOR),
+        &LocatorData::from(*locator, ParameterId::PID_MULTICAST_LOCATOR),
       )
       .unwrap();
     }
