@@ -1,32 +1,28 @@
-use crate::dds::data_types::GUID;
-use std::collections::BTreeSet;
-use crate::structure::sequence_number::SequenceNumber;
+use std::{
+  cmp::max,
+  collections::{BTreeMap, HashMap},
+  ops::Bound::{Excluded, Included},
+};
 
 #[allow(unused_imports)]
 use log::{debug, error, info, trace};
 
-use std::{
-  collections::{BTreeMap, HashMap /*btree_map::Range*/},
-  cmp::max,
+use crate::{
+  dds::{
+    data_types::GUID,
+    qos::{policy::ResourceLimits, QosPolicies, QosPolicyBuilder},
+    typedesc::TypeDesc,
+  },
+  structure::{sequence_number::SequenceNumber, time::Timestamp},
 };
+use super::{cache_change::CacheChange, topic_kind::TopicKind};
 
-use crate::dds::{
-  typedesc::TypeDesc,
-  qos::{QosPolicies, QosPolicyBuilder, policy::ResourceLimits},
-};
-use crate::structure::time::Timestamp;
-
-use super::{
-  topic_kind::TopicKind,
-  cache_change::{CacheChange},
-};
-use std::ops::Bound::{Included, Excluded};
-
-/// DDSCache contains all cacheCahanges that are produced by participant or recieved by participant.
-/// Each topic that is been published or been subscribed are contained in separate TopicCaches.
-/// One TopicCache cotains only DDSCacheChanges of one serialized IDL datatype.
-/// -> all cachechanges in same TopicCache can be serialized/deserialized same way.
-/// Topic/TopicCache is identified by its name, which must be unique in the whole Domain.
+/// DDSCache contains all cacheCahanges that are produced by participant or
+/// received by participant. Each topic that is been published or been
+/// subscribed are contained in separate TopicCaches. One TopicCache cotains
+/// only DDSCacheChanges of one serialized IDL datatype. -> all cachechanges in
+/// same TopicCache can be serialized/deserialized same way. Topic/TopicCache is
+/// identified by its name, which must be unique in the whole Domain.
 #[derive(Debug)]
 pub struct DDSCache {
   topic_caches: HashMap<String, TopicCache>,
@@ -189,8 +185,8 @@ impl TopicCache {
         max_samples_per_instance: 64,
       })
       .max_samples;
-    // TODO: We cannot currently keep track of instance counts, because TopicCache or
-    // DDSCache below do not know about instances.
+    // TODO: We cannot currently keep track of instance counts, because TopicCache
+    // or DDSCache below do not know about instances.
     let remove_count = self.history_cache.changes.len() as i32 - max_keep_samples as i32;
     let split_key = *self
       .history_cache
@@ -208,7 +204,8 @@ impl TopicCache {
 #[derive(Debug)]
 pub struct DDSHistoryCache {
   pub(crate) changes: BTreeMap<Timestamp, CacheChange>,
-  sequence_numbers: BTreeMap<GUID, BTreeSet<SequenceNumber>>,
+  // sequence_numbers is an index to "changes" by GUID and SN
+  sequence_numbers: BTreeMap<GUID, BTreeMap<SequenceNumber, Timestamp>>,
 }
 
 impl DDSHistoryCache {
@@ -219,31 +216,33 @@ impl DDSHistoryCache {
     }
   }
 
-  fn have_sn(&self, cc: &CacheChange) -> bool {
-    match self.sequence_numbers.get(&cc.writer_guid) {
-      None => false,
-      Some(sn_set) => sn_set.contains(&cc.sequence_number),
-    }
+  fn find_by_sn(&self, cc: &CacheChange) -> Option<Timestamp> {
+    self
+      .sequence_numbers
+      .get(&cc.writer_guid)
+      .map(|snm| snm.get(&cc.sequence_number))
+      .flatten()
+      .cloned()
   }
 
-  fn insert_sn(&mut self, cc: &CacheChange) {
+  fn insert_sn(&mut self, instant: Timestamp, cc: &CacheChange) {
     self
       .sequence_numbers
       .entry(cc.writer_guid)
-      .or_insert_with(|| {
-        let mut s = BTreeSet::new();
-        s.insert(cc.sequence_number);
-        s
-      })
-      .insert(cc.sequence_number);
+      .or_insert_with(BTreeMap::new)
+      .insert(cc.sequence_number, instant);
   }
 
   fn remove_sn(&mut self, cc: &CacheChange) {
+    let mut emptied = false;
+
     self.sequence_numbers.entry(cc.writer_guid).and_modify(|s| {
       s.remove(&cc.sequence_number);
+      emptied = s.is_empty();
     });
-
-    //TODO: If this makes a SN set empty, remove it from BTreeMap.
+    if emptied {
+      self.sequence_numbers.remove(&cc.writer_guid);
+    }
   }
 
   pub fn add_change(
@@ -251,26 +250,32 @@ impl DDSHistoryCache {
     instant: &Timestamp,
     cache_change: CacheChange,
   ) -> Option<CacheChange> {
-    if self.have_sn(&cache_change) {
-      trace!(
-        "Received duplicate {:?} from {:?}, discarding.",
-        cache_change.sequence_number,
-        cache_change.writer_guid
-      );
-      Some(cache_change)
-    } else {
-      self.insert_sn(&cache_change);
-      let result = self.changes.insert(*instant, cache_change);
-      match result {
-        None => None, // all is good. timestamp was not inserted before.
-        Some(old_cc) => {
-          // If this happens cahce changes were created at exactly same instant.
-          error!(
-            "DDSHistoryCache already contained element with key {:?} !!!",
-            instant
-          );
-          self.remove_sn(&old_cc);
-          Some(old_cc)
+    match self.find_by_sn(&cache_change) {
+      Some(old_instant) => {
+        // Got duplicate DATA for a SN that we already have. It should be discarded.
+        debug!(
+          "add_change: discarding duplicate {:?} from {:?}. old timestamp = {:?}, new = {:?}",
+          cache_change.sequence_number, cache_change.writer_guid, old_instant, instant,
+        );
+        Some(cache_change)
+      }
+      None => {
+        // This is a new (to us) SequenceNumber, this is the default processing path.
+        self.insert_sn(*instant, &cache_change);
+        let result = self.changes.insert(*instant, cache_change);
+        match result {
+          None => None, // all is good. timestamp was not inserted before.
+          Some(old_cc) => {
+            // If this happens, cache changes were created at exactly same instant.
+            // This is bad, since we are using instants as keys and assume that they
+            // are unique.
+            error!(
+              "DDSHistoryCache already contained element with key {:?} !!!",
+              instant
+            );
+            self.remove_sn(&old_cc);
+            Some(old_cc)
+          }
         }
       }
     }
@@ -316,17 +321,21 @@ impl DDSHistoryCache {
 
 #[cfg(test)]
 mod tests {
-  use std::sync::{Arc, RwLock};
-  use std::{thread};
+  use std::{
+    sync::{Arc, RwLock},
+    thread,
+  };
 
   use super::DDSCache;
   use crate::{
     dds::{
-      data_types::DDSTimestamp, ddsdata::DDSData, data_types::DDSDuration, typedesc::TypeDesc,
+      data_types::{DDSDuration, DDSTimestamp},
+      ddsdata::DDSData,
+      typedesc::TypeDesc,
     },
-    messages::submessages::submessage_elements::serialized_payload::{SerializedPayload},
+    messages::submessages::submessage_elements::serialized_payload::SerializedPayload,
     structure::{
-      cache_change::CacheChange, topic_kind::TopicKind, guid::GUID, sequence_number::SequenceNumber,
+      cache_change::CacheChange, guid::GUID, sequence_number::SequenceNumber, topic_kind::TopicKind,
     },
   };
 
@@ -350,7 +359,7 @@ mod tests {
       .unwrap()
       .add_change(&topic_name, &DDSTimestamp::now(), change1);
 
-    let pointerToCache1 = cache.clone();
+    let pointer_to_cache_1 = cache.clone();
 
     thread::spawn(move || {
       let topic_name = String::from("ImJustATopic");
@@ -360,7 +369,7 @@ mod tests {
         None,
         DDSData::new(SerializedPayload::default()),
       );
-      pointerToCache1
+      pointer_to_cache_1
         .write()
         .unwrap()
         .add_change(&topic_name, &DDSTimestamp::now(), cahange2);
@@ -370,7 +379,7 @@ mod tests {
         None,
         DDSData::new(SerializedPayload::default()),
       );
-      pointerToCache1
+      pointer_to_cache_1
         .write()
         .unwrap()
         .add_change(&topic_name, &DDSTimestamp::now(), cahange3);
