@@ -1,16 +1,13 @@
-use byteorder::{ByteOrder};
+use byteorder::ByteOrder;
 use enumflags2::BitFlags;
+use serde::{Deserialize, Serialize};
 
 use super::cache_change::ChangeKind;
 use crate::{
-  messages::submessages::submessage_elements::RepresentationIdentifier,
-  serialization::{
-    CDRDeserializerAdapter,
-    cdr_serializer::{to_bytes},
-  },
   dds::traits::serde_adapters::no_key::*,
+  messages::submessages::submessage_elements::RepresentationIdentifier,
+  serialization::{cdr_serializer::to_bytes, CDRDeserializerAdapter},
 };
-use serde::{Serialize, Deserialize};
 
 #[derive(Debug, BitFlags, Clone, Copy, PartialEq, Serialize, Deserialize)]
 #[repr(u8)]
@@ -25,25 +22,30 @@ pub enum StatusInfoEnum {
 #[derive(Debug, Clone, Copy, PartialEq, Serialize, Deserialize)]
 pub struct StatusInfo {
   em: [u8; 3],
-  si: BitFlags<StatusInfoEnum>, // This is now a bit set of StatusInfoEnum
-                                // Interpretation:
-                                // empty set => Sample is ALIVE and must be present in the message
-                                // not Unregistered and not Disposed => ALIVE (but may be asbent)
-                                // Disposed => DataWriter disposed instance. NOT_ALIVE
-                                // Unregistered => DataWriter unregistered message. Note that DataWriter is not required
-                                //  notify about any unregister operations. This does not make the instance NOT_ALIVE, but infoms
-                                //  that the DataWriter is not going to update that instance anymore.
-                                // Filtered => DataWriter wrote a sample, but it was filtered away by the current QoS settings and
-                                // thus data is not present.
-                                //
-                                // There may be several flags set at the same time.
-                                //
-                                // Disposed & Unregistered:
-                                //
-                                // Meanings of some combinations are uknown:
-                                // Disposed & Filtered : ???
-                                // Unregistered & Filtered: ???
-                                // Disposed & Unregistered & Filtered: ???
+  si: BitFlags<StatusInfoEnum>, /* This is now a bit set of StatusInfoEnum
+                                 * Interpretation:
+                                 * empty set => Sample is ALIVE and must be present in the
+                                 * message not Unregistered and
+                                 * not Disposed => ALIVE (but may be asbent)
+                                 * Disposed => DataWriter disposed instance. NOT_ALIVE
+                                 * Unregistered => DataWriter unregistered message. Note that
+                                 * DataWriter is not required
+                                 *  notify about any unregister operations. This does not make
+                                 * the instance NOT_ALIVE, but infoms
+                                 *  that the DataWriter is not going to update that instance
+                                 * anymore. Filtered =>
+                                 * DataWriter wrote a sample, but it was filtered away by the
+                                 * current QoS settings and thus
+                                 * data is not present.
+                                 *
+                                 * There may be several flags set at the same time.
+                                 *
+                                 * Disposed & Unregistered:
+                                 *
+                                 * Meanings of some combinations are uknown:
+                                 * Disposed & Filtered : ???
+                                 * Unregistered & Filtered: ???
+                                 * Disposed & Unregistered & Filtered: ??? */
 }
 
 impl StatusInfo {
@@ -87,9 +89,8 @@ impl StatusInfo {
 
 #[cfg(test)]
 mod tests {
-  use byteorder::LittleEndian;
-  use byteorder::BigEndian;
-  use crate::dds::traits::key::KeyHash;
+  use byteorder::{BigEndian, LittleEndian};
+
   use super::*;
 
   #[test]
@@ -134,6 +135,4 @@ mod tests {
       }
     );
   }
-
-  
 }
